.upload[theme="default"]{transition-property:background-color, border-color, color, fill, stroke, opacity, box-shadow, transform, filter, -webkit-backdrop-filter;transition-property:background-color, border-color, color, fill, stroke, opacity, box-shadow, transform, filter, backdrop-filter;transition-property:background-color, border-color, color, fill, stroke, opacity, box-shadow, transform, filter, backdrop-filter, -webkit-backdrop-filter;transition-timing-function:cubic-bezier(0.4, 0, 0.2, 1);transition-duration:150ms
}.upload[theme="default"]:hover{--tw-border-opacity:1;border-color:rgba(156, 163, 175, var(--tw-border-opacity));--tw-text-opacity:1;color:rgba(107, 114, 128, var(--tw-text-opacity))
}.dark .upload[theme="default"]:hover{--tw-border-opacity:1;border-color:rgba(209, 213, 219, var(--tw-border-opacity));--tw-text-opacity:1;color:rgba(209, 213, 219, var(--tw-text-opacity))
}
.modify-upload[theme="default"]{margin:0.25rem;display:flex;gap:0.25rem}.modify-upload[theme="default"] .edit{border-radius:0.25rem;--tw-bg-opacity:1;background-color:rgba(245, 158, 11, var(--tw-bg-opacity));--tw-shadow:0 1px 3px 0 rgba(0, 0, 0, 0.1), 0 1px 2px 0 rgba(0, 0, 0, 0.06);box-shadow:var(--tw-ring-offset-shadow, 0 0 #0000), var(--tw-ring-shadow, 0 0 #0000), var(--tw-shadow)}.modify-upload[theme="default"] .dark .edit{--tw-bg-opacity:1;background-color:rgba(220, 38, 38, var(--tw-bg-opacity))}.modify-upload[theme="default"] .clear{border-radius:0.25rem;--tw-bg-opacity:1;background-color:rgba(249, 250, 251, var(--tw-bg-opacity));--tw-shadow:0 1px 3px 0 rgba(0, 0, 0, 0.1), 0 1px 2px 0 rgba(0, 0, 0, 0.06);box-shadow:var(--tw-ring-offset-shadow, 0 0 #0000), var(--tw-ring-shadow, 0 0 #0000), var(--tw-shadow)}.modify-upload[theme="default"] .dark .clear{--tw-bg-opacity:1;background-color:rgba(107, 114, 128, var(--tw-bg-opacity))}
.rangeSlider{--pip:var(--range-pip, lightslategray);--pip-text:var(--range-pip-text, var(--pip));--pip-active:var(--range-pip-active, darkslategrey);--pip-active-text:var(--range-pip-active-text, var(--pip-active));--pip-hover:var(--range-pip-hover, darkslategrey);--pip-hover-text:var(--range-pip-hover-text, var(--pip-hover));--pip-in-range:var(--range-pip-in-range, var(--pip-active));--pip-in-range-text:var(--range-pip-in-range-text, var(--pip-active-text))}.rangePips{position:absolute;height:1em;left:0;right:0;bottom:-1em}.rangePips.vertical{height:auto;width:1em;left:100%;right:auto;top:0;bottom:0}.rangePips .pip{height:0.4em;position:absolute;top:0.25em;width:1px;white-space:nowrap}.rangePips.vertical .pip{height:1px;width:0.4em;left:0.25em;top:auto;bottom:auto}.rangePips .pipVal{position:absolute;top:0.4em;transform:translate(-50%, 25%)}.rangePips.vertical .pipVal{position:absolute;top:0;left:0.4em;transform:translate(25%, -50%)}.rangePips .pip{transition:all 0.15s ease}.rangePips .pipVal{transition:all 0.15s ease, font-weight 0s linear}.rangePips .pip{color:lightslategray;color:var(--pip-text);background-color:lightslategray;background-color:var(--pip)}.rangePips .pip.selected{color:darkslategrey;color:var(--pip-active-text);background-color:darkslategrey;background-color:var(--pip-active)}.rangePips.hoverable:not(.disabled) .pip:hover{color:darkslategrey;color:var(--pip-hover-text);background-color:darkslategrey;background-color:var(--pip-hover)}.rangePips .pip.in-range{color:darkslategrey;color:var(--pip-in-range-text);background-color:darkslategrey;background-color:var(--pip-in-range)}.rangePips .pip.selected{height:0.75em}.rangePips.vertical .pip.selected{height:1px;width:0.75em}.rangePips .pip.selected .pipVal{font-weight:bold;top:0.75em}.rangePips.vertical .pip.selected .pipVal{top:0;left:0.75em}.rangePips.hoverable:not(.disabled) .pip:not(.selected):hover{transition:none}.rangePips.hoverable:not(.disabled) .pip:not(.selected):hover .pipVal{transition:none;font-weight:bold}
.rangeSlider{--slider:var(--range-slider, #d7dada);--handle-inactive:var(--range-handle-inactive, #99a2a2);--handle:var(--range-handle, #838de7);--handle-focus:var(--range-handle-focus, #4a40d4);--handle-border:var(--range-handle-border, var(--handle));--range-inactive:var(--range-range-inactive, var(--handle-inactive));--range:var(--range-range, var(--handle-focus));--float-inactive:var(--range-float-inactive, var(--handle-inactive));--float:var(--range-float, var(--handle-focus));--float-text:var(--range-float-text, white);position:relative;border-radius:100px;height:0.5em;margin:1em;transition:opacity 0.2s ease;-webkit-user-select:none;-moz-user-select:none;-ms-user-select:none;user-select:none}.rangeSlider *{-webkit-user-select:none;-moz-user-select:none;-ms-user-select:none;user-select:none}.rangeSlider.pips{margin-bottom:1.8em}.rangeSlider.pip-labels{margin-bottom:2.8em}.rangeSlider.vertical{display:inline-block;border-radius:100px;width:0.5em;min-height:200px}.rangeSlider.vertical.pips{margin-right:1.8em;margin-bottom:1em}.rangeSlider.vertical.pip-labels{margin-right:2.8em;margin-bottom:1em}.rangeSlider .rangeHandle{position:absolute;display:block;height:1.4em;width:1.4em;top:0.25em;bottom:auto;transform:translateY(-50%) translateX(-50%);z-index:2}.rangeSlider.reversed .rangeHandle{transform:translateY(-50%) translateX(50%)}.rangeSlider.vertical .rangeHandle{left:0.25em;top:auto;transform:translateY(50%) translateX(-50%)}.rangeSlider.vertical.reversed .rangeHandle{transform:translateY(-50%) translateX(-50%)}.rangeSlider .rangeNub,.rangeSlider .rangeHandle:before{position:absolute;left:0;top:0;display:block;border-radius:10em;height:100%;width:100%;transition:box-shadow 0.2s ease}.rangeSlider .rangeHandle:before{content:"";left:1px;top:1px;bottom:1px;right:1px;height:auto;width:auto;box-shadow:0 0 0 0px var(--handle-border);opacity:0}.rangeSlider.hoverable:not(.disabled) .rangeHandle:hover:before{box-shadow:0 0 0 8px var(--handle-border);opacity:0.2}.rangeSlider.hoverable:not(.disabled) .rangeHandle.press:before,.rangeSlider.hoverable:not(.disabled) .rangeHandle.press:hover:before{box-shadow:0 0 0 12px var(--handle-border);opacity:0.4}.rangeSlider.range:not(.min):not(.max) .rangeNub{border-radius:10em 10em 10em 1.6em}.rangeSlider.range .rangeHandle:nth-of-type(1) .rangeNub{transform:rotate(-135deg)}.rangeSlider.range .rangeHandle:nth-of-type(2) .rangeNub{transform:rotate(45deg)}.rangeSlider.range.reversed .rangeHandle:nth-of-type(1) .rangeNub{transform:rotate(45deg)}.rangeSlider.range.reversed .rangeHandle:nth-of-type(2) .rangeNub{transform:rotate(-135deg)}.rangeSlider.range.vertical .rangeHandle:nth-of-type(1) .rangeNub{transform:rotate(135deg)}.rangeSlider.range.vertical .rangeHandle:nth-of-type(2) .rangeNub{transform:rotate(-45deg)}.rangeSlider.range.vertical.reversed .rangeHandle:nth-of-type(1) .rangeNub{transform:rotate(-45deg)}.rangeSlider.range.vertical.reversed .rangeHandle:nth-of-type(2) .rangeNub{transform:rotate(135deg)}.rangeSlider .rangeFloat{display:block;position:absolute;left:50%;top:-0.5em;transform:translate(-50%, -100%);font-size:1em;text-align:center;opacity:0;pointer-events:none;white-space:nowrap;transition:all 0.2s ease;font-size:0.9em;padding:0.2em 0.4em;border-radius:0.2em}.rangeSlider .rangeHandle.active .rangeFloat,.rangeSlider.hoverable .rangeHandle:hover .rangeFloat{opacity:1;top:-0.2em;transform:translate(-50%, -100%)}.rangeSlider .rangeBar{position:absolute;display:block;transition:background 0.2s ease;border-radius:1em;height:0.5em;top:0;-webkit-user-select:none;-moz-user-select:none;-ms-user-select:none;user-select:none;z-index:1}.rangeSlider.vertical .rangeBar{width:0.5em;height:auto}.rangeSlider{background-color:#d7dada;background-color:var(--slider)}.rangeSlider .rangeBar{background-color:#99a2a2;background-color:var(--range-inactive)}.rangeSlider.focus .rangeBar{background-color:#838de7;background-color:var(--range)}.rangeSlider .rangeNub{background-color:#99a2a2;background-color:var(--handle-inactive)}.rangeSlider.focus .rangeNub{background-color:#838de7;background-color:var(--handle)}.rangeSlider .rangeHandle.active .rangeNub{background-color:#4a40d4;background-color:var(--handle-focus)}.rangeSlider .rangeFloat{color:white;color:var(--float-text);background-color:#99a2a2;background-color:var(--float-inactive)}.rangeSlider.focus .rangeFloat{background-color:#4a40d4;background-color:var(--float)}.rangeSlider.disabled{opacity:0.5}.rangeSlider.disabled .rangeNub{background-color:#d7dada;background-color:var(--slider)}
.selected.svelte-7ch4xb .check.svelte-7ch4xb{opacity:1
}.input-checkbox[theme="default"].svelte-7ch4xb .checkbox-item.svelte-7ch4xb{--tw-bg-opacity:1;background-color:rgba(255, 255, 255, var(--tw-bg-opacity));--tw-shadow:0 1px 3px 0 rgba(0, 0, 0, 0.1), 0 1px 2px 0 rgba(0, 0, 0, 0.06);box-shadow:var(--tw-ring-offset-shadow, 0 0 #0000), var(--tw-ring-shadow, 0 0 #0000), var(--tw-shadow);transition-property:background-color, border-color, color, fill, stroke, opacity, box-shadow, transform, filter, -webkit-backdrop-filter;transition-property:background-color, border-color, color, fill, stroke, opacity, box-shadow, transform, filter, backdrop-filter;transition-property:background-color, border-color, color, fill, stroke, opacity, box-shadow, transform, filter, backdrop-filter, -webkit-backdrop-filter;transition-timing-function:cubic-bezier(0.4, 0, 0.2, 1);transition-duration:150ms
}.input-checkbox[theme="default"].svelte-7ch4xb .checkbox-item.svelte-7ch4xb:hover{--tw-shadow:0 4px 6px -1px rgba(0, 0, 0, 0.1), 0 2px 4px -1px rgba(0, 0, 0, 0.06);box-shadow:var(--tw-ring-offset-shadow, 0 0 #0000), var(--tw-ring-shadow, 0 0 #0000), var(--tw-shadow)
}.input-checkbox[theme="default"].svelte-7ch4xb .dark .checkbox-item.svelte-7ch4xb{--tw-bg-opacity:1;background-color:rgba(31, 41, 55, var(--tw-bg-opacity))
}.input-checkbox[theme="default"].svelte-7ch4xb .checkbox.svelte-7ch4xb{--tw-bg-opacity:1;background-color:rgba(243, 244, 246, var(--tw-bg-opacity));transition-property:background-color, border-color, color, fill, stroke, opacity, box-shadow, transform, filter, -webkit-backdrop-filter;transition-property:background-color, border-color, color, fill, stroke, opacity, box-shadow, transform, filter, backdrop-filter;transition-property:background-color, border-color, color, fill, stroke, opacity, box-shadow, transform, filter, backdrop-filter, -webkit-backdrop-filter;transition-timing-function:cubic-bezier(0.4, 0, 0.2, 1);transition-duration:150ms
}.input-checkbox[theme="default"].svelte-7ch4xb .dark .checkbox.svelte-7ch4xb{--tw-bg-opacity:1;background-color:rgba(156, 163, 175, var(--tw-bg-opacity))
}.input-checkbox[theme="default"].svelte-7ch4xb .checkbox-item.selected.svelte-7ch4xb{--tw-bg-opacity:1;background-color:rgba(245, 158, 11, var(--tw-bg-opacity));--tw-text-opacity:1;color:rgba(255, 255, 255, var(--tw-text-opacity))
}.input-checkbox[theme="default"].svelte-7ch4xb .dark .checkbox-item.selected.svelte-7ch4xb{--tw-bg-opacity:1;background-color:rgba(220, 38, 38, var(--tw-bg-opacity))
}.input-checkbox[theme="default"].svelte-7ch4xb .selected .checkbox.svelte-7ch4xb{--tw-bg-opacity:1;background-color:rgba(217, 119, 6, var(--tw-bg-opacity))
}.input-checkbox[theme="default"].svelte-7ch4xb .dark .selected .checkbox.svelte-7ch4xb{--tw-bg-opacity:1;background-color:rgba(185, 28, 28, var(--tw-bg-opacity))
}
.selected.svelte-3p1bzx .check.svelte-3p1bzx{opacity:1
}.input-checkbox[theme="default"].svelte-3p1bzx .checkbox-item.svelte-3p1bzx{--tw-bg-opacity:1;background-color:rgba(255, 255, 255, var(--tw-bg-opacity));--tw-shadow:0 1px 3px 0 rgba(0, 0, 0, 0.1), 0 1px 2px 0 rgba(0, 0, 0, 0.06);box-shadow:var(--tw-ring-offset-shadow, 0 0 #0000), var(--tw-ring-shadow, 0 0 #0000), var(--tw-shadow);transition-property:background-color, border-color, color, fill, stroke, opacity, box-shadow, transform, filter, -webkit-backdrop-filter;transition-property:background-color, border-color, color, fill, stroke, opacity, box-shadow, transform, filter, backdrop-filter;transition-property:background-color, border-color, color, fill, stroke, opacity, box-shadow, transform, filter, backdrop-filter, -webkit-backdrop-filter;transition-timing-function:cubic-bezier(0.4, 0, 0.2, 1);transition-duration:150ms
}.input-checkbox[theme="default"].svelte-3p1bzx .checkbox-item.svelte-3p1bzx:hover{--tw-shadow:0 4px 6px -1px rgba(0, 0, 0, 0.1), 0 2px 4px -1px rgba(0, 0, 0, 0.06);box-shadow:var(--tw-ring-offset-shadow, 0 0 #0000), var(--tw-ring-shadow, 0 0 #0000), var(--tw-shadow)
}.input-checkbox[theme="default"].svelte-3p1bzx .dark .checkbox-item.svelte-3p1bzx{--tw-bg-opacity:1;background-color:rgba(31, 41, 55, var(--tw-bg-opacity))
}.input-checkbox[theme="default"].svelte-3p1bzx .checkbox-item.selected.svelte-3p1bzx{--tw-bg-opacity:1;background-color:rgba(245, 158, 11, var(--tw-bg-opacity));--tw-text-opacity:1;color:rgba(255, 255, 255, var(--tw-text-opacity))
}.input-checkbox[theme="default"].svelte-3p1bzx .dark .checkbox-item.selected.svelte-3p1bzx{--tw-bg-opacity:1;background-color:rgba(220, 38, 38, var(--tw-bg-opacity))
}
.selected.svelte-nu9k4h .check.svelte-nu9k4h{opacity:1
}.input-checkbox-group[theme="default"].svelte-nu9k4h .checkbox-item.svelte-nu9k4h{--tw-bg-opacity:1;background-color:rgba(255, 255, 255, var(--tw-bg-opacity));--tw-shadow:0 1px 3px 0 rgba(0, 0, 0, 0.1), 0 1px 2px 0 rgba(0, 0, 0, 0.06);box-shadow:var(--tw-ring-offset-shadow, 0 0 #0000), var(--tw-ring-shadow, 0 0 #0000), var(--tw-shadow);transition-property:background-color, border-color, color, fill, stroke, opacity, box-shadow, transform, filter, -webkit-backdrop-filter;transition-property:background-color, border-color, color, fill, stroke, opacity, box-shadow, transform, filter, backdrop-filter;transition-property:background-color, border-color, color, fill, stroke, opacity, box-shadow, transform, filter, backdrop-filter, -webkit-backdrop-filter;transition-timing-function:cubic-bezier(0.4, 0, 0.2, 1);transition-duration:150ms
}.input-checkbox-group[theme="default"].svelte-nu9k4h .checkbox-item.svelte-nu9k4h:hover{--tw-shadow:0 4px 6px -1px rgba(0, 0, 0, 0.1), 0 2px 4px -1px rgba(0, 0, 0, 0.06);box-shadow:var(--tw-ring-offset-shadow, 0 0 #0000), var(--tw-ring-shadow, 0 0 #0000), var(--tw-shadow)
}.input-checkbox-group[theme="default"].svelte-nu9k4h .dark .checkbox-item.svelte-nu9k4h{--tw-bg-opacity:1;background-color:rgba(31, 41, 55, var(--tw-bg-opacity))
}.input-checkbox-group[theme="default"].svelte-nu9k4h .checkbox.svelte-nu9k4h{--tw-bg-opacity:1;background-color:rgba(243, 244, 246, var(--tw-bg-opacity));transition-property:background-color, border-color, color, fill, stroke, opacity, box-shadow, transform, filter, -webkit-backdrop-filter;transition-property:background-color, border-color, color, fill, stroke, opacity, box-shadow, transform, filter, backdrop-filter;transition-property:background-color, border-color, color, fill, stroke, opacity, box-shadow, transform, filter, backdrop-filter, -webkit-backdrop-filter;transition-timing-function:cubic-bezier(0.4, 0, 0.2, 1);transition-duration:150ms
}.input-checkbox-group[theme="default"].svelte-nu9k4h .dark .checkbox.svelte-nu9k4h{--tw-bg-opacity:1;background-color:rgba(156, 163, 175, var(--tw-bg-opacity))
}.input-checkbox-group[theme="default"].svelte-nu9k4h .checkbox-item.selected.svelte-nu9k4h{--tw-bg-opacity:1;background-color:rgba(245, 158, 11, var(--tw-bg-opacity));--tw-text-opacity:1;color:rgba(255, 255, 255, var(--tw-text-opacity))
}.input-checkbox-group[theme="default"].svelte-nu9k4h .dark .checkbox-item.selected.svelte-nu9k4h{--tw-bg-opacity:1;background-color:rgba(220, 38, 38, var(--tw-bg-opacity))
}.input-checkbox-group[theme="default"].svelte-nu9k4h .selected .checkbox.svelte-nu9k4h{--tw-bg-opacity:1;background-color:rgba(217, 119, 6, var(--tw-bg-opacity))
}.input-checkbox-group[theme="default"].svelte-nu9k4h .dark .selected .checkbox.svelte-nu9k4h{--tw-bg-opacity:1;background-color:rgba(185, 28, 28, var(--tw-bg-opacity))
}
.selected.svelte-nu9k4h .check.svelte-nu9k4h{opacity:1
}.input-checkbox-group[theme="default"].svelte-nu9k4h .checkbox-item.svelte-nu9k4h{--tw-bg-opacity:1;background-color:rgba(255, 255, 255, var(--tw-bg-opacity));--tw-shadow:0 1px 3px 0 rgba(0, 0, 0, 0.1), 0 1px 2px 0 rgba(0, 0, 0, 0.06);box-shadow:var(--tw-ring-offset-shadow, 0 0 #0000), var(--tw-ring-shadow, 0 0 #0000), var(--tw-shadow);transition-property:background-color, border-color, color, fill, stroke, opacity, box-shadow, transform, filter, -webkit-backdrop-filter;transition-property:background-color, border-color, color, fill, stroke, opacity, box-shadow, transform, filter, backdrop-filter;transition-property:background-color, border-color, color, fill, stroke, opacity, box-shadow, transform, filter, backdrop-filter, -webkit-backdrop-filter;transition-timing-function:cubic-bezier(0.4, 0, 0.2, 1);transition-duration:150ms
}.input-checkbox-group[theme="default"].svelte-nu9k4h .checkbox-item.svelte-nu9k4h:hover{--tw-shadow:0 4px 6px -1px rgba(0, 0, 0, 0.1), 0 2px 4px -1px rgba(0, 0, 0, 0.06);box-shadow:var(--tw-ring-offset-shadow, 0 0 #0000), var(--tw-ring-shadow, 0 0 #0000), var(--tw-shadow)
}.input-checkbox-group[theme="default"].svelte-nu9k4h .dark .checkbox-item.svelte-nu9k4h{--tw-bg-opacity:1;background-color:rgba(31, 41, 55, var(--tw-bg-opacity))
}.input-checkbox-group[theme="default"].svelte-nu9k4h .checkbox.svelte-nu9k4h{--tw-bg-opacity:1;background-color:rgba(243, 244, 246, var(--tw-bg-opacity));transition-property:background-color, border-color, color, fill, stroke, opacity, box-shadow, transform, filter, -webkit-backdrop-filter;transition-property:background-color, border-color, color, fill, stroke, opacity, box-shadow, transform, filter, backdrop-filter;transition-property:background-color, border-color, color, fill, stroke, opacity, box-shadow, transform, filter, backdrop-filter, -webkit-backdrop-filter;transition-timing-function:cubic-bezier(0.4, 0, 0.2, 1);transition-duration:150ms
}.input-checkbox-group[theme="default"].svelte-nu9k4h .dark .checkbox.svelte-nu9k4h{--tw-bg-opacity:1;background-color:rgba(156, 163, 175, var(--tw-bg-opacity))
}.input-checkbox-group[theme="default"].svelte-nu9k4h .checkbox-item.selected.svelte-nu9k4h{--tw-bg-opacity:1;background-color:rgba(245, 158, 11, var(--tw-bg-opacity));--tw-text-opacity:1;color:rgba(255, 255, 255, var(--tw-text-opacity))
}.input-checkbox-group[theme="default"].svelte-nu9k4h .dark .checkbox-item.selected.svelte-nu9k4h{--tw-bg-opacity:1;background-color:rgba(220, 38, 38, var(--tw-bg-opacity))
}.input-checkbox-group[theme="default"].svelte-nu9k4h .selected .checkbox.svelte-nu9k4h{--tw-bg-opacity:1;background-color:rgba(217, 119, 6, var(--tw-bg-opacity))
}.input-checkbox-group[theme="default"].svelte-nu9k4h .dark .selected .checkbox.svelte-nu9k4h{--tw-bg-opacity:1;background-color:rgba(185, 28, 28, var(--tw-bg-opacity))
}
.input-dropdown[theme="default"] .selector{--tw-bg-opacity:1;background-color:rgba(255, 255, 255, var(--tw-bg-opacity));--tw-shadow:0 1px 3px 0 rgba(0, 0, 0, 0.1), 0 1px 2px 0 rgba(0, 0, 0, 0.06);box-shadow:var(--tw-ring-offset-shadow, 0 0 #0000), var(--tw-ring-shadow, 0 0 #0000), var(--tw-shadow);transition-property:background-color, border-color, color, fill, stroke, opacity, box-shadow, transform, filter, -webkit-backdrop-filter;transition-property:background-color, border-color, color, fill, stroke, opacity, box-shadow, transform, filter, backdrop-filter;transition-property:background-color, border-color, color, fill, stroke, opacity, box-shadow, transform, filter, backdrop-filter, -webkit-backdrop-filter;transition-timing-function:cubic-bezier(0.4, 0, 0.2, 1);transition-duration:150ms
}.input-dropdown[theme="default"] .selector:hover{--tw-shadow:0 4px 6px -1px rgba(0, 0, 0, 0.1), 0 2px 4px -1px rgba(0, 0, 0, 0.06);box-shadow:var(--tw-ring-offset-shadow, 0 0 #0000), var(--tw-ring-shadow, 0 0 #0000), var(--tw-shadow)
}.input-dropdown[theme="default"] .dark .selector{--tw-bg-opacity:1;background-color:rgba(31, 41, 55, var(--tw-bg-opacity))
}.input-dropdown[theme="default"] .dropdown-menu{--tw-shadow:0 1px 3px 0 rgba(0, 0, 0, 0.1), 0 1px 2px 0 rgba(0, 0, 0, 0.06);box-shadow:var(--tw-ring-offset-shadow, 0 0 #0000), var(--tw-ring-shadow, 0 0 #0000), var(--tw-shadow)
}.input-dropdown[theme="default"] .dropdown-item{--tw-bg-opacity:1;background-color:rgba(255, 255, 255, var(--tw-bg-opacity))
}.input-dropdown[theme="default"] .dropdown-item:hover{--tw-bg-opacity:1;background-color:rgba(245, 158, 11, var(--tw-bg-opacity));font-weight:600;--tw-text-opacity:1;color:rgba(249, 250, 251, var(--tw-text-opacity))
}.input-dropdown[theme="default"] .dark .dropdown-item{--tw-bg-opacity:1;background-color:rgba(31, 41, 55, var(--tw-bg-opacity))
}.input-dropdown[theme="default"] .dark .dropdown-item:hover{--tw-bg-opacity:1;background-color:rgba(220, 38, 38, var(--tw-bg-opacity))
}
.input-dropdown[theme="default"] .selector{--tw-bg-opacity:1;background-color:rgba(255, 255, 255, var(--tw-bg-opacity));--tw-shadow:0 1px 3px 0 rgba(0, 0, 0, 0.1), 0 1px 2px 0 rgba(0, 0, 0, 0.06);box-shadow:var(--tw-ring-offset-shadow, 0 0 #0000), var(--tw-ring-shadow, 0 0 #0000), var(--tw-shadow);transition-property:background-color, border-color, color, fill, stroke, opacity, box-shadow, transform, filter, -webkit-backdrop-filter;transition-property:background-color, border-color, color, fill, stroke, opacity, box-shadow, transform, filter, backdrop-filter;transition-property:background-color, border-color, color, fill, stroke, opacity, box-shadow, transform, filter, backdrop-filter, -webkit-backdrop-filter;transition-timing-function:cubic-bezier(0.4, 0, 0.2, 1);transition-duration:150ms
}.input-dropdown[theme="default"] .selector:hover{--tw-shadow:0 4px 6px -1px rgba(0, 0, 0, 0.1), 0 2px 4px -1px rgba(0, 0, 0, 0.06);box-shadow:var(--tw-ring-offset-shadow, 0 0 #0000), var(--tw-ring-shadow, 0 0 #0000), var(--tw-shadow)
}.input-dropdown[theme="default"] .dark .selector{--tw-bg-opacity:1;background-color:rgba(31, 41, 55, var(--tw-bg-opacity))
}.input-dropdown[theme="default"] .dropdown-menu{--tw-shadow:0 1px 3px 0 rgba(0, 0, 0, 0.1), 0 1px 2px 0 rgba(0, 0, 0, 0.06);box-shadow:var(--tw-ring-offset-shadow, 0 0 #0000), var(--tw-ring-shadow, 0 0 #0000), var(--tw-shadow)
}.input-dropdown[theme="default"] .dropdown-item{--tw-bg-opacity:1;background-color:rgba(255, 255, 255, var(--tw-bg-opacity))
}.input-dropdown[theme="default"] .dropdown-item:hover{font-weight:600
}.input-dropdown[theme="default"] .dark .dropdown-item{--tw-bg-opacity:1;background-color:rgba(31, 41, 55, var(--tw-bg-opacity))
}
.input-file[theme="default"].svelte-cchktx .file-preview.svelte-cchktx{height:15rem
}
.container.svelte-1ide9f7{display:block;touch-action:none}
.image_editor_buttons{width:800px;display:flex;justify-content:flex-end;gap:0.25rem}.image_editor_buttons button{border-top-left-radius:0.25rem;border-top-right-radius:0.25rem;--tw-bg-opacity:1;background-color:rgba(0, 0, 0, var(--tw-bg-opacity));padding-left:0.5rem;padding-right:0.5rem;padding-top:0.25rem;padding-bottom:0.25rem;font-size:1.25rem;line-height:1.75rem;font-weight:600;--tw-text-opacity:1;color:rgba(255, 255, 255, var(--tw-text-opacity))}.tui-image-editor-header-buttons{display:none}.tui-colorpicker-palette-button{width:12px;height:12px}
input::-webkit-outer-spin-button,input::-webkit-inner-spin-button{-webkit-appearance:none;margin:0}input[type="number"]{-moz-appearance:textfield}.input-number[theme="default"]{--tw-shadow:0 1px 3px 0 rgba(0, 0, 0, 0.1), 0 1px 2px 0 rgba(0, 0, 0, 0.06);box-shadow:var(--tw-ring-offset-shadow, 0 0 #0000), var(--tw-ring-shadow, 0 0 #0000), var(--tw-shadow);transition-property:background-color, border-color, color, fill, stroke, opacity, box-shadow, transform, filter, -webkit-backdrop-filter;transition-property:background-color, border-color, color, fill, stroke, opacity, box-shadow, transform, filter, backdrop-filter;transition-property:background-color, border-color, color, fill, stroke, opacity, box-shadow, transform, filter, backdrop-filter, -webkit-backdrop-filter;transition-timing-function:cubic-bezier(0.4, 0, 0.2, 1);transition-duration:150ms}.input-number[theme="default"]:hover{--tw-shadow:0 4px 6px -1px rgba(0, 0, 0, 0.1), 0 2px 4px -1px rgba(0, 0, 0, 0.06);box-shadow:var(--tw-ring-offset-shadow, 0 0 #0000), var(--tw-ring-shadow, 0 0 #0000), var(--tw-shadow)}.dark .input-number[theme="default"]{--tw-bg-opacity:1;background-color:rgba(31, 41, 55, var(--tw-bg-opacity))}
input::-webkit-outer-spin-button,input::-webkit-inner-spin-button{-webkit-appearance:none;margin:0}input[type="number"]{-moz-appearance:textfield}.input-number[theme="default"]{--tw-shadow:0 1px 3px 0 rgba(0, 0, 0, 0.1), 0 1px 2px 0 rgba(0, 0, 0, 0.06);box-shadow:var(--tw-ring-offset-shadow, 0 0 #0000), var(--tw-ring-shadow, 0 0 #0000), var(--tw-shadow);transition-property:background-color, border-color, color, fill, stroke, opacity, box-shadow, transform, filter, -webkit-backdrop-filter;transition-property:background-color, border-color, color, fill, stroke, opacity, box-shadow, transform, filter, backdrop-filter;transition-property:background-color, border-color, color, fill, stroke, opacity, box-shadow, transform, filter, backdrop-filter, -webkit-backdrop-filter;transition-timing-function:cubic-bezier(0.4, 0, 0.2, 1);transition-duration:150ms}.input-number[theme="default"]:hover{--tw-shadow:0 4px 6px -1px rgba(0, 0, 0, 0.1), 0 2px 4px -1px rgba(0, 0, 0, 0.06);box-shadow:var(--tw-ring-offset-shadow, 0 0 #0000), var(--tw-ring-shadow, 0 0 #0000), var(--tw-shadow)}.dark .input-number[theme="default"]{--tw-bg-opacity:1;background-color:rgba(31, 41, 55, var(--tw-bg-opacity))}
.input-radio[theme="default"].svelte-4dsq7y .radio-item.svelte-4dsq7y{--tw-bg-opacity:1;background-color:rgba(255, 255, 255, var(--tw-bg-opacity));--tw-shadow:0 1px 3px 0 rgba(0, 0, 0, 0.1), 0 1px 2px 0 rgba(0, 0, 0, 0.06);box-shadow:var(--tw-ring-offset-shadow, 0 0 #0000), var(--tw-ring-shadow, 0 0 #0000), var(--tw-shadow);transition-property:background-color, border-color, color, fill, stroke, opacity, box-shadow, transform, filter, -webkit-backdrop-filter;transition-property:background-color, border-color, color, fill, stroke, opacity, box-shadow, transform, filter, backdrop-filter;transition-property:background-color, border-color, color, fill, stroke, opacity, box-shadow, transform, filter, backdrop-filter, -webkit-backdrop-filter;transition-timing-function:cubic-bezier(0.4, 0, 0.2, 1);transition-duration:150ms
}.input-radio[theme="default"].svelte-4dsq7y .radio-item.svelte-4dsq7y:hover{--tw-shadow:0 4px 6px -1px rgba(0, 0, 0, 0.1), 0 2px 4px -1px rgba(0, 0, 0, 0.06);box-shadow:var(--tw-ring-offset-shadow, 0 0 #0000), var(--tw-ring-shadow, 0 0 #0000), var(--tw-shadow)
}.input-radio[theme="default"].svelte-4dsq7y .dark .radio-item.svelte-4dsq7y{--tw-bg-opacity:1;background-color:rgba(31, 41, 55, var(--tw-bg-opacity))
}.input-radio[theme="default"].svelte-4dsq7y .radio-circle.svelte-4dsq7y{border-width:4px;--tw-border-opacity:1;border-color:rgba(229, 231, 235, var(--tw-border-opacity));--tw-bg-opacity:1;background-color:rgba(249, 250, 251, var(--tw-bg-opacity))
}.input-radio[theme="default"].svelte-4dsq7y .dark .radio-circle.svelte-4dsq7y{--tw-border-opacity:1;border-color:rgba(75, 85, 99, var(--tw-border-opacity));--tw-bg-opacity:1;background-color:rgba(156, 163, 175, var(--tw-bg-opacity))
}.input-radio[theme="default"].svelte-4dsq7y .radio-item.selected.svelte-4dsq7y{--tw-bg-opacity:1;background-color:rgba(245, 158, 11, var(--tw-bg-opacity));--tw-text-opacity:1;color:rgba(255, 255, 255, var(--tw-text-opacity));--tw-shadow:0 1px 3px 0 rgba(0, 0, 0, 0.1), 0 1px 2px 0 rgba(0, 0, 0, 0.06);box-shadow:var(--tw-ring-offset-shadow, 0 0 #0000), var(--tw-ring-shadow, 0 0 #0000), var(--tw-shadow)
}.input-radio[theme="default"].svelte-4dsq7y .dark .radio-item.selected.svelte-4dsq7y{--tw-bg-opacity:1;background-color:rgba(220, 38, 38, var(--tw-bg-opacity))
}.input-radio[theme="default"].svelte-4dsq7y .radio-circle.svelte-4dsq7y{box-sizing:border-box;height:1rem;width:1rem;border-radius:9999px;--tw-bg-opacity:1;background-color:rgba(255, 255, 255, var(--tw-bg-opacity));transition-property:background-color, border-color, color, fill, stroke, opacity, box-shadow, transform, filter, -webkit-backdrop-filter;transition-property:background-color, border-color, color, fill, stroke, opacity, box-shadow, transform, filter, backdrop-filter;transition-property:background-color, border-color, color, fill, stroke, opacity, box-shadow, transform, filter, backdrop-filter, -webkit-backdrop-filter;transition-timing-function:cubic-bezier(0.4, 0, 0.2, 1);transition-duration:150ms
}.input-radio[theme="default"].svelte-4dsq7y .selected .radio-circle.svelte-4dsq7y{--tw-border-opacity:1;border-color:rgba(217, 119, 6, var(--tw-border-opacity))
}.input-radio[theme="default"].svelte-4dsq7y .dark .selected .radio-circle.svelte-4dsq7y{--tw-border-opacity:1;border-color:rgba(185, 28, 28, var(--tw-border-opacity))
}
.input-radio[theme="default"].svelte-rcyu36 .radio-item.svelte-rcyu36{--tw-bg-opacity:1;background-color:rgba(255, 255, 255, var(--tw-bg-opacity));--tw-shadow:0 1px 3px 0 rgba(0, 0, 0, 0.1), 0 1px 2px 0 rgba(0, 0, 0, 0.06);box-shadow:var(--tw-ring-offset-shadow, 0 0 #0000), var(--tw-ring-shadow, 0 0 #0000), var(--tw-shadow);transition-property:background-color, border-color, color, fill, stroke, opacity, box-shadow, transform, filter, -webkit-backdrop-filter;transition-property:background-color, border-color, color, fill, stroke, opacity, box-shadow, transform, filter, backdrop-filter;transition-property:background-color, border-color, color, fill, stroke, opacity, box-shadow, transform, filter, backdrop-filter, -webkit-backdrop-filter;transition-timing-function:cubic-bezier(0.4, 0, 0.2, 1);transition-duration:150ms
}.input-radio[theme="default"].svelte-rcyu36 .radio-item.svelte-rcyu36:hover{--tw-shadow:0 4px 6px -1px rgba(0, 0, 0, 0.1), 0 2px 4px -1px rgba(0, 0, 0, 0.06);box-shadow:var(--tw-ring-offset-shadow, 0 0 #0000), var(--tw-ring-shadow, 0 0 #0000), var(--tw-shadow)
}.input-radio[theme="default"].svelte-rcyu36 .dark .radio-item.svelte-rcyu36{--tw-bg-opacity:1;background-color:rgba(31, 41, 55, var(--tw-bg-opacity))
}.input-radio[theme="default"].svelte-rcyu36 .radio-circle.svelte-rcyu36{box-sizing:border-box;height:1rem;width:1rem;border-radius:9999px
}.input-radio[theme="default"].svelte-rcyu36 .radio-item.selected.svelte-rcyu36{--tw-bg-opacity:1;background-color:rgba(245, 158, 11, var(--tw-bg-opacity));--tw-text-opacity:1;color:rgba(255, 255, 255, var(--tw-text-opacity));--tw-shadow:0 1px 3px 0 rgba(0, 0, 0, 0.1), 0 1px 2px 0 rgba(0, 0, 0, 0.06);box-shadow:var(--tw-ring-offset-shadow, 0 0 #0000), var(--tw-ring-shadow, 0 0 #0000), var(--tw-shadow)
}.input-radio[theme="default"].svelte-rcyu36 .dark .radio-item.selected.svelte-rcyu36{--tw-bg-opacity:1;background-color:rgba(220, 38, 38, var(--tw-bg-opacity))
}
.range.svelte-my1kre.svelte-my1kre::-webkit-slider-thumb{-webkit-appearance:none;height:1.25rem;width:1.25rem;cursor:pointer;appearance:none;border-radius:0.25rem}.range.svelte-my1kre.svelte-my1kre::-moz-range-thumb{height:1.25rem;width:1.25rem;cursor:pointer;-moz-appearance:none;appearance:none;border-radius:0.25rem}.input-slider[theme="default"].svelte-my1kre .range.svelte-my1kre{height:0.75rem;--tw-bg-opacity:1;background-color:rgba(255, 255, 255, var(--tw-bg-opacity));--tw-shadow:0 1px 3px 0 rgba(0, 0, 0, 0.1), 0 1px 2px 0 rgba(0, 0, 0, 0.06);box-shadow:var(--tw-ring-offset-shadow, 0 0 #0000), var(--tw-ring-shadow, 0 0 #0000), var(--tw-shadow);transition-property:background-color, border-color, color, fill, stroke, opacity, box-shadow, transform, filter, -webkit-backdrop-filter;transition-property:background-color, border-color, color, fill, stroke, opacity, box-shadow, transform, filter, backdrop-filter;transition-property:background-color, border-color, color, fill, stroke, opacity, box-shadow, transform, filter, backdrop-filter, -webkit-backdrop-filter;transition-timing-function:cubic-bezier(0.4, 0, 0.2, 1);transition-duration:150ms}.input-slider[theme="default"].svelte-my1kre .range.svelte-my1kre:hover{--tw-shadow:0 4px 6px -1px rgba(0, 0, 0, 0.1), 0 2px 4px -1px rgba(0, 0, 0, 0.06);box-shadow:var(--tw-ring-offset-shadow, 0 0 #0000), var(--tw-ring-shadow, 0 0 #0000), var(--tw-shadow)}.input-slider[theme="default"].svelte-my1kre .dark .range.svelte-my1kre{--tw-bg-opacity:1;background-color:rgba(31, 41, 55, var(--tw-bg-opacity))}.input-slider[theme="default"].svelte-my1kre .range.svelte-my1kre::-webkit-slider-thumb{background-image:linear-gradient(to bottom, var(--tw-gradient-stops));--tw-gradient-from:#fbbf24;--tw-gradient-stops:var(--tw-gradient-from), var(--tw-gradient-to, rgba(251, 191, 36, 0));--tw-gradient-to:#f59e0b;--tw-shadow:0 1px 3px 0 rgba(0, 0, 0, 0.1), 0 1px 2px 0 rgba(0, 0, 0, 0.06);box-shadow:var(--tw-ring-offset-shadow, 0 0 #0000), var(--tw-ring-shadow, 0 0 #0000), var(--tw-shadow)}.input-slider[theme="default"].svelte-my1kre .dark .range.svelte-my1kre::-webkit-slider-thumb{--tw-gradient-from:#ef4444;--tw-gradient-stops:var(--tw-gradient-from), var(--tw-gradient-to, rgba(239, 68, 68, 0));--tw-gradient-to:#dc2626}.input-slider[theme="default"].svelte-my1kre .range.svelte-my1kre::-moz-range-thumb{background-image:linear-gradient(to bottom, var(--tw-gradient-stops));--tw-gradient-from:#fbbf24;--tw-gradient-stops:var(--tw-gradient-from), var(--tw-gradient-to, rgba(251, 191, 36, 0));--tw-gradient-to:#f59e0b;--tw-shadow:0 1px 3px 0 rgba(0, 0, 0, 0.1), 0 1px 2px 0 rgba(0, 0, 0, 0.06);box-shadow:var(--tw-ring-offset-shadow, 0 0 #0000), var(--tw-ring-shadow, 0 0 #0000), var(--tw-shadow)}.input-slider[theme="default"].svelte-my1kre .value.svelte-my1kre{--tw-bg-opacity:1;background-color:rgba(243, 244, 246, var(--tw-bg-opacity));font-weight:600}.input-slider[theme="default"].svelte-my1kre .dark .value.svelte-my1kre{--tw-bg-opacity:1;background-color:rgba(75, 85, 99, var(--tw-bg-opacity))}
.range.svelte-my1kre.svelte-my1kre::-webkit-slider-thumb{-webkit-appearance:none;height:1.25rem;width:1.25rem;cursor:pointer;appearance:none;border-radius:0.25rem}.range.svelte-my1kre.svelte-my1kre::-moz-range-thumb{height:1.25rem;width:1.25rem;cursor:pointer;-moz-appearance:none;appearance:none;border-radius:0.25rem}.input-slider[theme="default"].svelte-my1kre .range.svelte-my1kre{height:0.75rem;--tw-bg-opacity:1;background-color:rgba(255, 255, 255, var(--tw-bg-opacity));--tw-shadow:0 1px 3px 0 rgba(0, 0, 0, 0.1), 0 1px 2px 0 rgba(0, 0, 0, 0.06);box-shadow:var(--tw-ring-offset-shadow, 0 0 #0000), var(--tw-ring-shadow, 0 0 #0000), var(--tw-shadow);transition-property:background-color, border-color, color, fill, stroke, opacity, box-shadow, transform, filter, -webkit-backdrop-filter;transition-property:background-color, border-color, color, fill, stroke, opacity, box-shadow, transform, filter, backdrop-filter;transition-property:background-color, border-color, color, fill, stroke, opacity, box-shadow, transform, filter, backdrop-filter, -webkit-backdrop-filter;transition-timing-function:cubic-bezier(0.4, 0, 0.2, 1);transition-duration:150ms}.input-slider[theme="default"].svelte-my1kre .range.svelte-my1kre:hover{--tw-shadow:0 4px 6px -1px rgba(0, 0, 0, 0.1), 0 2px 4px -1px rgba(0, 0, 0, 0.06);box-shadow:var(--tw-ring-offset-shadow, 0 0 #0000), var(--tw-ring-shadow, 0 0 #0000), var(--tw-shadow)}.input-slider[theme="default"].svelte-my1kre .dark .range.svelte-my1kre{--tw-bg-opacity:1;background-color:rgba(31, 41, 55, var(--tw-bg-opacity))}.input-slider[theme="default"].svelte-my1kre .range.svelte-my1kre::-webkit-slider-thumb{background-image:linear-gradient(to bottom, var(--tw-gradient-stops));--tw-gradient-from:#fbbf24;--tw-gradient-stops:var(--tw-gradient-from), var(--tw-gradient-to, rgba(251, 191, 36, 0));--tw-gradient-to:#f59e0b;--tw-shadow:0 1px 3px 0 rgba(0, 0, 0, 0.1), 0 1px 2px 0 rgba(0, 0, 0, 0.06);box-shadow:var(--tw-ring-offset-shadow, 0 0 #0000), var(--tw-ring-shadow, 0 0 #0000), var(--tw-shadow)}.input-slider[theme="default"].svelte-my1kre .dark .range.svelte-my1kre::-webkit-slider-thumb{--tw-gradient-from:#ef4444;--tw-gradient-stops:var(--tw-gradient-from), var(--tw-gradient-to, rgba(239, 68, 68, 0));--tw-gradient-to:#dc2626}.input-slider[theme="default"].svelte-my1kre .range.svelte-my1kre::-moz-range-thumb{background-image:linear-gradient(to bottom, var(--tw-gradient-stops));--tw-gradient-from:#fbbf24;--tw-gradient-stops:var(--tw-gradient-from), var(--tw-gradient-to, rgba(251, 191, 36, 0));--tw-gradient-to:#f59e0b;--tw-shadow:0 1px 3px 0 rgba(0, 0, 0, 0.1), 0 1px 2px 0 rgba(0, 0, 0, 0.06);box-shadow:var(--tw-ring-offset-shadow, 0 0 #0000), var(--tw-ring-shadow, 0 0 #0000), var(--tw-shadow)}.input-slider[theme="default"].svelte-my1kre .value.svelte-my1kre{--tw-bg-opacity:1;background-color:rgba(243, 244, 246, var(--tw-bg-opacity));font-weight:600}.input-slider[theme="default"].svelte-my1kre .dark .value.svelte-my1kre{--tw-bg-opacity:1;background-color:rgba(75, 85, 99, var(--tw-bg-opacity))}
.input-text[theme="default"]{--tw-shadow:0 1px 3px 0 rgba(0, 0, 0, 0.1), 0 1px 2px 0 rgba(0, 0, 0, 0.06);box-shadow:var(--tw-ring-offset-shadow, 0 0 #0000), var(--tw-ring-shadow, 0 0 #0000), var(--tw-shadow);transition-property:background-color, border-color, color, fill, stroke, opacity, box-shadow, transform, filter, -webkit-backdrop-filter;transition-property:background-color, border-color, color, fill, stroke, opacity, box-shadow, transform, filter, backdrop-filter;transition-property:background-color, border-color, color, fill, stroke, opacity, box-shadow, transform, filter, backdrop-filter, -webkit-backdrop-filter;transition-timing-function:cubic-bezier(0.4, 0, 0.2, 1);transition-duration:150ms
}.input-text[theme="default"]:hover{--tw-shadow:0 4px 6px -1px rgba(0, 0, 0, 0.1), 0 2px 4px -1px rgba(0, 0, 0, 0.06);box-shadow:var(--tw-ring-offset-shadow, 0 0 #0000), var(--tw-ring-shadow, 0 0 #0000), var(--tw-shadow)
}.dark .input-text[theme="default"]{--tw-bg-opacity:1;background-color:rgba(31, 41, 55, var(--tw-bg-opacity))
}
.sorted.svelte-113l4lf::after{opacity:1}.des.svelte-113l4lf::after{transform:rotate(180deg) translateY(1.5px)}
.output-file[theme="default"].svelte-1ubyv2p{height:15rem
}.output-file[theme="default"].svelte-1ubyv2p:hover{--tw-text-opacity:1;color:rgba(107, 114, 128, var(--tw-text-opacity))
}
.output-highlightedtext[theme="default"].svelte-c0uzn6 .textfield.svelte-c0uzn6{--tw-shadow:0 1px 3px 0 rgba(0, 0, 0, 0.1), 0 1px 2px 0 rgba(0, 0, 0, 0.06);box-shadow:var(--tw-ring-offset-shadow, 0 0 #0000), var(--tw-ring-shadow, 0 0 #0000), var(--tw-shadow)
}
.output-text[theme="default"]{--tw-shadow:0 1px 3px 0 rgba(0, 0, 0, 0.1), 0 1px 2px 0 rgba(0, 0, 0, 0.06);box-shadow:var(--tw-ring-offset-shadow, 0 0 #0000), var(--tw-ring-shadow, 0 0 #0000), var(--tw-shadow);transition-property:background-color, border-color, color, fill, stroke, opacity, box-shadow, transform, filter, -webkit-backdrop-filter;transition-property:background-color, border-color, color, fill, stroke, opacity, box-shadow, transform, filter, backdrop-filter;transition-property:background-color, border-color, color, fill, stroke, opacity, box-shadow, transform, filter, backdrop-filter, -webkit-backdrop-filter;transition-timing-function:cubic-bezier(0.4, 0, 0.2, 1);transition-duration:150ms
}.output-text[theme="default"]:hover{--tw-shadow:0 4px 6px -1px rgba(0, 0, 0, 0.1), 0 2px 4px -1px rgba(0, 0, 0, 0.06);box-shadow:var(--tw-ring-offset-shadow, 0 0 #0000), var(--tw-ring-shadow, 0 0 #0000), var(--tw-shadow)
}.dark .output-text[theme="default"]{--tw-bg-opacity:1;background-color:rgba(31, 41, 55, var(--tw-bg-opacity))
}
.output-label[theme="default"].svelte-1m14co9 .label.svelte-1m14co9{height:1.75rem;font-size:1rem;line-height:1.5rem
}.output-label[theme="default"].svelte-1m14co9 .confidence.svelte-1m14co9{box-sizing:border-box;height:1.75rem;border-radius:0.25rem;border-bottom-width:2px;--tw-border-opacity:1;border-color:rgba(209, 213, 219, var(--tw-border-opacity));--tw-bg-opacity:1;background-color:rgba(229, 231, 235, var(--tw-bg-opacity));font-family:ui-monospace, SFMono-Regular, Menlo, Monaco, Consolas, "Liberation Mono", "Courier New", monospace;font-size:0.875rem;line-height:1.25rem;font-weight:600
}.output-label[theme="default"].svelte-1m14co9 .dark .confidence.svelte-1m14co9{--tw-border-opacity:1;border-color:rgba(75, 85, 99, var(--tw-border-opacity));--tw-bg-opacity:1;background-color:rgba(107, 114, 128, var(--tw-bg-opacity))
}.output-label[theme="default"].svelte-1m14co9 .confidence.svelte-1m14co9:first-child{--tw-border-opacity:1;border-color:rgba(217, 119, 6, var(--tw-border-opacity));--tw-border-opacity:1;border-color:rgba(185, 28, 28, var(--tw-border-opacity));--tw-bg-opacity:1;background-color:rgba(245, 158, 11, var(--tw-bg-opacity));--tw-text-opacity:1;color:rgba(255, 255, 255, var(--tw-text-opacity))
}.output-label[theme="default"].svelte-1m14co9 .dark .confidence.svelte-1m14co9:first-child{--tw-bg-opacity:1;background-color:rgba(220, 38, 38, var(--tw-bg-opacity))
}
.output-text[theme="default"]{--tw-shadow:0 1px 3px 0 rgba(0, 0, 0, 0.1), 0 1px 2px 0 rgba(0, 0, 0, 0.06);box-shadow:var(--tw-ring-offset-shadow, 0 0 #0000), var(--tw-ring-shadow, 0 0 #0000), var(--tw-shadow);transition-property:background-color, border-color, color, fill, stroke, opacity, box-shadow, transform, filter, -webkit-backdrop-filter;transition-property:background-color, border-color, color, fill, stroke, opacity, box-shadow, transform, filter, backdrop-filter;transition-property:background-color, border-color, color, fill, stroke, opacity, box-shadow, transform, filter, backdrop-filter, -webkit-backdrop-filter;transition-timing-function:cubic-bezier(0.4, 0, 0.2, 1);transition-duration:150ms
}.output-text[theme="default"]:hover{--tw-shadow:0 4px 6px -1px rgba(0, 0, 0, 0.1), 0 2px 4px -1px rgba(0, 0, 0, 0.06);box-shadow:var(--tw-ring-offset-shadow, 0 0 #0000), var(--tw-ring-shadow, 0 0 #0000), var(--tw-shadow)
}.dark .output-text[theme="default"]{--tw-bg-opacity:1;background-color:rgba(31, 41, 55, var(--tw-bg-opacity))
}
.examples[theme="default"] .examples-holder:not(.gallery){--tw-shadow:0 1px 3px 0 rgba(0, 0, 0, 0.1), 0 1px 2px 0 rgba(0, 0, 0, 0.06);box-shadow:var(--tw-ring-offset-shadow, 0 0 #0000), var(--tw-ring-shadow, 0 0 #0000), var(--tw-shadow)
}.examples[theme="default"] .examples-holder:not(.gallery) .examples-table{border-radius:0.25rem
}.examples[theme="default"] .examples-holder:not(.gallery) .dark .examples-table{--tw-bg-opacity:1;background-color:rgba(55, 65, 81, var(--tw-bg-opacity))
}.examples[theme="default"] .examples-holder:not(.gallery) .examples-table thead{--tw-border-opacity:1;border-color:rgba(209, 213, 219, var(--tw-border-opacity))
}.examples[theme="default"] .examples-holder:not(.gallery) .examples-table .dark thead{--tw-border-opacity:1;border-color:rgba(75, 85, 99, var(--tw-border-opacity))
}.examples[theme="default"] .examples-holder:not(.gallery) .examples-table tbody tr:hover{--tw-bg-opacity:1;background-color:rgba(245, 158, 11, var(--tw-bg-opacity));--tw-text-opacity:1;color:rgba(255, 255, 255, var(--tw-text-opacity))
}.examples[theme="default"] .examples-holder:not(.gallery) .examples-table .dark tbody tr:hover{--tw-bg-opacity:1;background-color:rgba(185, 28, 28, var(--tw-bg-opacity))
}.examples[theme="default"] .examples-holder .examples-gallery .example{--tw-shadow:0 1px 3px 0 rgba(0, 0, 0, 0.1), 0 1px 2px 0 rgba(0, 0, 0, 0.06);box-shadow:var(--tw-ring-offset-shadow, 0 0 #0000), var(--tw-ring-shadow, 0 0 #0000), var(--tw-shadow)
}.examples[theme="default"] .examples-holder .examples-gallery .example:hover{--tw-bg-opacity:1;background-color:rgba(245, 158, 11, var(--tw-bg-opacity));--tw-text-opacity:1;color:rgba(255, 255, 255, var(--tw-text-opacity))
}
@-webkit-keyframes ld-breath{0%{-webkit-animation-timing-function:cubic-bezier(
          0.9647,
          0.2413,
          -0.0705,
          0.7911
        );animation-timing-function:cubic-bezier(
          0.9647,
          0.2413,
          -0.0705,
          0.7911
        );transform:scale(0.9)}51%{-webkit-animation-timing-function:cubic-bezier(
          0.9226,
          0.2631,
          -0.0308,
          0.7628
        );animation-timing-function:cubic-bezier(
          0.9226,
          0.2631,
          -0.0308,
          0.7628
        );transform:scale(1.2)}100%{transform:scale(0.9)}}@keyframes ld-breath{0%{-webkit-animation-timing-function:cubic-bezier(
          0.9647,
          0.2413,
          -0.0705,
          0.7911
        );animation-timing-function:cubic-bezier(
          0.9647,
          0.2413,
          -0.0705,
          0.7911
        );transform:scale(0.9)}51%{-webkit-animation-timing-function:cubic-bezier(
          0.9226,
          0.2631,
          -0.0308,
          0.7628
        );animation-timing-function:cubic-bezier(
          0.9226,
          0.2631,
          -0.0308,
          0.7628
        );transform:scale(1.2)}100%{transform:scale(0.9)}}.pending{-webkit-animation:ld-breath 0.75s infinite linear;animation:ld-breath 0.75s infinite linear}.gradio-interface[theme="default"] .component-set{--tw-bg-opacity:1;background-color:rgba(249, 250, 251, var(--tw-bg-opacity));--tw-shadow:0 1px 3px 0 rgba(0, 0, 0, 0.1), 0 1px 2px 0 rgba(0, 0, 0, 0.06);box-shadow:var(--tw-ring-offset-shadow, 0 0 #0000), var(--tw-ring-shadow, 0 0 #0000), var(--tw-shadow)}.gradio-interface[theme="default"] .dark .component-set{--tw-bg-opacity:1;background-color:rgba(55, 65, 81, var(--tw-bg-opacity));--tw-drop-shadow:drop-shadow(0 20px 13px rgba(0, 0, 0, 0.03)) drop-shadow(0 8px 5px rgba(0, 0, 0, 0.08));filter:var(--tw-filter)}.gradio-interface[theme="default"] .component{margin-bottom:0.5rem}.gradio-interface[theme="default"] .panel-header{font-size:0.75rem;line-height:1rem;text-transform:uppercase}.gradio-interface[theme="default"] .panel-button{--tw-shadow:0 1px 3px 0 rgba(0, 0, 0, 0.1), 0 1px 2px 0 rgba(0, 0, 0, 0.06);box-shadow:var(--tw-ring-offset-shadow, 0 0 #0000), var(--tw-ring-shadow, 0 0 #0000), var(--tw-shadow)}.gradio-interface[theme="default"] .panel-button:hover{--tw-bg-opacity:1;background-color:rgba(243, 244, 246, var(--tw-bg-opacity))}.gradio-interface[theme="default"] .dark .panel-button:hover{--tw-bg-opacity:1;background-color:rgba(75, 85, 99, var(--tw-bg-opacity))}.gradio-interface[theme="default"] .panel-button.disabled{cursor:not-allowed;--tw-text-opacity:1;color:rgba(156, 163, 175, var(--tw-text-opacity))}.gradio-interface[theme="default"] .panel-button.submit{--tw-bg-opacity:1;background-color:rgba(245, 158, 11, var(--tw-bg-opacity));--tw-text-opacity:1;color:rgba(255, 255, 255, var(--tw-text-opacity))}.gradio-interface[theme="default"] .panel-button.submit:hover{--tw-bg-opacity:1;background-color:rgba(251, 191, 36, var(--tw-bg-opacity))}.gradio-interface[theme="default"] .dark .panel-button.submit{--tw-bg-opacity:1;background-color:rgba(185, 28, 28, var(--tw-bg-opacity))}.gradio-interface[theme="default"] .dark .panel-button.submit:hover{--tw-bg-opacity:1;background-color:rgba(220, 38, 38, var(--tw-bg-opacity))}.gradio-interface[theme="default"] .examples .examples-table-holder:not(.gallery){--tw-shadow:0 1px 3px 0 rgba(0, 0, 0, 0.1), 0 1px 2px 0 rgba(0, 0, 0, 0.06);box-shadow:var(--tw-ring-offset-shadow, 0 0 #0000), var(--tw-ring-shadow, 0 0 #0000), var(--tw-shadow)}.gradio-interface[theme="default"] .examples .examples-table-holder:not(.gallery) .examples-table{border-radius:0.25rem}.gradio-interface[theme="default"] .examples .examples-table-holder:not(.gallery) .dark .examples-table{--tw-bg-opacity:1;background-color:rgba(55, 65, 81, var(--tw-bg-opacity))}.gradio-interface[theme="default"] .examples .examples-table-holder:not(.gallery) .examples-table thead{--tw-border-opacity:1;border-color:rgba(209, 213, 219, var(--tw-border-opacity))}.gradio-interface[theme="default"] .examples .examples-table-holder:not(.gallery) .examples-table .dark thead{--tw-border-opacity:1;border-color:rgba(75, 85, 99, var(--tw-border-opacity))}.gradio-interface[theme="default"] .examples .examples-table-holder:not(.gallery) .examples-table tbody tr:hover{--tw-bg-opacity:1;background-color:rgba(245, 158, 11, var(--tw-bg-opacity));--tw-text-opacity:1;color:rgba(255, 255, 255, var(--tw-text-opacity))}.gradio-interface[theme="default"] .examples .examples-table-holder:not(.gallery) .examples-table .dark tbody tr:hover{--tw-bg-opacity:1;background-color:rgba(185, 28, 28, var(--tw-bg-opacity))}.gradio-interface[theme="default"] .examples .examples-table-holder.gallery .examples-table tbody td{--tw-shadow:0 1px 3px 0 rgba(0, 0, 0, 0.1), 0 1px 2px 0 rgba(0, 0, 0, 0.06);box-shadow:var(--tw-ring-offset-shadow, 0 0 #0000), var(--tw-ring-shadow, 0 0 #0000), var(--tw-shadow)}.gradio-interface[theme="default"] .examples .examples-table-holder.gallery .examples-table tbody td:hover{--tw-bg-opacity:1;background-color:rgba(245, 158, 11, var(--tw-bg-opacity));--tw-text-opacity:1;color:rgba(255, 255, 255, var(--tw-text-opacity))}
*,::before,::after{box-sizing:border-box}html{-moz-tab-size:4;-o-tab-size:4;tab-size:4;line-height:1.15;-webkit-text-size-adjust:100%}body{margin:0;font-family:system-ui,
		-apple-system, /* Firefox supports this but not yet `system-ui` */
		'Segoe UI',
		Roboto,
		Helvetica,
		Arial,
		sans-serif,
		'Apple Color Emoji',
		'Segoe UI Emoji'}hr{height:0;color:inherit}abbr[title]{-webkit-text-decoration:underline dotted;text-decoration:underline dotted}b,strong{font-weight:bolder}code,kbd,samp,pre{font-family:ui-monospace,
		SFMono-Regular,
		Consolas,
		'Liberation Mono',
		Menlo,
		monospace;font-size:1em}small{font-size:80%}sub,sup{font-size:75%;line-height:0;position:relative;vertical-align:baseline}sub{bottom:-0.25em}sup{top:-0.5em}table{text-indent:0;border-color:inherit}button,input,optgroup,select,textarea{font-family:inherit;font-size:100%;line-height:1.15;margin:0}button,select{text-transform:none}button,[type='button'],[type='reset'],[type='submit']{-webkit-appearance:button}::-moz-focus-inner{border-style:none;padding:0}:-moz-focusring{outline:1px dotted ButtonText}:-moz-ui-invalid{box-shadow:none}legend{padding:0}progress{vertical-align:baseline}::-webkit-inner-spin-button,::-webkit-outer-spin-button{height:auto}[type='search']{-webkit-appearance:textfield;outline-offset:-2px}::-webkit-search-decoration{-webkit-appearance:none}::-webkit-file-upload-button{-webkit-appearance:button;font:inherit}summary{display:list-item}blockquote,dl,dd,h1,h2,h3,h4,h5,h6,hr,figure,p,pre{margin:0}button{background-color:transparent;background-image:none}fieldset{margin:0;padding:0}ol,ul{list-style:none;margin:0;padding:0}html{font-family:ui-sans-serif, system-ui, -apple-system, BlinkMacSystemFont, "Segoe UI", Roboto, "Helvetica Neue", Arial, "Noto Sans", sans-serif, "Apple Color Emoji", "Segoe UI Emoji", "Segoe UI Symbol", "Noto Color Emoji";line-height:1.5}body{font-family:inherit;line-height:inherit}*,::before,::after{box-sizing:border-box;border-width:0;border-style:solid;border-color:currentColor}hr{border-top-width:1px}img{border-style:solid}textarea{resize:vertical}input::-moz-placeholder,textarea::-moz-placeholder{opacity:1;color:#9ca3af}input:-ms-input-placeholder,textarea:-ms-input-placeholder{opacity:1;color:#9ca3af}input::-moz-placeholder, textarea::-moz-placeholder{opacity:1;color:#9ca3af}input:-ms-input-placeholder, textarea:-ms-input-placeholder{opacity:1;color:#9ca3af}input::placeholder,textarea::placeholder{opacity:1;color:#9ca3af}button,[role="button"]{cursor:pointer}:-moz-focusring{outline:auto}table{border-collapse:collapse}h1,h2,h3,h4,h5,h6{font-size:inherit;font-weight:inherit}a{color:inherit;text-decoration:inherit}button,input,optgroup,select,textarea{padding:0;line-height:inherit;color:inherit}pre,code,kbd,samp{font-family:ui-monospace, SFMono-Regular, Menlo, Monaco, Consolas, "Liberation Mono", "Courier New", monospace}img,svg,video,canvas,audio,iframe,embed,object{display:block;vertical-align:middle}img,video{max-width:100%;height:auto}[hidden]{display:none}*,::before,::after{--tw-translate-x:0;--tw-translate-y:0;--tw-rotate:0;--tw-skew-x:0;--tw-skew-y:0;--tw-scale-x:1;--tw-scale-y:1;--tw-transform:translateX(var(--tw-translate-x)) translateY(var(--tw-translate-y)) rotate(var(--tw-rotate)) skewX(var(--tw-skew-x)) skewY(var(--tw-skew-y)) scaleX(var(--tw-scale-x)) scaleY(var(--tw-scale-y));--tw-border-opacity:1;border-color:rgba(229, 231, 235, var(--tw-border-opacity));--tw-ring-offset-shadow:0 0 #0000;--tw-ring-shadow:0 0 #0000;--tw-shadow:0 0 #0000;--tw-blur:var(--tw-empty,/*!*/ /*!*/);--tw-brightness:var(--tw-empty,/*!*/ /*!*/);--tw-contrast:var(--tw-empty,/*!*/ /*!*/);--tw-grayscale:var(--tw-empty,/*!*/ /*!*/);--tw-hue-rotate:var(--tw-empty,/*!*/ /*!*/);--tw-invert:var(--tw-empty,/*!*/ /*!*/);--tw-saturate:var(--tw-empty,/*!*/ /*!*/);--tw-sepia:var(--tw-empty,/*!*/ /*!*/);--tw-drop-shadow:var(--tw-empty,/*!*/ /*!*/);--tw-filter:var(--tw-blur) var(--tw-brightness) var(--tw-contrast) var(--tw-grayscale) var(--tw-hue-rotate) var(--tw-invert) var(--tw-saturate) var(--tw-sepia) var(--tw-drop-shadow)}.container{width:100%}@media(min-width: 640px){.container{max-width:640px}}@media(min-width: 768px){.container{max-width:768px}}@media(min-width: 1024px){.container{max-width:1024px}}@media(min-width: 1280px){.container{max-width:1280px}}@media(min-width: 1536px){.container{max-width:1536px}}.fixed{position:fixed}.absolute{position:absolute}.relative{position:relative}.inset-x-0{left:0px;right:0px}.inset-y-0{top:0px;bottom:0px}.right-2{right:0.5rem}.top-0{top:0px}.left-0{left:0px}.right-0{right:0px}.bottom-2{bottom:0.5rem}.left-6{left:1.5rem}.z-40{z-index:40}.z-50{z-index:50}.z-10{z-index:10}.m-1{margin:0.25rem}.m-auto{margin:auto}.m-2{margin:0.5rem}.mx-auto{margin-left:auto;margin-right:auto}.my-2{margin-top:0.5rem;margin-bottom:0.5rem}.my-4{margin-top:1rem;margin-bottom:1rem}.mx-2{margin-left:0.5rem;margin-right:0.5rem}.my-1{margin-top:0.25rem;margin-bottom:0.25rem}.mb-4{margin-bottom:1rem}.mt-4{margin-top:1rem}.mb-1\.5{margin-bottom:0.375rem}.mb-1{margin-bottom:0.25rem}.ml-1{margin-left:0.25rem}.ml-2{margin-left:0.5rem}.mt-8{margin-top:2rem}.mr-1{margin-right:0.25rem}.mr-0{margin-right:0px}.mt-1{margin-top:0.25rem}.mt-0\.5{margin-top:0.125rem}.mt-0{margin-top:0px}.mb-2{margin-bottom:0.5rem}.mr-0\.5{margin-right:0.125rem}.ml-0\.5{margin-left:0.125rem}.ml-0{margin-left:0px}.mb-3{margin-bottom:0.75rem}.mr-2{margin-right:0.5rem}.box-border{box-sizing:border-box}.block{display:block}.inline-block{display:inline-block}.inline{display:inline}.flex{display:flex}.inline-flex{display:inline-flex}.table{display:table}.grid{display:grid}.hidden{display:none}.h-full{height:100%}.h-auto{height:auto}.h-5{height:1.25rem}.h-6{height:1.5rem}.h-\[10px\]{height:10px}.h-screen{height:100vh}.h-8{height:2rem}.h-4{height:1rem}.h-3{height:0.75rem}.h-60{height:15rem}.h-10{height:2.5rem}.h-2\/4{height:50%}.h-80{height:20rem}.h-24{height:6rem}.h-7{height:1.75rem}.max-h-80{max-height:20rem}.min-h-full{min-height:100%}.min-h-\[3\.3rem\]{min-height:3.3rem}.w-1\/2{width:50%}.w-\[10px\]{width:10px}.w-full{width:100%}.w-screen{width:100vw}.w-8{width:2rem}.w-3{width:0.75rem}.w-10{width:2.5rem}.w-2\/4{width:50%}.w-4{width:1rem}.w-3\/4{width:75%}.w-1\/5{width:20%}.w-3\/5{width:60%}.w-5{width:1.25rem}.min-w-full{min-width:100%}.max-w-none{max-width:none}.max-w-full{max-width:100%}.flex-1{flex:1 1 0%}.flex-shrink-0{flex-shrink:0}.flex-grow{flex-grow:1}.table-auto{table-layout:auto}.border-collapse{border-collapse:collapse}.transform{transform:var(--tw-transform)}.cursor-pointer{cursor:pointer}.cursor-default{cursor:default}.appearance-none{-webkit-appearance:none;-moz-appearance:none;appearance:none}.flex-row{flex-direction:row}.flex-col{flex-direction:column}.flex-wrap{flex-wrap:wrap}.items-center{align-items:center}.items-baseline{align-items:baseline}.justify-end{justify-content:flex-end}.justify-center{justify-content:center}.justify-between{justify-content:space-between}.gap-2\.5{gap:0.625rem}.gap-2{gap:0.5rem}.gap-4{gap:1rem}.gap-0\.5{gap:0.125rem}.gap-0{gap:0px}.gap-1{gap:0.25rem}.divide-y>:not([hidden])~:not([hidden]){--tw-divide-y-reverse:0;border-top-width:calc(1px * calc(1 - var(--tw-divide-y-reverse)));border-bottom-width:calc(1px * var(--tw-divide-y-reverse))}.divide-gray-200>:not([hidden])~:not([hidden]){--tw-divide-opacity:1;border-color:rgba(229, 231, 235, var(--tw-divide-opacity))}.overflow-hidden{overflow:hidden}.overflow-x-auto{overflow-x:auto}.overflow-y-auto{overflow-y:auto}.overflow-ellipsis{text-overflow:ellipsis}.whitespace-nowrap{white-space:nowrap}.whitespace-pre-wrap{white-space:pre-wrap}.break-all{word-break:break-all}.rounded{border-radius:0.25rem}.rounded-full{border-radius:9999px}.rounded-sm{border-radius:0.125rem}.rounded-b{border-bottom-right-radius:0.25rem;border-bottom-left-radius:0.25rem}.border-2{border-width:2px}.border-8{border-width:8px}.border{border-width:1px}.border-\[0\.125rem\]{border-width:0.125rem}.border-4{border-width:4px}.border-b-2{border-bottom-width:2px}.border-r-2{border-right-width:2px}.border-dashed{border-style:dashed}.border-gray-100{--tw-border-opacity:1;border-color:rgba(243, 244, 246, var(--tw-border-opacity))}.border-gray-300{--tw-border-opacity:1;border-color:rgba(209, 213, 219, var(--tw-border-opacity))}.border-green-300{--tw-border-opacity:1;border-color:rgba(110, 231, 183, var(--tw-border-opacity))}.border-gray-400{--tw-border-opacity:1;border-color:rgba(156, 163, 175, var(--tw-border-opacity))}.border-gray-200{--tw-border-opacity:1;border-color:rgba(229, 231, 235, var(--tw-border-opacity))}.border-gray-600{--tw-border-opacity:1;border-color:rgba(75, 85, 99, var(--tw-border-opacity))}.border-transparent{border-color:transparent}.border-yellow-600{--tw-border-opacity:1;border-color:rgba(217, 119, 6, var(--tw-border-opacity))}.border-red-700{--tw-border-opacity:1;border-color:rgba(185, 28, 28, var(--tw-border-opacity))}.bg-gray-100{--tw-bg-opacity:1;background-color:rgba(243, 244, 246, var(--tw-bg-opacity))}.bg-gray-50{--tw-bg-opacity:1;background-color:rgba(249, 250, 251, var(--tw-bg-opacity))}.bg-yellow-500{--tw-bg-opacity:1;background-color:rgba(245, 158, 11, var(--tw-bg-opacity))}.bg-black{--tw-bg-opacity:1;background-color:rgba(0, 0, 0, var(--tw-bg-opacity))}.bg-red-200{--tw-bg-opacity:1;background-color:rgba(254, 202, 202, var(--tw-bg-opacity))}.bg-white{--tw-bg-opacity:1;background-color:rgba(255, 255, 255, var(--tw-bg-opacity))}.bg-yellow-600{--tw-bg-opacity:1;background-color:rgba(217, 119, 6, var(--tw-bg-opacity))}.bg-transparent{background-color:transparent}.bg-gray-200{--tw-bg-opacity:1;background-color:rgba(229, 231, 235, var(--tw-bg-opacity))}.bg-opacity-50{--tw-bg-opacity:0.5}.bg-opacity-30{--tw-bg-opacity:0.3}.bg-opacity-80{--tw-bg-opacity:0.8}.bg-opacity-20{--tw-bg-opacity:0.2}.bg-none{background-image:none}.bg-gradient-to-b{background-image:linear-gradient(to bottom, var(--tw-gradient-stops))}.from-yellow-400{--tw-gradient-from:#fbbf24;--tw-gradient-stops:var(--tw-gradient-from), var(--tw-gradient-to, rgba(251, 191, 36, 0))}.to-yellow-500{--tw-gradient-to:#f59e0b}.fill-current{fill:currentColor}.object-contain{-o-object-fit:contain;object-fit:contain}.p-4{padding:1rem}.p-2{padding:0.5rem}.p-3{padding:0.75rem}.p-1\.5{padding:0.375rem}.p-1{padding:0.25rem}.p-0{padding:0px}.p-6{padding:1.5rem}.px-4{padding-left:1rem;padding-right:1rem}.py-2{padding-top:0.5rem;padding-bottom:0.5rem}.px-3{padding-left:0.75rem;padding-right:0.75rem}.px-6{padding-left:1.5rem;padding-right:1.5rem}.py-3{padding-top:0.75rem;padding-bottom:0.75rem}.px-5{padding-left:1.25rem;padding-right:1.25rem}.py-1{padding-top:0.25rem;padding-bottom:0.25rem}.px-2{padding-left:0.5rem;padding-right:0.5rem}.py-0\.5{padding-top:0.125rem;padding-bottom:0.125rem}.py-0{padding-top:0px;padding-bottom:0px}.px-0\.5{padding-left:0.125rem;padding-right:0.125rem}.px-0{padding-left:0px;padding-right:0px}.py-6{padding-top:1.5rem;padding-bottom:1.5rem}.px-1{padding-left:0.25rem;padding-right:0.25rem}.pt-4{padding-top:1rem}.pb-4{padding-bottom:1rem}.pt-8{padding-top:2rem}.pt-1{padding-top:0.25rem}.pl-4{padding-left:1rem}.text-left{text-align:left}.text-center{text-align:center}.text-right{text-align:right}.font-mono{font-family:ui-monospace, SFMono-Regular, Menlo, Monaco, Consolas, "Liberation Mono", "Courier New", monospace}.text-4xl{font-size:2.25rem;line-height:2.5rem}.text-lg{font-size:1.125rem;line-height:1.75rem}.text-xs{font-size:0.75rem;line-height:1rem}.text-2xl{font-size:1.5rem;line-height:2rem}.text-sm{font-size:0.875rem;line-height:1.25rem}.text-3xl{font-size:1.875rem;line-height:2.25rem}.text-xl{font-size:1.25rem;line-height:1.75rem}.text-base{font-size:1rem;line-height:1.5rem}.font-semibold{font-weight:600}.font-medium{font-weight:500}.font-bold{font-weight:700}.uppercase{text-transform:uppercase}.leading-10{line-height:2.5rem}.leading-8{line-height:2rem}.leading-relaxed{line-height:1.625}.tracking-wider{letter-spacing:0.05em}.text-gray-700{--tw-text-opacity:1;color:rgba(55, 65, 81, var(--tw-text-opacity))}.text-gray-400{--tw-text-opacity:1;color:rgba(156, 163, 175, var(--tw-text-opacity))}.text-white{--tw-text-opacity:1;color:rgba(255, 255, 255, var(--tw-text-opacity))}.text-green-400{--tw-text-opacity:1;color:rgba(52, 211, 153, var(--tw-text-opacity))}.text-red-500{--tw-text-opacity:1;color:rgba(239, 68, 68, var(--tw-text-opacity))}.text-gray-500{--tw-text-opacity:1;color:rgba(107, 114, 128, var(--tw-text-opacity))}.text-green-500{--tw-text-opacity:1;color:rgba(16, 185, 129, var(--tw-text-opacity))}.text-blue-500{--tw-text-opacity:1;color:rgba(59, 130, 246, var(--tw-text-opacity))}.opacity-50{opacity:0.5}.opacity-0{opacity:0}.opacity-90{opacity:0.9}.shadow-md{--tw-shadow:0 4px 6px -1px rgba(0, 0, 0, 0.1), 0 2px 4px -1px rgba(0, 0, 0, 0.06);box-shadow:var(--tw-ring-offset-shadow, 0 0 #0000), var(--tw-ring-shadow, 0 0 #0000), var(--tw-shadow)}.shadow{--tw-shadow:0 1px 3px 0 rgba(0, 0, 0, 0.1), 0 1px 2px 0 rgba(0, 0, 0, 0.06);box-shadow:var(--tw-ring-offset-shadow, 0 0 #0000), var(--tw-ring-shadow, 0 0 #0000), var(--tw-shadow)}.outline-none{outline:2px solid transparent;outline-offset:2px}.drop-shadow-lg{--tw-drop-shadow:drop-shadow(0 10px 8px rgba(0, 0, 0, 0.04)) drop-shadow(0 4px 3px rgba(0, 0, 0, 0.1));filter:var(--tw-filter)}.filter{filter:var(--tw-filter)}.transition{transition-property:background-color, border-color, color, fill, stroke, opacity, box-shadow, transform, filter, -webkit-backdrop-filter;transition-property:background-color, border-color, color, fill, stroke, opacity, box-shadow, transform, filter, backdrop-filter;transition-property:background-color, border-color, color, fill, stroke, opacity, box-shadow, transform, filter, backdrop-filter, -webkit-backdrop-filter;transition-timing-function:cubic-bezier(0.4, 0, 0.2, 1);transition-duration:150ms}.gradio-page.embedded{border-radius:0.25rem;border-width:2px;--tw-border-opacity:1;border-color:rgba(243, 244, 246, var(--tw-border-opacity));--tw-shadow:0 10px 15px -3px rgba(0, 0, 0, 0.1), 0 4px 6px -2px rgba(0, 0, 0, 0.05);box-shadow:var(--tw-ring-offset-shadow, 0 0 #0000), var(--tw-ring-shadow, 0 0 #0000), var(--tw-shadow)}.gradio-page:not(.embedded){height:100%}.gradio-page:not(.embedded) .content{flex-shrink:0;flex-grow:1;padding-left:1rem;padding-right:1rem;padding-top:1rem}.after\:absolute::after{content:"";position:absolute}.after\:inset-y-0::after{content:"";top:0px;bottom:0px}.after\:m-auto::after{content:"";margin:auto}.after\:ml-2::after{content:"";margin-left:0.5rem}.after\:h-\[1\.05rem\]::after{content:"";height:1.05rem}.after\:opacity-0::after{content:"";opacity:0}.after\:content-\[\'\25B2\'\]::after{content:'▲'}.first\:rounded-t:first-child{border-top-left-radius:0.25rem;border-top-right-radius:0.25rem}.last\:rounded-b:last-child{border-bottom-right-radius:0.25rem;border-bottom-left-radius:0.25rem}.hover\:border-gray-400:hover{--tw-border-opacity:1;border-color:rgba(156, 163, 175, var(--tw-border-opacity))}.hover\:bg-gray-100:hover{--tw-bg-opacity:1;background-color:rgba(243, 244, 246, var(--tw-bg-opacity))}.hover\:bg-yellow-400:hover{--tw-bg-opacity:1;background-color:rgba(251, 191, 36, var(--tw-bg-opacity))}.hover\:bg-yellow-500:hover{--tw-bg-opacity:1;background-color:rgba(245, 158, 11, var(--tw-bg-opacity))}.hover\:bg-opacity-100:hover{--tw-bg-opacity:1}.hover\:text-gray-500:hover{--tw-text-opacity:1;color:rgba(107, 114, 128, var(--tw-text-opacity))}.hover\:text-gray-50:hover{--tw-text-opacity:1;color:rgba(249, 250, 251, var(--tw-text-opacity))}.hover\:opacity-20:hover{opacity:0.2}.hover\:shadow-md:hover{--tw-shadow:0 4px 6px -1px rgba(0, 0, 0, 0.1), 0 2px 4px -1px rgba(0, 0, 0, 0.06);box-shadow:var(--tw-ring-offset-shadow, 0 0 #0000), var(--tw-ring-shadow, 0 0 #0000), var(--tw-shadow)}.focus\:outline-none:focus{outline:2px solid transparent;outline-offset:2px}.group:hover .group-hover\:block{display:block}.dark .dark\:border-gray-600{--tw-border-opacity:1;border-color:rgba(75, 85, 99, var(--tw-border-opacity))}.dark .dark\:border-green-500{--tw-border-opacity:1;border-color:rgba(16, 185, 129, var(--tw-border-opacity))}.dark .dark\:border-gray-500{--tw-border-opacity:1;border-color:rgba(107, 114, 128, var(--tw-border-opacity))}.dark .dark\:bg-gray-600{--tw-bg-opacity:1;background-color:rgba(75, 85, 99, var(--tw-bg-opacity))}.dark .dark\:bg-gray-700{--tw-bg-opacity:1;background-color:rgba(55, 65, 81, var(--tw-bg-opacity))}.dark .dark\:bg-red-700{--tw-bg-opacity:1;background-color:rgba(185, 28, 28, var(--tw-bg-opacity))}.dark .dark\:bg-red-600{--tw-bg-opacity:1;background-color:rgba(220, 38, 38, var(--tw-bg-opacity))}.dark .dark\:bg-gray-500{--tw-bg-opacity:1;background-color:rgba(107, 114, 128, var(--tw-bg-opacity))}.dark .dark\:bg-gray-800{--tw-bg-opacity:1;background-color:rgba(31, 41, 55, var(--tw-bg-opacity))}.dark .dark\:bg-gray-400{--tw-bg-opacity:1;background-color:rgba(156, 163, 175, var(--tw-bg-opacity))}.dark .dark\:bg-opacity-80{--tw-bg-opacity:0.8}.dark .dark\:from-red-500{--tw-gradient-from:#ef4444;--tw-gradient-stops:var(--tw-gradient-from), var(--tw-gradient-to, rgba(239, 68, 68, 0))}.dark .dark\:to-red-600{--tw-gradient-to:#dc2626}.dark .dark\:text-gray-50{--tw-text-opacity:1;color:rgba(249, 250, 251, var(--tw-text-opacity))}.dark .dark\:text-green-500{--tw-text-opacity:1;color:rgba(16, 185, 129, var(--tw-text-opacity))}.dark .dark\:text-gray-500{--tw-text-opacity:1;color:rgba(107, 114, 128, var(--tw-text-opacity))}.dark .dark\:text-red-100{--tw-text-opacity:1;color:rgba(254, 226, 226, var(--tw-text-opacity))}.dark .dark\:text-white{--tw-text-opacity:1;color:rgba(255, 255, 255, var(--tw-text-opacity))}.dark .dark\:text-gray-400{--tw-text-opacity:1;color:rgba(156, 163, 175, var(--tw-text-opacity))}.dark .dark\:drop-shadow-xl{--tw-drop-shadow:drop-shadow(0 20px 13px rgba(0, 0, 0, 0.03)) drop-shadow(0 8px 5px rgba(0, 0, 0, 0.08));filter:var(--tw-filter)}.dark .dark\:invert{--tw-invert:invert(100%);filter:var(--tw-filter)}.dark .dark\:hover\:border-gray-300:hover{--tw-border-opacity:1;border-color:rgba(209, 213, 219, var(--tw-border-opacity))}.dark .dark\:hover\:bg-gray-600:hover{--tw-bg-opacity:1;background-color:rgba(75, 85, 99, var(--tw-bg-opacity))}.dark .dark\:hover\:bg-red-600:hover{--tw-bg-opacity:1;background-color:rgba(220, 38, 38, var(--tw-bg-opacity))}.dark .dark\:hover\:bg-yellow-600:hover{--tw-bg-opacity:1;background-color:rgba(217, 119, 6, var(--tw-bg-opacity))}@media(min-width: 640px){.sm\:flex-row{flex-direction:row}}