.gradio_wrapper .slider_container {
  display: flex;
  align-items: center;
  justify-content: center;
  padding: 8px 0;
  position: relative;
}

.gradio_wrapper .slider {
  position: relative;
  width: 100%;
}

.gradio_wrapper .slider__track, .gradio_wrapper .slider__range, .gradio_wrapper .slider__left-value, .gradio_wrapper .slider__right-value {
  position: absolute;
}

.gradio_wrapper .slider__track, .gradio_wrapper .slider__range {
  border-radius: 3px;
  height: 5px;
}

.gradio_wrapper .slider__track {
  background-color: #ced4da;
  width: 100%;
  z-index: 1;
}

.gradio_wrapper .slider__range {
  background-color: pink;
  z-index: 2;
}

.gradio_wrapper .slider__left-value, .gradio_wrapper .slider__right-value {
  color: #dee2e6;
  font-size: 12px;
  margin-top: 20px;
}

.gradio_wrapper .slider__left-value {
  left: 6px;
}

.gradio_wrapper .slider__right-value {
  right: -4px;
}

/* Removing the default appearance */
.gradio_wrapper .thumb, .gradio_wrapper .thumb::-webkit-slider-thumb {
  -webkit-appearance: none;
  -webkit-tap-highlight-color: transparent;
}

.gradio_wrapper .thumb {
  pointer-events: none;
  position: absolute;
  height: 0;
  width: 100%;
  outline: none;
}

.gradio_wrapper .thumb--left {
  z-index: 3;
}

.gradio_wrapper .thumb--right {
  z-index: 4;
}

/* For Chrome browsers */
.gradio_wrapper .thumb::-webkit-slider-thumb {
  background-color: maroon;
  border: none;
  cursor: pointer;
  height: 18px;
  width: 4px;
  margin-top: 4px;
  pointer-events: all;
  position: relative;
}

/* For Firefox browsers */
.gradio_wrapper .thumb::-moz-range-thumb {
  background-color: maroon;
  border: none;
  cursor: pointer;
  height: 18px;
  width: 4px;
  margin-top: 4px;
  pointer-events: all;
  position: relative;
}

.gradio_wrapper :root {
    --jexcel-border-color:#000;
}

.gradio_wrapper .jexcel_container {
    display:inline-block;
    padding-right:2px;
    box-sizing: border-box;
    -ms-scroll-chaining: none;
        overscroll-behavior: contain;
    outline: none;
}

.gradio_wrapper .jexcel_container.fullscreen {
    position:fixed;
    top:0px;
    left:0px;
    width:100%;
    height:100%;
    z-index:21;
}

.gradio_wrapper .jexcel_container.fullscreen .jexcel_content {
    overflow:auto;
    width:100%;
    height:100%;
    background-color:#ffffff;
}

.gradio_wrapper .jexcel_container.with-toolbar .jexcel > thead > tr > td {
    top: 0;
}

.gradio_wrapper .jexcel_container.fullscreen.with-toolbar {
    height: calc(100% - 46px);
}

.gradio_wrapper .jexcel_content {
    display:inline-block;
    box-sizing: border-box;
    padding-right:3px;
    padding-bottom:3px;
    position:relative;
    scrollbar-width: thin;
    scrollbar-color: #666 transparent;
}

@supports (-moz-appearance:none) {
    .gradio_wrapper .jexcel_content { padding-right:10px; } 
}

.gradio_wrapper .jexcel_content::-webkit-scrollbar {
    width: 8px;
    height: 8px;
}

.gradio_wrapper .jexcel_content::-webkit-scrollbar-track {
    background: #eee;
}
 
.gradio_wrapper .jexcel_content::-webkit-scrollbar-thumb {
  background: #666; 
}

.gradio_wrapper .jexcel {
    border-collapse: separate;
    table-layout: fixed;
    white-space:  nowrap;
    empty-cells: show;
    border: 0px;
    background-color: #fff;
    width: 0;

    border-top: 1px solid transparent;
    border-left: 1px solid transparent;
    border-right: 1px solid #ccc;
    border-bottom: 1px solid #ccc;
}

.gradio_wrapper .jexcel > thead > tr > td
{
    border-top: 1px solid #ccc;
    border-left: 1px solid #ccc;
    border-right: 1px solid transparent;
    border-bottom: 1px solid transparent;
    background-color: #f3f3f3;
    padding: 2px;
    cursor: pointer;
    box-sizing: border-box;
    overflow: hidden;
    position: -webkit-sticky;
    position: sticky;
    top: 0;
    z-index:2;
}

.gradio_wrapper .jexcel_container.with-toolbar .jexcel > thead > tr > td
{
    top:42px;
}

.gradio_wrapper .jexcel > thead > tr > td.dragging
{
    background-color:#fff;
    opacity:0.5;
}

.gradio_wrapper .jexcel > thead > tr > td.selected
{
    background-color:#dcdcdc;
}

.gradio_wrapper .jexcel > thead > tr > td.arrow-up
{
    background-repeat:no-repeat;
    background-position:center right 5px;
    background-image: url("data:image/svg+xml,%0A%3Csvg xmlns='http://www.w3.org/2000/svg' width='24' height='24' viewBox='0 0 24 24'%3E%3Cpath fill='none' d='M0 0h24v24H0V0z'/%3E%3Cpath d='M7 14l5-5 5 5H7z' fill='gray'/%3E%3C/svg%3E");
    text-decoration:underline;
}

.gradio_wrapper .jexcel > thead > tr > td.arrow-down
{
    background-repeat:no-repeat;
    background-position:center right 5px;
    background-image: url("data:image/svg+xml,%0A%3Csvg xmlns='http://www.w3.org/2000/svg' width='24' height='24' viewBox='0 0 24 24'%3E%3Cpath fill='none' d='M0 0h24v24H0V0z'/%3E%3Cpath d='M7 10l5 5 5-5H7z' fill='gray'/%3E%3C/svg%3E");
    text-decoration:underline;
}

.gradio_wrapper .jexcel > tbody > tr > td:first-child
{
    position:relative;
    background-color:#f3f3f3;
    text-align:center;
}

.gradio_wrapper .jexcel > tbody.resizable > tr > td:first-child::before
{
    content:'\00a0';
    width:100%;
    height:3px;
    position:absolute;
    bottom:0px;
    left:0px;
    cursor:row-resize;
}

.gradio_wrapper .jexcel > tbody.draggable > tr > td:first-child::after
{
    content:'\00a0';
    width:3px;
    height:100%;
    position:absolute;
    top:0px;
    right:0px;
    cursor:move;
}

.gradio_wrapper .jexcel > tbody > tr.dragging > td
{
    background-color:#eee;
    opacity:0.5;
}

.gradio_wrapper .jexcel > tbody > tr > td
{
    border-top:1px solid #ccc;
    border-left:1px solid #ccc;
    border-right:1px solid transparent;
    border-bottom:1px solid transparent;
    padding:4px;
    white-space: nowrap;
    box-sizing: border-box;
    line-height:1em;
}

.gradio_wrapper .jexcel_overflow > tbody > tr > td {
    overflow: hidden;
}

.gradio_wrapper .jexcel > tbody > tr > td:last-child
{
    overflow:hidden;
}

.gradio_wrapper .jexcel > tbody > tr > td > img
{
    display:inline-block;
    max-width:100px;
}

.gradio_wrapper .jexcel > tbody > tr > td.readonly
{
    color:rgba(0,0,0,0.3)
}
.gradio_wrapper .jexcel > tbody > tr.selected > td:first-child
{
    background-color:#dcdcdc;
}
.gradio_wrapper .jexcel > tbody > tr > td > select, .gradio_wrapper .jexcel > tbody > tr > td > input, .gradio_wrapper .jexcel > tbody > tr > td > textarea
{
    border:0px;
    border-radius:0px;
    outline:0px;
    width:100%;
    margin:0px;
    padding:0px;
    padding-right:2px;
    background-color:transparent;
    box-sizing: border-box;
}

.gradio_wrapper .jexcel > tbody > tr > td > textarea
{
    resize: none;
    padding-top:6px !important;
}

.gradio_wrapper .jexcel > tbody > tr > td > input[type=checkbox]
{
    width:12px;
    margin-top:2px;
}
.gradio_wrapper .jexcel > tbody > tr > td > input[type=radio]
{
    width:12px;
    margin-top:2px;
}

.gradio_wrapper .jexcel > tbody > tr > td > select
{
    -webkit-appearance: none;
    appearance: none;
    background-repeat: no-repeat;
    background-position-x: 100%;
    background-position-y: 40%;
    background-image: url(data:image/svg+xml;base64,PHN2ZyBmaWxsPSdibGFjaycgaGVpZ2h0PScyNCcgdmlld0JveD0nMCAwIDI0IDI0JyB3aWR0aD0nMjQnIHhtbG5zPSdodHRwOi8vd3d3LnczLm9yZy8yMDAwL3N2Zyc+PHBhdGggZD0nTTcgMTBsNSA1IDUtNXonLz48cGF0aCBkPSdNMCAwaDI0djI0SDB6JyBmaWxsPSdub25lJy8+PC9zdmc+);
}

.gradio_wrapper .jexcel > tbody > tr > td.jexcel_dropdown
{
    background-repeat: no-repeat;
    background-position:top 50% right 5px;
    background-image: url("data:image/svg+xml,%0A%3Csvg xmlns='http://www.w3.org/2000/svg' width='24' height='24' viewBox='0 0 24 24'%3E%3Cpath fill='none' d='M0 0h24v24H0V0z'/%3E%3Cpath d='M7 10l5 5 5-5H7z' fill='lightgray'/%3E%3C/svg%3E");
    text-overflow: ellipsis;
    overflow-x:hidden;
}

.gradio_wrapper .jexcel > tbody > tr > td.jexcel_dropdown.jexcel_comments
{
    background:url("data:image/svg+xml,%0A%3Csvg xmlns='http://www.w3.org/2000/svg' width='24' height='24' viewBox='0 0 24 24'%3E%3Cpath fill='none' d='M0 0h24v24H0V0z'/%3E%3Cpath d='M7 10l5 5 5-5H7z' fill='lightgray'/%3E%3C/svg%3E") top 50% right 5px no-repeat, url('data:image/png;base64,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') top right no-repeat;
}

.gradio_wrapper .jexcel > tbody > tr > td > .color
{
    width:90%;
    height:10px;
    margin:auto;
}

.gradio_wrapper .jexcel > tbody > tr > td > a {
    text-decoration: underline;
}

.gradio_wrapper .jexcel > tbody > tr > td.highlight > a {
    color: blue;
    cursor: pointer;
}

.gradio_wrapper .jexcel > tfoot > tr > td
{
    border-top: 1px solid #ccc;
    border-left: 1px solid #ccc;
    border-right: 1px solid transparent;
    border-bottom: 1px solid transparent;
    background-color: #f3f3f3;
    padding: 2px;
    cursor: pointer;
    box-sizing: border-box;
    overflow: hidden;
}

.gradio_wrapper .jexcel .highlight {
    background-color:rgba(0,0,0,0.05);
}

.gradio_wrapper .jexcel .highlight-top {
    border-top:1px solid #000; /* var(--jexcel-border-color);*/
    box-shadow: 0px -1px #ccc;
}

.gradio_wrapper .jexcel .highlight-left {
    border-left:1px solid #000; /* var(--jexcel-border-color);*/
    box-shadow: -1px 0px #ccc;
}

.gradio_wrapper .jexcel .highlight-right {
    border-right:1px solid #000; /* var(--jexcel-border-color);*/
}

.gradio_wrapper .jexcel .highlight-bottom {
    border-bottom:1px solid #000; /* var(--jexcel-border-color);*/
}

.gradio_wrapper .jexcel .highlight-top.highlight-left {
    box-shadow: -1px -1px #ccc;
    -webkit-box-shadow: -1px -1px #ccc;
    -moz-box-shadow: -1px -1px #ccc;
}

.gradio_wrapper .jexcel .highlight-selected
{
    background-color:rgba(0,0,0,0.0);
}
.gradio_wrapper .jexcel .selection
{
    background-color:rgba(0,0,0,0.05);
}
.gradio_wrapper .jexcel .selection-left
{
    border-left:1px dotted #000;
}
.gradio_wrapper .jexcel .selection-right
{
    border-right:1px dotted #000;
}
.gradio_wrapper .jexcel .selection-top
{
    border-top:1px dotted #000;
}
.gradio_wrapper .jexcel .selection-bottom
{
    border-bottom:1px dotted #000;
}
.gradio_wrapper .jexcel_corner
{
    position:absolute;
    background-color: rgb(0, 0, 0);
    height: 1px;
    width: 1px;
    border: 1px solid rgb(255, 255, 255);
    top:-2000px;
    left:-2000px;
    cursor:crosshair;
    box-sizing: content-box;
    box-sizing: initial;
    z-index:30;
    padding: 2px;
}

.gradio_wrapper .jexcel .editor
{
    outline:0px solid transparent;
    overflow:visible;
    white-space: nowrap;
    text-align:left;
    padding:0px;
    box-sizing: border-box;
    overflow:visible !important;
}

.gradio_wrapper .jexcel .editor > input
{
    padding-left:4px;
}

.gradio_wrapper .jexcel .editor .jupload
{
    position:fixed;
    top:100%;
    z-index:40;
    -webkit-user-select:none;
        -ms-user-select:none;
            user-select:none;
    -webkit-font-smoothing: antialiased;
    font-size: .875rem;
    letter-spacing: .2px;
    border-radius: 4px;
    box-shadow: 0 8px 10px 1px rgba(0,0,0,0.14), 0 3px 14px 2px rgba(0,0,0,0.12), 0 5px 5px -3px rgba(0,0,0,0.2);
    padding:10px;
    background-color:#fff;
    width:300px;
    min-height:225px;
    margin-top:2px;
}

.gradio_wrapper .jexcel .editor .jupload img
{
    width:100%;
    height:auto;
}

.gradio_wrapper .jexcel .editor .jexcel_richtext
{
    position:fixed;
    top:100%;
    z-index:40;
    -webkit-user-select:none;
        -ms-user-select:none;
            user-select:none;
    -webkit-font-smoothing: antialiased;
    font-size: .875rem;
    letter-spacing: .2px;
    box-shadow: 0 8px 10px 1px rgba(0,0,0,0.14), 0 3px 14px 2px rgba(0,0,0,0.12), 0 5px 5px -3px rgba(0,0,0,0.2);
    padding:10px;
    background-color:#fff;
    min-width:280px;
    max-width:310px;
    margin-top:2px;
    text-align:left;
}

.gradio_wrapper .jexcel .editor .jclose:after
{
    position:absolute;
    top:0;
    right:0;
    margin:10px;
    content:'close';
    font-family:'Material icons';
    font-size:24px;
    width:24px;
    height:24px;
    line-height:24px;
    cursor:pointer;
    text-shadow: 0px 0px 5px #fff;
}

.gradio_wrapper .jexcel, .gradio_wrapper .jexcel td, .gradio_wrapper .jexcel_corner
{
  -webkit-touch-callout: none;
  -webkit-user-select: none;
  -ms-user-select: none;
  user-select: none;
  -webkit-user-drag: none;
  -khtml-user-drag: none;
  -moz-user-drag: none;
  -o-user-drag: none;
  user-drag: none;
}

.gradio_wrapper .jexcel_textarea
{
    position:absolute;
    top:-999px;
    left:-999px;
    width:1px;
    height:1px;
}
.gradio_wrapper .jexcel .dragline
{
    position:absolute;
}
.gradio_wrapper .jexcel .dragline div
{
    position:relative;
    top:-6px;
    height:5px;
    width:22px;
}
.gradio_wrapper .jexcel .dragline div:hover
{
    cursor:move;
}

.gradio_wrapper .jexcel .onDrag
{
    background-color:rgba(0,0,0,0.6);
}

.gradio_wrapper .jexcel .error
{
    border:1px solid red;
}

.gradio_wrapper .jexcel thead td.resizing
{
    border-right-style:dotted !important;
    border-right-color:red !important;
}

.gradio_wrapper .jexcel tbody tr.resizing > td
{
    border-bottom-style:dotted !important;
    border-bottom-color:red !important;
}

.gradio_wrapper .jexcel tbody td.resizing
{
    border-right-style:dotted !important;
    border-right-color:red !important;
}

.gradio_wrapper .jexcel .jdropdown-header
{
    border:0px !important;
    outline:none !important;
    width:100% !important;
    height:100% !important;
    padding:0px !important;
    padding-left:8px !important;
}

.gradio_wrapper .jexcel .jdropdown-container
{
    margin-top:1px;
}

.gradio_wrapper .jexcel .jdropdown-container-header {
    padding: 0px;
    margin: 0px;
    height: inherit;
}

.gradio_wrapper .jexcel .jdropdown-picker
{
    border:0px !important;
    padding:0px !important;
    width:inherit;
    height:inherit;
}

.gradio_wrapper .jexcel .jexcel_comments
{
    background:url('data:image/png;base64,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');
    background-repeat: no-repeat;
    background-position: top right;
}

.gradio_wrapper .jexcel .sp-replacer
{
    margin: 2px;
    border:0px;
}

.gradio_wrapper .jexcel > thead > tr.jexcel_filter > td > input
{
    border:0px;
    width:100%;
    outline:none;
}

.gradio_wrapper .jexcel_about {
    float: right;
    font-size: 0.7em;
    padding: 2px;
    text-transform: uppercase;
    letter-spacing: 1px;
    display: none;
}
.gradio_wrapper .jexcel_about a {
    color: #ccc;
    text-decoration: none;
}

.gradio_wrapper .jexcel_about img {
    display: none;
}

.gradio_wrapper .jexcel_filter
{
    display:flex;
    justify-content:space-between;
    margin-bottom:4px;
}

.gradio_wrapper .jexcel_filter > div
{
    padding:8px;
    align-items:center;
}

.gradio_wrapper .jexcel_pagination
{
    display:flex;
    justify-content:space-between;
    align-items:center;
}

.gradio_wrapper .jexcel_pagination > div
{
    display:flex;
    padding:10px;
}

.gradio_wrapper .jexcel_pagination > div:last-child
{
    padding-right:10px;
    padding-top:10px;
}

.gradio_wrapper .jexcel_pagination > div > div
{
    text-align:center;
    width:36px;
    height:36px;
    line-height:34px;
    border:1px solid #ccc;
    box-sizing: border-box;
    margin-left:2px;
    cursor:pointer;
}

.gradio_wrapper .jexcel_page
{
    font-size:0.8em;
}

.gradio_wrapper .jexcel_page_selected
{
    font-weight:bold;
    background-color:#f3f3f3;
}

.gradio_wrapper .jexcel_toolbar
{
    display:flex;
    background-color:#f3f3f3;
    border:1px solid #ccc;
    padding:4px;
    margin:0px 2px 4px 1px;
    position:-webkit-sticky;
    position:sticky;
    top:0px;
    z-index:21;
}

.gradio_wrapper .jexcel_toolbar:empty
{
    display:none;
}

.gradio_wrapper .jexcel_toolbar i.jexcel_toolbar_item 
{
    width:24px;
    height:24px;
    padding:4px;
    cursor:pointer;
    display:inline-block;
}

.gradio_wrapper .jexcel_toolbar i.jexcel_toolbar_item:hover 
{
    background-color:#ddd;
}

.gradio_wrapper .jexcel_toolbar select.jexcel_toolbar_item 
{
    margin-left:2px;
    margin-right:2px;
    display:inline-block;
    border:0px;
    background-color:transparent;
    padding-right:10px;
}

.gradio_wrapper .jexcel .dragging-left
{
    background-repeat: no-repeat;
    background-position:top 50% left 0px;
    background-image: url("data:image/svg+xml,%3Csvg xmlns='http://www.w3.org/2000/svg' width='24' height='24' viewBox='0 0 24 24'%3E%3Cpath d='M14 7l-5 5 5 5V7z'/%3E%3Cpath fill='none' d='M24 0v24H0V0h24z'/%3E%3C/svg%3E");
}

.gradio_wrapper .jexcel .dragging-right
{
    background-repeat: no-repeat;
    background-position:top 50% right 0px;
    background-image: url("data:image/svg+xml,%3Csvg xmlns='http://www.w3.org/2000/svg' width='24' height='24' viewBox='0 0 24 24'%3E%3Cpath d='M10 17l5-5-5-5v10z'/%3E%3Cpath fill='none' d='M0 24V0h24v24H0z'/%3E%3C/svg%3E");
}

.gradio_wrapper .jexcel_tabs .jexcel_tab
{
    display:none;
}

.gradio_wrapper .jexcel_tabs .jexcel_tab_link
{
    display:inline-block;
    padding:10px;
    padding-left:20px;
    padding-right:20px;
    margin-right:5px;
    margin-bottom:5px;
    background-color:#f3f3f3;
    cursor:pointer;
}

.gradio_wrapper .jexcel_tabs .jexcel_tab_link.selected
{
    background-color:#ddd;
}

.gradio_wrapper .jexcel_hidden_index > tbody > tr > td:first-child, .gradio_wrapper .jexcel_hidden_index > thead > tr > td:first-child, .gradio_wrapper .jexcel_hidden_index > tfoot > tr > td:first-child, .gradio_wrapper .jexcel_hidden_index > colgroup > col:first-child
{
    display:none;
}



.gradio_wrapper .jexcel .jrating {
    display: inline-flex;
}
.gradio_wrapper .jexcel .jrating > div {
    zoom: 0.55;
}

.gradio_wrapper .jexcel .copying-top {
    border-top:1px dashed #000;
}

.gradio_wrapper .jexcel .copying-left {
    border-left:1px dashed #000;
}

.gradio_wrapper .jexcel .copying-right {
    border-right:1px dashed #000;
}

.gradio_wrapper .jexcel .copying-bottom {
    border-bottom:1px dashed #000;
}

.gradio_wrapper .jexcel .jexcel_column_filter {
    background-repeat: no-repeat;
    background-position: top 50% right 5px;
    background-image: url("data:image/svg+xml,%3Csvg xmlns='http://www.w3.org/2000/svg' viewBox='0 0 24 24' fill='gray' width='18px' height='18px'%3E%3Cpath d='M10 18h4v-2h-4v2zM3 6v2h18V6H3zm3 7h12v-2H6v2z'/%3E%3Cpath d='M0 0h24v24H0z' fill='none'/%3E%3C/svg%3E");
    text-overflow: ellipsis;
    overflow: hidden;
    padding: 0px;
    padding-left: 6px;
    padding-right: 20px;
}

.gradio_wrapper .jexcel thead .jexcel_freezed, .gradio_wrapper .jexcel tfoot .jexcel_freezed {
    left: 0px;
    z-index: 3 !important;
    box-shadow: 2px 0px 2px 0.2px #ccc !important;
    -webkit-box-shadow: 2px 0px 2px 0.2px #ccc !important;
    -moz-box-shadow: 2px 0px 2px 0.2px #ccc !important;
}

.gradio_wrapper .jexcel tbody .jexcel_freezed {
    position: relative;
    background-color: #fff;
    box-shadow: 1px 1px 1px 1px #ccc !important;
    -webkit-box-shadow: 2px 4px 4px 0.1px #ccc !important;
    -moz-box-shadow: 2px 4px 4px 0.1px #ccc !important;
}

.gradio_wrapper :root {
    --jexcel-border-color:#000;
}

.gradio_wrapper .jexcel_container {
    display:inline-block;
    padding-right:2px;
    box-sizing: border-box;
    -ms-scroll-chaining: none;
        overscroll-behavior: contain;
    outline: none;
}

.gradio_wrapper .jexcel_container.fullscreen {
    position:fixed;
    top:0px;
    left:0px;
    width:100%;
    height:100%;
    z-index:21;
}

.gradio_wrapper .jexcel_container.fullscreen .jexcel_content {
    overflow:auto;
    width:100%;
    height:100%;
    background-color:#ffffff;
}

.gradio_wrapper .jexcel_container.with-toolbar .jexcel > thead > tr > td {
    top: 0;
}

.gradio_wrapper .jexcel_container.fullscreen.with-toolbar {
    height: calc(100% - 46px);
}

.gradio_wrapper .jexcel_content {
    display:inline-block;
    box-sizing: border-box;
    padding-right:3px;
    padding-bottom:3px;
    position:relative;
    scrollbar-width: thin;
    scrollbar-color: #666 transparent;
}

@supports (-moz-appearance:none) {
    .gradio_wrapper .jexcel_content { padding-right:10px; } 
}

.gradio_wrapper .jexcel_content::-webkit-scrollbar {
    width: 8px;
    height: 8px;
}

.gradio_wrapper .jexcel_content::-webkit-scrollbar-track {
    background: #eee;
}
 
.gradio_wrapper .jexcel_content::-webkit-scrollbar-thumb {
  background: #666; 
}

.gradio_wrapper .jexcel {
    border-collapse: separate;
    table-layout: fixed;
    white-space:  nowrap;
    empty-cells: show;
    border: 0px;
    background-color: #fff;
    width: 0;

    border-top: 1px solid transparent;
    border-left: 1px solid transparent;
    border-right: 1px solid #ccc;
    border-bottom: 1px solid #ccc;
}

.gradio_wrapper .jexcel > thead > tr > td
{
    border-top: 1px solid #ccc;
    border-left: 1px solid #ccc;
    border-right: 1px solid transparent;
    border-bottom: 1px solid transparent;
    background-color: #f3f3f3;
    padding: 2px;
    cursor: pointer;
    box-sizing: border-box;
    overflow: hidden;
    position: -webkit-sticky;
    position: sticky;
    top: 0;
    z-index:2;
}

.gradio_wrapper .jexcel_container.with-toolbar .jexcel > thead > tr > td
{
    top:42px;
}

.gradio_wrapper .jexcel > thead > tr > td.dragging
{
    background-color:#fff;
    opacity:0.5;
}

.gradio_wrapper .jexcel > thead > tr > td.selected
{
    background-color:#dcdcdc;
}

.gradio_wrapper .jexcel > thead > tr > td.arrow-up
{
    background-repeat:no-repeat;
    background-position:center right 5px;
    background-image: url("data:image/svg+xml,%0A%3Csvg xmlns='http://www.w3.org/2000/svg' width='24' height='24' viewBox='0 0 24 24'%3E%3Cpath fill='none' d='M0 0h24v24H0V0z'/%3E%3Cpath d='M7 14l5-5 5 5H7z' fill='gray'/%3E%3C/svg%3E");
    text-decoration:underline;
}

.gradio_wrapper .jexcel > thead > tr > td.arrow-down
{
    background-repeat:no-repeat;
    background-position:center right 5px;
    background-image: url("data:image/svg+xml,%0A%3Csvg xmlns='http://www.w3.org/2000/svg' width='24' height='24' viewBox='0 0 24 24'%3E%3Cpath fill='none' d='M0 0h24v24H0V0z'/%3E%3Cpath d='M7 10l5 5 5-5H7z' fill='gray'/%3E%3C/svg%3E");
    text-decoration:underline;
}

.gradio_wrapper .jexcel > tbody > tr > td:first-child
{
    position:relative;
    background-color:#f3f3f3;
    text-align:center;
}

.gradio_wrapper .jexcel > tbody.resizable > tr > td:first-child::before
{
    content:'\00a0';
    width:100%;
    height:3px;
    position:absolute;
    bottom:0px;
    left:0px;
    cursor:row-resize;
}

.gradio_wrapper .jexcel > tbody.draggable > tr > td:first-child::after
{
    content:'\00a0';
    width:3px;
    height:100%;
    position:absolute;
    top:0px;
    right:0px;
    cursor:move;
}

.gradio_wrapper .jexcel > tbody > tr.dragging > td
{
    background-color:#eee;
    opacity:0.5;
}

.gradio_wrapper .jexcel > tbody > tr > td
{
    border-top:1px solid #ccc;
    border-left:1px solid #ccc;
    border-right:1px solid transparent;
    border-bottom:1px solid transparent;
    padding:4px;
    white-space: nowrap;
    box-sizing: border-box;
    line-height:1em;
}

.gradio_wrapper .jexcel_overflow > tbody > tr > td {
    overflow: hidden;
}

.gradio_wrapper .jexcel > tbody > tr > td:last-child
{
    overflow:hidden;
}

.gradio_wrapper .jexcel > tbody > tr > td > img
{
    display:inline-block;
    max-width:100px;
}

.gradio_wrapper .jexcel > tbody > tr > td.readonly
{
    color:rgba(0,0,0,0.3)
}
.gradio_wrapper .jexcel > tbody > tr.selected > td:first-child
{
    background-color:#dcdcdc;
}
.gradio_wrapper .jexcel > tbody > tr > td > select, .gradio_wrapper .jexcel > tbody > tr > td > input, .gradio_wrapper .jexcel > tbody > tr > td > textarea
{
    border:0px;
    border-radius:0px;
    outline:0px;
    width:100%;
    margin:0px;
    padding:0px;
    padding-right:2px;
    background-color:transparent;
    box-sizing: border-box;
}

.gradio_wrapper .jexcel > tbody > tr > td > textarea
{
    resize: none;
    padding-top:6px !important;
}

.gradio_wrapper .jexcel > tbody > tr > td > input[type=checkbox]
{
    width:12px;
    margin-top:2px;
}
.gradio_wrapper .jexcel > tbody > tr > td > input[type=radio]
{
    width:12px;
    margin-top:2px;
}

.gradio_wrapper .jexcel > tbody > tr > td > select
{
    -webkit-appearance: none;
    appearance: none;
    background-repeat: no-repeat;
    background-position-x: 100%;
    background-position-y: 40%;
    background-image: url(data:image/svg+xml;base64,PHN2ZyBmaWxsPSdibGFjaycgaGVpZ2h0PScyNCcgdmlld0JveD0nMCAwIDI0IDI0JyB3aWR0aD0nMjQnIHhtbG5zPSdodHRwOi8vd3d3LnczLm9yZy8yMDAwL3N2Zyc+PHBhdGggZD0nTTcgMTBsNSA1IDUtNXonLz48cGF0aCBkPSdNMCAwaDI0djI0SDB6JyBmaWxsPSdub25lJy8+PC9zdmc+);
}

.gradio_wrapper .jexcel > tbody > tr > td.jexcel_dropdown
{
    background-repeat: no-repeat;
    background-position:top 50% right 5px;
    background-image: url("data:image/svg+xml,%0A%3Csvg xmlns='http://www.w3.org/2000/svg' width='24' height='24' viewBox='0 0 24 24'%3E%3Cpath fill='none' d='M0 0h24v24H0V0z'/%3E%3Cpath d='M7 10l5 5 5-5H7z' fill='lightgray'/%3E%3C/svg%3E");
    text-overflow: ellipsis;
    overflow-x:hidden;
}

.gradio_wrapper .jexcel > tbody > tr > td.jexcel_dropdown.jexcel_comments
{
    background:url("data:image/svg+xml,%0A%3Csvg xmlns='http://www.w3.org/2000/svg' width='24' height='24' viewBox='0 0 24 24'%3E%3Cpath fill='none' d='M0 0h24v24H0V0z'/%3E%3Cpath d='M7 10l5 5 5-5H7z' fill='lightgray'/%3E%3C/svg%3E") top 50% right 5px no-repeat, url('data:image/png;base64,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') top right no-repeat;
}

.gradio_wrapper .jexcel > tbody > tr > td > .color
{
    width:90%;
    height:10px;
    margin:auto;
}

.gradio_wrapper .jexcel > tbody > tr > td > a {
    text-decoration: underline;
}

.gradio_wrapper .jexcel > tbody > tr > td.highlight > a {
    color: blue;
    cursor: pointer;
}

.gradio_wrapper .jexcel > tfoot > tr > td
{
    border-top: 1px solid #ccc;
    border-left: 1px solid #ccc;
    border-right: 1px solid transparent;
    border-bottom: 1px solid transparent;
    background-color: #f3f3f3;
    padding: 2px;
    cursor: pointer;
    box-sizing: border-box;
    overflow: hidden;
}

.gradio_wrapper .jexcel .highlight {
    background-color:rgba(0,0,0,0.05);
}

.gradio_wrapper .jexcel .highlight-top {
    border-top:1px solid #000; /* var(--jexcel-border-color);*/
    box-shadow: 0px -1px #ccc;
}

.gradio_wrapper .jexcel .highlight-left {
    border-left:1px solid #000; /* var(--jexcel-border-color);*/
    box-shadow: -1px 0px #ccc;
}

.gradio_wrapper .jexcel .highlight-right {
    border-right:1px solid #000; /* var(--jexcel-border-color);*/
}

.gradio_wrapper .jexcel .highlight-bottom {
    border-bottom:1px solid #000; /* var(--jexcel-border-color);*/
}

.gradio_wrapper .jexcel .highlight-top.highlight-left {
    box-shadow: -1px -1px #ccc;
    -webkit-box-shadow: -1px -1px #ccc;
    -moz-box-shadow: -1px -1px #ccc;
}

.gradio_wrapper .jexcel .highlight-selected
{
    background-color:rgba(0,0,0,0.0);
}
.gradio_wrapper .jexcel .selection
{
    background-color:rgba(0,0,0,0.05);
}
.gradio_wrapper .jexcel .selection-left
{
    border-left:1px dotted #000;
}
.gradio_wrapper .jexcel .selection-right
{
    border-right:1px dotted #000;
}
.gradio_wrapper .jexcel .selection-top
{
    border-top:1px dotted #000;
}
.gradio_wrapper .jexcel .selection-bottom
{
    border-bottom:1px dotted #000;
}
.gradio_wrapper .jexcel_corner
{
    position:absolute;
    background-color: rgb(0, 0, 0);
    height: 1px;
    width: 1px;
    border: 1px solid rgb(255, 255, 255);
    top:-2000px;
    left:-2000px;
    cursor:crosshair;
    box-sizing: content-box;
    box-sizing: initial;
    z-index:30;
    padding: 2px;
}

.gradio_wrapper .jexcel .editor
{
    outline:0px solid transparent;
    overflow:visible;
    white-space: nowrap;
    text-align:left;
    padding:0px;
    box-sizing: border-box;
    overflow:visible !important;
}

.gradio_wrapper .jexcel .editor > input
{
    padding-left:4px;
}

.gradio_wrapper .jexcel .editor .jupload
{
    position:fixed;
    top:100%;
    z-index:40;
    -webkit-user-select:none;
        -ms-user-select:none;
            user-select:none;
    -webkit-font-smoothing: antialiased;
    font-size: .875rem;
    letter-spacing: .2px;
    border-radius: 4px;
    box-shadow: 0 8px 10px 1px rgba(0,0,0,0.14), 0 3px 14px 2px rgba(0,0,0,0.12), 0 5px 5px -3px rgba(0,0,0,0.2);
    padding:10px;
    background-color:#fff;
    width:300px;
    min-height:225px;
    margin-top:2px;
}

.gradio_wrapper .jexcel .editor .jupload img
{
    width:100%;
    height:auto;
}

.gradio_wrapper .jexcel .editor .jexcel_richtext
{
    position:fixed;
    top:100%;
    z-index:40;
    -webkit-user-select:none;
        -ms-user-select:none;
            user-select:none;
    -webkit-font-smoothing: antialiased;
    font-size: .875rem;
    letter-spacing: .2px;
    box-shadow: 0 8px 10px 1px rgba(0,0,0,0.14), 0 3px 14px 2px rgba(0,0,0,0.12), 0 5px 5px -3px rgba(0,0,0,0.2);
    padding:10px;
    background-color:#fff;
    min-width:280px;
    max-width:310px;
    margin-top:2px;
    text-align:left;
}

.gradio_wrapper .jexcel .editor .jclose:after
{
    position:absolute;
    top:0;
    right:0;
    margin:10px;
    content:'close';
    font-family:'Material icons';
    font-size:24px;
    width:24px;
    height:24px;
    line-height:24px;
    cursor:pointer;
    text-shadow: 0px 0px 5px #fff;
}

.gradio_wrapper .jexcel, .gradio_wrapper .jexcel td, .gradio_wrapper .jexcel_corner
{
  -webkit-touch-callout: none;
  -webkit-user-select: none;
  -ms-user-select: none;
  user-select: none;
  -webkit-user-drag: none;
  -khtml-user-drag: none;
  -moz-user-drag: none;
  -o-user-drag: none;
  user-drag: none;
}

.gradio_wrapper .jexcel_textarea
{
    position:absolute;
    top:-999px;
    left:-999px;
    width:1px;
    height:1px;
}
.gradio_wrapper .jexcel .dragline
{
    position:absolute;
}
.gradio_wrapper .jexcel .dragline div
{
    position:relative;
    top:-6px;
    height:5px;
    width:22px;
}
.gradio_wrapper .jexcel .dragline div:hover
{
    cursor:move;
}

.gradio_wrapper .jexcel .onDrag
{
    background-color:rgba(0,0,0,0.6);
}

.gradio_wrapper .jexcel .error
{
    border:1px solid red;
}

.gradio_wrapper .jexcel thead td.resizing
{
    border-right-style:dotted !important;
    border-right-color:red !important;
}

.gradio_wrapper .jexcel tbody tr.resizing > td
{
    border-bottom-style:dotted !important;
    border-bottom-color:red !important;
}

.gradio_wrapper .jexcel tbody td.resizing
{
    border-right-style:dotted !important;
    border-right-color:red !important;
}

.gradio_wrapper .jexcel .jdropdown-header
{
    border:0px !important;
    outline:none !important;
    width:100% !important;
    height:100% !important;
    padding:0px !important;
    padding-left:8px !important;
}

.gradio_wrapper .jexcel .jdropdown-container
{
    margin-top:1px;
}

.gradio_wrapper .jexcel .jdropdown-container-header {
    padding: 0px;
    margin: 0px;
    height: inherit;
}

.gradio_wrapper .jexcel .jdropdown-picker
{
    border:0px !important;
    padding:0px !important;
    width:inherit;
    height:inherit;
}

.gradio_wrapper .jexcel .jexcel_comments
{
    background:url('data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAAAgAAAAICAYAAADED76LAAAACXBIWXMAAAsTAAALEwEAmpwYAAAFuGlUWHRYTUw6Y29tLmFkb2JlLnhtcAAAAAAAPD94cGFja2V0IGJlZ2luPSLvu78iIGlkPSJXNU0wTXBDZWhpSHpyZVN6TlRjemtjOWQiPz4gPHg6eG1wbWV0YSB4bWxuczp4PSJhZG9iZTpuczptZXRhLyIgeDp4bXB0az0iQWRvYmUgWE1QIENvcmUgNS42LWMxNDUgNzkuMTYzNDk5LCAyMDE4LzA4LzEzLTE2OjQwOjIyICAgICAgICAiPiA8cmRmOlJERiB4bWxuczpyZGY9Imh0dHA6Ly93d3cudzMub3JnLzE5OTkvMDIvMjItcmRmLXN5bnRheC1ucyMiPiA8cmRmOkRlc2NyaXB0aW9uIHJkZjphYm91dD0iIiB4bWxuczp4bXA9Imh0dHA6Ly9ucy5hZG9iZS5jb20veGFwLzEuMC8iIHhtbG5zOnhtcE1NPSJodHRwOi8vbnMuYWRvYmUuY29tL3hhcC8xLjAvbW0vIiB4bWxuczpzdEV2dD0iaHR0cDovL25zLmFkb2JlLmNvbS94YXAvMS4wL3NUeXBlL1Jlc291cmNlRXZlbnQjIiB4bWxuczpkYz0iaHR0cDovL3B1cmwub3JnL2RjL2VsZW1lbnRzLzEuMS8iIHhtbG5zOnBob3Rvc2hvcD0iaHR0cDovL25zLmFkb2JlLmNvbS9waG90b3Nob3AvMS4wLyIgeG1wOkNyZWF0b3JUb29sPSJBZG9iZSBQaG90b3Nob3AgQ0MgMjAxOSAoV2luZG93cykiIHhtcDpDcmVhdGVEYXRlPSIyMDE5LTAxLTMxVDE4OjU1OjA4WiIgeG1wOk1ldGFkYXRhRGF0ZT0iMjAxOS0wMS0zMVQxODo1NTowOFoiIHhtcDpNb2RpZnlEYXRlPSIyMDE5LTAxLTMxVDE4OjU1OjA4WiIgeG1wTU06SW5zdGFuY2VJRD0ieG1wLmlpZDphMTlhZDJmOC1kMDI2LTI1NDItODhjOS1iZTRkYjkyMmQ0MmQiIHhtcE1NOkRvY3VtZW50SUQ9ImFkb2JlOmRvY2lkOnBob3Rvc2hvcDpkOGI5NDUyMS00ZjEwLWQ5NDktYjUwNC0wZmU1N2I3Nzk1MDEiIHhtcE1NOk9yaWdpbmFsRG9jdW1lbnRJRD0ieG1wLmRpZDplMzdjYmE1ZS1hYTMwLWNkNDUtYTAyNS1lOWYxZjk2MzUzOGUiIGRjOmZvcm1hdD0iaW1hZ2UvcG5nIiBwaG90b3Nob3A6Q29sb3JNb2RlPSIzIj4gPHhtcE1NOkhpc3Rvcnk+IDxyZGY6U2VxPiA8cmRmOmxpIHN0RXZ0OmFjdGlvbj0iY3JlYXRlZCIgc3RFdnQ6aW5zdGFuY2VJRD0ieG1wLmlpZDplMzdjYmE1ZS1hYTMwLWNkNDUtYTAyNS1lOWYxZjk2MzUzOGUiIHN0RXZ0OndoZW49IjIwMTktMDEtMzFUMTg6NTU6MDhaIiBzdEV2dDpzb2Z0d2FyZUFnZW50PSJBZG9iZSBQaG90b3Nob3AgQ0MgMjAxOSAoV2luZG93cykiLz4gPHJkZjpsaSBzdEV2dDphY3Rpb249InNhdmVkIiBzdEV2dDppbnN0YW5jZUlEPSJ4bXAuaWlkOmExOWFkMmY4LWQwMjYtMjU0Mi04OGM5LWJlNGRiOTIyZDQyZCIgc3RFdnQ6d2hlbj0iMjAxOS0wMS0zMVQxODo1NTowOFoiIHN0RXZ0OnNvZnR3YXJlQWdlbnQ9IkFkb2JlIFBob3Rvc2hvcCBDQyAyMDE5IChXaW5kb3dzKSIgc3RFdnQ6Y2hhbmdlZD0iLyIvPiA8L3JkZjpTZXE+IDwveG1wTU06SGlzdG9yeT4gPC9yZGY6RGVzY3JpcHRpb24+IDwvcmRmOlJERj4gPC94OnhtcG1ldGE+IDw/eHBhY2tldCBlbmQ9InIiPz4En6MDAAAAX0lEQVQYlX3KOw6AIBBAwS32RpJADXfx0pTET+ERZJ8F8RODFtONsG0QAoh0CSDM82dqodaBdQXnfoLZQM7gPai+wjNNE8R4pTuAYNZSKZASqL7CMy0LxNgJp30fKYUDi3+vIqb/+rUAAAAASUVORK5CYII=');
    background-repeat: no-repeat;
    background-position: top right;
}

.gradio_wrapper .jexcel .sp-replacer
{
    margin: 2px;
    border:0px;
}

.gradio_wrapper .jexcel > thead > tr.jexcel_filter > td > input
{
    border:0px;
    width:100%;
    outline:none;
}

.gradio_wrapper .jexcel_about {
    float: right;
    font-size: 0.7em;
    padding: 2px;
    text-transform: uppercase;
    letter-spacing: 1px;
    display: none;
}
.gradio_wrapper .jexcel_about a {
    color: #ccc;
    text-decoration: none;
}

.gradio_wrapper .jexcel_about img {
    display: none;
}

.gradio_wrapper .jexcel_filter
{
    display:flex;
    justify-content:space-between;
    margin-bottom:4px;
}

.gradio_wrapper .jexcel_filter > div
{
    padding:8px;
    align-items:center;
}

.gradio_wrapper .jexcel_pagination
{
    display:flex;
    justify-content:space-between;
    align-items:center;
}

.gradio_wrapper .jexcel_pagination > div
{
    display:flex;
    padding:10px;
}

.gradio_wrapper .jexcel_pagination > div:last-child
{
    padding-right:10px;
    padding-top:10px;
}

.gradio_wrapper .jexcel_pagination > div > div
{
    text-align:center;
    width:36px;
    height:36px;
    line-height:34px;
    border:1px solid #ccc;
    box-sizing: border-box;
    margin-left:2px;
    cursor:pointer;
}

.gradio_wrapper .jexcel_page
{
    font-size:0.8em;
}

.gradio_wrapper .jexcel_page_selected
{
    font-weight:bold;
    background-color:#f3f3f3;
}

.gradio_wrapper .jexcel_toolbar
{
    display:flex;
    background-color:#f3f3f3;
    border:1px solid #ccc;
    padding:4px;
    margin:0px 2px 4px 1px;
    position:-webkit-sticky;
    position:sticky;
    top:0px;
    z-index:21;
}

.gradio_wrapper .jexcel_toolbar:empty
{
    display:none;
}

.gradio_wrapper .jexcel_toolbar i.jexcel_toolbar_item 
{
    width:24px;
    height:24px;
    padding:4px;
    cursor:pointer;
    display:inline-block;
}

.gradio_wrapper .jexcel_toolbar i.jexcel_toolbar_item:hover 
{
    background-color:#ddd;
}

.gradio_wrapper .jexcel_toolbar select.jexcel_toolbar_item 
{
    margin-left:2px;
    margin-right:2px;
    display:inline-block;
    border:0px;
    background-color:transparent;
    padding-right:10px;
}

.gradio_wrapper .jexcel .dragging-left
{
    background-repeat: no-repeat;
    background-position:top 50% left 0px;
    background-image: url("data:image/svg+xml,%3Csvg xmlns='http://www.w3.org/2000/svg' width='24' height='24' viewBox='0 0 24 24'%3E%3Cpath d='M14 7l-5 5 5 5V7z'/%3E%3Cpath fill='none' d='M24 0v24H0V0h24z'/%3E%3C/svg%3E");
}

.gradio_wrapper .jexcel .dragging-right
{
    background-repeat: no-repeat;
    background-position:top 50% right 0px;
    background-image: url("data:image/svg+xml,%3Csvg xmlns='http://www.w3.org/2000/svg' width='24' height='24' viewBox='0 0 24 24'%3E%3Cpath d='M10 17l5-5-5-5v10z'/%3E%3Cpath fill='none' d='M0 24V0h24v24H0z'/%3E%3C/svg%3E");
}

.gradio_wrapper .jexcel_tabs .jexcel_tab
{
    display:none;
}

.gradio_wrapper .jexcel_tabs .jexcel_tab_link
{
    display:inline-block;
    padding:10px;
    padding-left:20px;
    padding-right:20px;
    margin-right:5px;
    margin-bottom:5px;
    background-color:#f3f3f3;
    cursor:pointer;
}

.gradio_wrapper .jexcel_tabs .jexcel_tab_link.selected
{
    background-color:#ddd;
}

.gradio_wrapper .jexcel_hidden_index > tbody > tr > td:first-child, .gradio_wrapper .jexcel_hidden_index > thead > tr > td:first-child, .gradio_wrapper .jexcel_hidden_index > tfoot > tr > td:first-child, .gradio_wrapper .jexcel_hidden_index > colgroup > col:first-child
{
    display:none;
}



.gradio_wrapper .jexcel .jrating {
    display: inline-flex;
}
.gradio_wrapper .jexcel .jrating > div {
    zoom: 0.55;
}

.gradio_wrapper .jexcel .copying-top {
    border-top:1px dashed #000;
}

.gradio_wrapper .jexcel .copying-left {
    border-left:1px dashed #000;
}

.gradio_wrapper .jexcel .copying-right {
    border-right:1px dashed #000;
}

.gradio_wrapper .jexcel .copying-bottom {
    border-bottom:1px dashed #000;
}

.gradio_wrapper .jexcel .jexcel_column_filter {
    background-repeat: no-repeat;
    background-position: top 50% right 5px;
    background-image: url("data:image/svg+xml,%3Csvg xmlns='http://www.w3.org/2000/svg' viewBox='0 0 24 24' fill='gray' width='18px' height='18px'%3E%3Cpath d='M10 18h4v-2h-4v2zM3 6v2h18V6H3zm3 7h12v-2H6v2z'/%3E%3Cpath d='M0 0h24v24H0z' fill='none'/%3E%3C/svg%3E");
    text-overflow: ellipsis;
    overflow: hidden;
    padding: 0px;
    padding-left: 6px;
    padding-right: 20px;
}

.gradio_wrapper .jexcel thead .jexcel_freezed, .gradio_wrapper .jexcel tfoot .jexcel_freezed {
    left: 0px;
    z-index: 3 !important;
    box-shadow: 2px 0px 2px 0.2px #ccc !important;
    -webkit-box-shadow: 2px 0px 2px 0.2px #ccc !important;
    -moz-box-shadow: 2px 0px 2px 0.2px #ccc !important;
}

.gradio_wrapper .jexcel tbody .jexcel_freezed {
    position: relative;
    background-color: #fff;
    box-shadow: 1px 1px 1px 1px #ccc !important;
    -webkit-box-shadow: 2px 4px 4px 0.1px #ccc !important;
    -moz-box-shadow: 2px 4px 4px 0.1px #ccc !important;
}

/*!
 * tui-image-editor.js
 * @version 3.14.2
 * @author NHN. FE Development Lab <dl_javascript@nhn.com>
 * @license MIT
 */
.gradio_wrapper > textarea {
  position: fixed !important;
}
.gradio_wrapper .tui-image-editor-container {
  margin: 0;
  padding: 0;
  box-sizing: border-box;
  min-height: 300px;
  height: 100%;
  position: relative;
  background-color: #282828;
  overflow: hidden;
  letter-spacing: 0.3px;
}
.gradio_wrapper .tui-image-editor-container div, .gradio_wrapper .tui-image-editor-container ul, .gradio_wrapper .tui-image-editor-container label, .gradio_wrapper .tui-image-editor-container input, .gradio_wrapper .tui-image-editor-container li {
  box-sizing: border-box;
  margin: 0;
  padding: 0;
  -ms-user-select: none;
  -webkit-user-select: none;
  user-select: none;
}
.gradio_wrapper .tui-image-editor-container .tui-image-editor-header {
/* BUTTON AND LOGO */
  min-width: 533px;
  position: absolute;
  background-color: #151515;
  top: 0;
  width: 100%;
}
.gradio_wrapper .tui-image-editor-container .tui-image-editor-header-buttons, .gradio_wrapper .tui-image-editor-container .tui-image-editor-controls-buttons {
  float: right;
  margin: 8px;
}
.gradio_wrapper .tui-image-editor-container .tui-image-editor-header-logo, .gradio_wrapper .tui-image-editor-container .tui-image-editor-controls-logo {
  float: left;
  width: 30%;
  padding: 17px;
}
.gradio_wrapper .tui-image-editor-container .tui-image-editor-controls-logo, .gradio_wrapper .tui-image-editor-container .tui-image-editor-controls-buttons {
  width: 270px;
  height: 100%;
  display: none;
}
.gradio_wrapper .tui-image-editor-container .tui-image-editor-header-buttons button, .gradio_wrapper .tui-image-editor-container .tui-image-editor-header-buttons div, .gradio_wrapper .tui-image-editor-container .tui-image-editor-controls-buttons button, .gradio_wrapper .tui-image-editor-container .tui-image-editor-controls-buttons div {
  display: inline-block;
  position: relative;
  width: 120px;
  height: 40px;
  padding: 0;
  line-height: 40px;
  outline: none;
  border-radius: 20px;
  border: 1px solid #ddd;
  font-family: 'Noto Sans', sans-serif;
  font-size: 12px;
  font-weight: bold;
  cursor: pointer;
  vertical-align: middle;
  letter-spacing: 0.3px;
  text-align: center;
}
.gradio_wrapper .tui-image-editor-container .tui-image-editor-download-btn {
  background-color: #fdba3b;
  border-color: #fdba3b;
  color: #fff;
}
.gradio_wrapper .tui-image-editor-container .tui-image-editor-load-btn {
  position: absolute;
  left: 0;
  right: 0;
  display: inline-block;
  top: 0;
  bottom: 0;
  width: 100%;
  cursor: pointer;
  opacity: 0;
}
.gradio_wrapper .tui-image-editor-container .tui-image-editor-main-container {
  position: absolute;
  width: 100%;
  top: 0;
  bottom: 64px;
}
.gradio_wrapper .tui-image-editor-container .tui-image-editor-main {
  position: absolute;
  text-align: center;
  top: 64px;
  bottom: 0;
  right: 0;
  left: 0;
}
.gradio_wrapper .tui-image-editor-container .tui-image-editor-wrap {
  position: absolute;
  bottom: 0;
  width: 100%;
  overflow: auto;
}
.gradio_wrapper .tui-image-editor-container .tui-image-editor-wrap .tui-image-editor-size-wrap {
  display: table;
  width: 100%;
  height: 100%;
}
.gradio_wrapper .tui-image-editor-container .tui-image-editor-wrap .tui-image-editor-size-wrap .tui-image-editor-align-wrap {
  display: table-cell;
  vertical-align: middle;
}
.gradio_wrapper .tui-image-editor-container .tui-image-editor {
  position: relative;
  display: inline-block;
}
.gradio_wrapper .tui-image-editor-container .tui-image-editor-menu, .gradio_wrapper .tui-image-editor-container .tui-image-editor-help-menu {
  width: auto;
  list-style: none;
  padding: 0;
  margin: 0 auto;
  display: table-cell;
  text-align: center;
  vertical-align: middle;
  white-space: nowrap;
}
.gradio_wrapper .tui-image-editor-container .tui-image-editor-menu > .tui-image-editor-item, .gradio_wrapper .tui-image-editor-container .tui-image-editor-help-menu > .tui-image-editor-item {
  position: relative;
  display: inline-block;
  border-radius: 2px;
  padding: 7px 8px 3px 8px;
  cursor: pointer;
  margin: 0 4px;
}
.gradio_wrapper .tui-image-editor-container .tui-image-editor-menu > .tui-image-editor-item[tooltip-content]:hover:before, .gradio_wrapper .tui-image-editor-container .tui-image-editor-help-menu > .tui-image-editor-item[tooltip-content]:hover:before {
  content: '';
  position: absolute;
  display: inline-block;
  margin: 0 auto 0;
  width: 0;
  height: 0;
  border-right: 7px solid transparent;
  border-top: 7px solid #2f2f2f;
  border-left: 7px solid transparent;
  left: 13px;
  top: -2px;
}
.gradio_wrapper .tui-image-editor-container .tui-image-editor-menu > .tui-image-editor-item[tooltip-content]:hover:after, .gradio_wrapper .tui-image-editor-container .tui-image-editor-help-menu > .tui-image-editor-item[tooltip-content]:hover:after {
  content: attr(tooltip-content);
  position: absolute;
  display: inline-block;
  background-color: #2f2f2f;
  color: #fff;
  padding: 5px 8px;
  font-size: 11px;
  font-weight: lighter;
  border-radius: 3px;
  max-height: 23px;
  top: -25px;
  left: 0;
  min-width: 24px;
}
.gradio_wrapper .tui-image-editor-container .tui-image-editor-menu > .tui-image-editor-item.active, .gradio_wrapper .tui-image-editor-container .tui-image-editor-help-menu > .tui-image-editor-item.active {
  background-color: #fff;
  transition: all 0.3s ease;
}
.gradio_wrapper .tui-image-editor-container .tui-image-editor-wrap {
  position: absolute;
}
.gradio_wrapper .tui-image-editor-container .tui-image-editor-grid-visual {
  display: none;
  position: absolute;
  width: 100%;
  height: 100%;
  border: 1px solid rgba(255,255,255,0.7);
}
.gradio_wrapper .tui-image-editor-container .tui-image-editor-main.tui-image-editor-menu-flip .tui-image-editor, .gradio_wrapper .tui-image-editor-container .tui-image-editor-main.tui-image-editor-menu-rotate .tui-image-editor {
  transition: none;
}
.gradio_wrapper .tui-image-editor-container .tui-image-editor-main.tui-image-editor-menu-flip .tui-image-editor-grid-visual, .gradio_wrapper .tui-image-editor-container .tui-image-editor-main.tui-image-editor-menu-rotate .tui-image-editor-grid-visual {
  display: block;
}
.gradio_wrapper .tui-image-editor-container .tui-image-editor-grid-visual table {
  width: 100%;
  height: 100%;
  border-collapse: collapse;
}
.gradio_wrapper .tui-image-editor-container .tui-image-editor-grid-visual table td {
  border: 1px solid rgba(255,255,255,0.3);
}
.gradio_wrapper .tui-image-editor-container .tui-image-editor-grid-visual table td.dot:before {
  content: '';
  position: absolute;
  box-sizing: border-box;
  width: 10px;
  height: 10px;
  border: 0;
  box-shadow: 0 0 1px 0 rgba(0,0,0,0.3);
  border-radius: 100%;
  background-color: #fff;
}
.gradio_wrapper .tui-image-editor-container .tui-image-editor-grid-visual table td.dot.left-top:before {
  top: -5px;
  left: -5px;
}
.gradio_wrapper .tui-image-editor-container .tui-image-editor-grid-visual table td.dot.right-top:before {
  top: -5px;
  right: -5px;
}
.gradio_wrapper .tui-image-editor-container .tui-image-editor-grid-visual table td.dot.left-bottom:before {
  bottom: -5px;
  left: -5px;
}
.gradio_wrapper .tui-image-editor-container .tui-image-editor-grid-visual table td.dot.right-bottom:before {
  bottom: -5px;
  right: -5px;
}
.gradio_wrapper .tui-image-editor-container .tui-image-editor-submenu {
  display: none;
  position: absolute;
  bottom: 0;
  width: 100%;
  height: 150px;
  white-space: nowrap;
  z-index: 2;
}
.gradio_wrapper .tui-image-editor-container .tui-image-editor-submenu .tui-image-editor-button:hover svg > use.active {
  display: block;
}
.gradio_wrapper .tui-image-editor-container .tui-image-editor-submenu .tui-image-editor-submenu-item li {
  display: inline-block;
  vertical-align: top;
}
.gradio_wrapper .tui-image-editor-container .tui-image-editor-submenu .tui-image-editor-submenu-item .tui-image-editor-newline {
  display: block;
  margin-top: 0;
}
.gradio_wrapper .tui-image-editor-container .tui-image-editor-submenu .tui-image-editor-submenu-item .tui-image-editor-button {
  position: relative;
  cursor: pointer;
  display: inline-block;
  font-weight: normal;
  font-size: 11px;
  margin: 0 9px 0 9px;
}
.gradio_wrapper .tui-image-editor-container .tui-image-editor-submenu .tui-image-editor-submenu-item .tui-image-editor-button.preset {
  margin: 0 9px 20px 5px;
}
.gradio_wrapper .tui-image-editor-container .tui-image-editor-submenu .tui-image-editor-submenu-item label > span {
  display: inline-block;
  cursor: pointer;
  padding-top: 5px;
  font-family: "Noto Sans", sans-serif;
  font-size: 11px;
}
.gradio_wrapper .tui-image-editor-container .tui-image-editor-submenu .tui-image-editor-submenu-item .tui-image-editor-button.apply label, .gradio_wrapper .tui-image-editor-container .tui-image-editor-submenu .tui-image-editor-submenu-item .tui-image-editor-button.cancel label {
  vertical-align: 7px;
}
.gradio_wrapper .tui-image-editor-container .tui-image-editor-submenu > div {
  display: none;
  vertical-align: bottom;
}
.gradio_wrapper .tui-image-editor-container .tui-image-editor-submenu .tui-image-editor-submenu-style {
  opacity: 0.95;
  z-index: -1;
  position: absolute;
  top: 0;
  bottom: 0;
  left: 0;
  right: 0;
  display: block;
}
.gradio_wrapper .tui-image-editor-container .tui-image-editor-partition > div {
  width: 1px;
  height: 52px;
  border-left: 1px solid #3c3c3c;
  margin: 0 8px 0 8px;
}
.gradio_wrapper .tui-image-editor-container .tui-image-editor-main.tui-image-editor-menu-filter .tui-image-editor-partition > div {
  height: 108px;
  margin: 0 29px 0 0px;
}
.gradio_wrapper .tui-image-editor-container .tui-image-editor-submenu-align {
  text-align: left;
  margin-right: 30px;
}
.gradio_wrapper .tui-image-editor-container .tui-image-editor-submenu-align label > span {
  width: 55px;
  white-space: nowrap;
}
.gradio_wrapper .tui-image-editor-container .tui-image-editor-submenu-align:first-child {
  margin-right: 0;
}
.gradio_wrapper .tui-image-editor-container .tui-image-editor-submenu-align:first-child label > span {
  width: 70px;
}
.gradio_wrapper .tui-image-editor-container .tui-image-editor-main.tui-image-editor-menu-crop .tui-image-editor-submenu > div.tui-image-editor-menu-crop, .gradio_wrapper .tui-image-editor-container .tui-image-editor-main.tui-image-editor-menu-flip .tui-image-editor-submenu > div.tui-image-editor-menu-flip, .gradio_wrapper .tui-image-editor-container .tui-image-editor-main.tui-image-editor-menu-rotate .tui-image-editor-submenu > div.tui-image-editor-menu-rotate, .gradio_wrapper .tui-image-editor-container .tui-image-editor-main.tui-image-editor-menu-shape .tui-image-editor-submenu > div.tui-image-editor-menu-shape, .gradio_wrapper .tui-image-editor-container .tui-image-editor-main.tui-image-editor-menu-text .tui-image-editor-submenu > div.tui-image-editor-menu-text, .gradio_wrapper .tui-image-editor-container .tui-image-editor-main.tui-image-editor-menu-mask .tui-image-editor-submenu > div.tui-image-editor-menu-mask, .gradio_wrapper .tui-image-editor-container .tui-image-editor-main.tui-image-editor-menu-icon .tui-image-editor-submenu > div.tui-image-editor-menu-icon, .gradio_wrapper .tui-image-editor-container .tui-image-editor-main.tui-image-editor-menu-draw .tui-image-editor-submenu > div.tui-image-editor-menu-draw, .gradio_wrapper .tui-image-editor-container .tui-image-editor-main.tui-image-editor-menu-filter .tui-image-editor-submenu > div.tui-image-editor-menu-filter, .gradio_wrapper .tui-image-editor-container .tui-image-editor-main.tui-image-editor-menu-zoom .tui-image-editor-submenu > div.tui-image-editor-menu-zoom {
  display: table-cell;
}
.gradio_wrapper .tui-image-editor-container .tui-image-editor-main.tui-image-editor-menu-crop .tui-image-editor-submenu, .gradio_wrapper .tui-image-editor-container .tui-image-editor-main.tui-image-editor-menu-flip .tui-image-editor-submenu, .gradio_wrapper .tui-image-editor-container .tui-image-editor-main.tui-image-editor-menu-rotate .tui-image-editor-submenu, .gradio_wrapper .tui-image-editor-container .tui-image-editor-main.tui-image-editor-menu-shape .tui-image-editor-submenu, .gradio_wrapper .tui-image-editor-container .tui-image-editor-main.tui-image-editor-menu-text .tui-image-editor-submenu, .gradio_wrapper .tui-image-editor-container .tui-image-editor-main.tui-image-editor-menu-mask .tui-image-editor-submenu, .gradio_wrapper .tui-image-editor-container .tui-image-editor-main.tui-image-editor-menu-icon .tui-image-editor-submenu, .gradio_wrapper .tui-image-editor-container .tui-image-editor-main.tui-image-editor-menu-draw .tui-image-editor-submenu, .gradio_wrapper .tui-image-editor-container .tui-image-editor-main.tui-image-editor-menu-filter .tui-image-editor-submenu, .gradio_wrapper .tui-image-editor-container .tui-image-editor-main.tui-image-editor-menu-zoom .tui-image-editor-submenu {
  display: table;
}
.gradio_wrapper .tui-image-editor-container .tui-image-editor-help-menu {
  list-style: none;
  padding: 0;
  margin: 0 auto;
  text-align: center;
  vertical-align: middle;
  border-radius: 20px;
  background-color: rgba(255,255,255,0.06);
  z-index: 2;
  position: absolute;
}
.gradio_wrapper .tui-image-editor-container .tui-image-editor-help-menu .tie-panel-history {
  display: none;
  background-color: #fff;
  color: #444;
  position: absolute;
  width: 196px;
  height: 276px;
  padding: 4px 2px;
  box-shadow: 0 2px 6px 0 rgba(0,0,0,0.15);
  cursor: auto;
  -webkit-transform: translateX(calc(-50% + 12px));
          transform: translateX(calc(-50% + 12px));
}
.gradio_wrapper .tui-image-editor-container .tui-image-editor-help-menu .tie-panel-history .history-list {
  height: 268px;
  padding: 0;
  overflow: hidden scroll;
  list-style: none;
}
.gradio_wrapper .tui-image-editor-container .tui-image-editor-help-menu .tie-panel-history .history-list .history-item {
  height: 24px;
  font-size: 11px;
  line-height: 24px;
}
.gradio_wrapper .tui-image-editor-container .tui-image-editor-help-menu .tie-panel-history .history-list .history-item .tui-image-editor-history-item {
  position: relative;
  height: 24px;
  cursor: pointer;
}
.gradio_wrapper .tui-image-editor-container .tui-image-editor-help-menu .tie-panel-history .history-list .history-item .tui-image-editor-history-item svg {
  width: 24px;
  height: 24px;
}
.gradio_wrapper .tui-image-editor-container .tui-image-editor-help-menu .tie-panel-history .history-list .history-item .tui-image-editor-history-item span {
  display: inline-block;
  width: 128px;
  height: 24px;
  text-align: left;
}
.gradio_wrapper .tui-image-editor-container .tui-image-editor-help-menu .tie-panel-history .history-list .history-item .tui-image-editor-history-item .history-item-icon {
  display: inline-block;
  width: 24px;
  height: 24px;
  position: absolute;
  top: 6px;
  left: 6px;
}
.gradio_wrapper .tui-image-editor-container .tui-image-editor-help-menu .tie-panel-history .history-list .history-item .tui-image-editor-history-item .history-item-checkbox {
  display: none;
  width: 24px;
  height: 24px;
  position: absolute;
  top: 5px;
  right: -6px;
}
.gradio_wrapper .tui-image-editor-container .tui-image-editor-help-menu .tie-panel-history .history-list .history-item.selected-item {
  background-color: rgba(119,119,119,0.12);
}
.gradio_wrapper .tui-image-editor-container .tui-image-editor-help-menu .tie-panel-history .history-list .history-item.selected-item .history-item-checkbox {
  display: inline-block;
}
.gradio_wrapper .tui-image-editor-container .tui-image-editor-help-menu .tie-panel-history .history-list .history-item.disabled-item {
  color: #333;
  opacity: 0.3;
}
.gradio_wrapper .tui-image-editor-container .tui-image-editor-help-menu .opened .tie-panel-history {
  display: block;
}
.gradio_wrapper .tui-image-editor-container .tui-image-editor-help-menu .opened .tie-panel-history:before {
  content: '';
  position: absolute;
  display: inline-block;
  margin: 0 auto;
  width: 0;
  height: 0;
}
.gradio_wrapper .tui-image-editor-container .filter-color-item {
  display: inline-block;
}
.gradio_wrapper .tui-image-editor-container .filter-color-item .tui-image-editor-checkbox {
  display: block;
}
.gradio_wrapper .tui-image-editor-container .tui-image-editor-checkbox-wrap {
  display: inline-block !important;
  text-align: left;
}
.gradio_wrapper .tui-image-editor-container .tui-image-editor-checkbox-wrap.fixed-width {
  width: 187px;
  white-space: normal;
}
.gradio_wrapper .tui-image-editor-container .tui-image-editor-checkbox {
  display: inline-block;
  margin: 1px 0 1px 0;
}
.gradio_wrapper .tui-image-editor-container .tui-image-editor-checkbox input {
  width: 14px;
  height: 14px;
  opacity: 0;
}
.gradio_wrapper .tui-image-editor-container .tui-image-editor-checkbox > label > span {
  color: #fff;
  height: 14px;
  position: relative;
}
.gradio_wrapper .tui-image-editor-container .tui-image-editor-checkbox input + label:before, .gradio_wrapper .tui-image-editor-container .tui-image-editor-checkbox > label > span:before {
  content: '';
  position: absolute;
  width: 14px;
  height: 14px;
  background-color: #fff;
  top: 6px;
  left: -19px;
  display: inline-block;
  margin: 0;
  text-align: center;
  font-size: 11px;
  border: 0;
  border-radius: 2px;
  padding-top: 1px;
  box-sizing: border-box;
}
.gradio_wrapper .tui-image-editor-container .tui-image-editor-checkbox input[type='checkbox']:checked + span:before {
  background-size: cover;
  background-image: url("data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAAA4AAAAOCAYAAAAfSC3RAAAAAXNSR0IArs4c6QAAAMBJREFUKBWVkjEOwjAMRe2WgZW7IIHEDdhghhuwcQ42rlJugAQS54Cxa5cq1QM5TUpByZfS2j9+dlJVt/tX5ZxbS4ZU9VLkQvSHKTIGRaVJYFmKrBbTCJxE2UgCdDzMZDkHrOV6b95V0US6UmgKodujEZbJg0B0ZgEModO5lrY1TMQf1TpyJGBEjD+E2NPN7ukIUDiF/BfEXgRiGEw8NgkffYGYwCi808fpn/6OvfUfsDr/Vc1IfRf8sKnFVqeiVQfDu0tf/nWH9gAAAABJRU5ErkJggg==");
}
.gradio_wrapper .tui-image-editor-container .tui-image-editor-selectlist-wrap {
  position: relative;
}
.gradio_wrapper .tui-image-editor-container .tui-image-editor-selectlist-wrap select {
  width: 100%;
  height: 28px;
  margin-top: 4px;
  border: 0;
  outline: 0;
  border-radius: 0;
  border: 1px solid #cbdbdb;
  background-color: #fff;
  -webkit-appearance: none;
  appearance: none;
  padding: 0 7px 0 10px;
}
.gradio_wrapper .tui-image-editor-container .tui-image-editor-selectlist-wrap .tui-image-editor-selectlist {
  display: none;
  position: relative;
  top: -1px;
  border: 1px solid #ccc;
  background-color: #fff;
  border-top: 0px;
  padding: 4px 0;
}
.gradio_wrapper .tui-image-editor-container .tui-image-editor-selectlist-wrap .tui-image-editor-selectlist li {
  display: block;
  text-align: left;
  padding: 7px 10px;
  font-family: 'Noto Sans', sans-serif;
}
.gradio_wrapper .tui-image-editor-container .tui-image-editor-selectlist-wrap .tui-image-editor-selectlist li:hover {
  background-color: rgba(81,92,230,0.05);
}
.gradio_wrapper .tui-image-editor-container .tui-image-editor-selectlist-wrap:before {
  content: '';
  position: absolute;
  display: inline-block;
  width: 14px;
  height: 14px;
  right: 5px;
  top: 10px;
  background-image: url("data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAAA4AAAAOCAYAAAAfSC3RAAAAAXNSR0IArs4c6QAAAHlJREFUKBVjYBgFOEOAEVkmPDxc89+/f6eAYjzI4kD2FyYmJrOVK1deh4kzwRggGiQBVJCELAZig8SQNYHEmEEEMrh69eo1HR0dfqCYJUickZGxf9WqVf3IakBsFBthklpaWmVA9mEQhrJhUoTp0NBQCRAmrHL4qgAAuu4cWZOZIGsAAAAASUVORK5CYII=");
  background-size: cover;
}
.gradio_wrapper .tui-image-editor-container .tui-image-editor-selectlist-wrap select::-ms-expand {
  display: none;
}
.gradio_wrapper .tui-image-editor-container .tui-image-editor-virtual-range-bar .tui-image-editor-disabled, .gradio_wrapper .tui-image-editor-container .tui-image-editor-virtual-range-subbar .tui-image-editor-disabled, .gradio_wrapper .tui-image-editor-container .tui-image-editor-virtual-range-pointer .tui-image-editor-disabled {
  backbround-color: #f00;
}
.gradio_wrapper .tui-image-editor-container .tui-image-editor-range {
  position: relative;
  top: 5px;
  width: 166px;
  height: 17px;
  display: inline-block;
}
.gradio_wrapper .tui-image-editor-container .tui-image-editor-virtual-range-bar {
  top: 7px;
  position: absolute;
  width: 100%;
  height: 2px;
  background-color: #666;
}
.gradio_wrapper .tui-image-editor-container .tui-image-editor-virtual-range-subbar {
  position: absolute;
  height: 100%;
  left: 0;
  right: 0;
  background-color: #d1d1d1;
}
.gradio_wrapper .tui-image-editor-container .tui-image-editor-virtual-range-pointer {
  position: absolute;
  cursor: pointer;
  top: -5px;
  left: 0;
  width: 12px;
  height: 12px;
  background-color: #fff;
  border-radius: 100%;
}
.gradio_wrapper .tui-image-editor-container .tui-image-editor-range-wrap {
  display: inline-block;
  margin-left: 4px;
}
.gradio_wrapper .tui-image-editor-container .tui-image-editor-range-wrap.short .tui-image-editor-range {
  width: 100px;
}
.gradio_wrapper .tui-image-editor-container .color-picker-control .tui-image-editor-range {
  width: 108px;
  margin-left: 10px;
}
.gradio_wrapper .tui-image-editor-container .color-picker-control .tui-image-editor-virtual-range-pointer {
  background-color: #333;
}
.gradio_wrapper .tui-image-editor-container .color-picker-control .tui-image-editor-virtual-range-bar {
  background-color: #ccc;
}
.gradio_wrapper .tui-image-editor-container .color-picker-control .tui-image-editor-virtual-range-subbar {
  background-color: #606060;
}
.gradio_wrapper .tui-image-editor-container .tui-image-editor-range-wrap.tui-image-editor-newline.short {
  margin-top: -2px;
  margin-left: 19px;
}
.gradio_wrapper .tui-image-editor-container .tui-image-editor-range-wrap.tui-image-editor-newline.short label {
  color: #8e8e8e;
  font-weight: normal;
}
.gradio_wrapper .tui-image-editor-container .tui-image-editor-range-wrap label {
  vertical-align: baseline;
  font-size: 11px;
  margin-right: 7px;
  color: #fff;
}
.gradio_wrapper .tui-image-editor-container .tui-image-editor-range-value {
  cursor: default;
  width: 40px;
  height: 24px;
  outline: none;
  border-radius: 2px;
  box-shadow: none;
  border: 1px solid #d5d5d5;
  text-align: center;
  background-color: #1c1c1c;
  color: #fff;
  font-weight: lighter;
  vertical-align: baseline;
  font-family: 'Noto Sans', sans-serif;
  margin-top: 21px;
  margin-left: 4px;
}
.gradio_wrapper .tui-image-editor-container .tui-image-editor-controls {
  position: absolute;
  background-color: #151515;
  width: 100%;
  height: 64px;
  display: table;
  bottom: 0;
  z-index: 2;
}
.gradio_wrapper .tui-image-editor-container .tui-image-editor-icpartition {
  display: inline-block;
  background-color: #444;
  width: 1px;
  height: 24px;
}
.gradio_wrapper .tui-image-editor-container.left .tui-image-editor-menu > .tui-image-editor-item[tooltip-content]:before {
  left: 28px;
  top: 11px;
  border-right: 7px solid #2f2f2f;
  border-top: 7px solid transparent;
  border-bottom: 7px solid transparent;
}
.gradio_wrapper .tui-image-editor-container.left .tui-image-editor-menu > .tui-image-editor-item[tooltip-content]:after {
  top: 7px;
  left: 42px;
  white-space: nowrap;
}
.gradio_wrapper .tui-image-editor-container.left .tui-image-editor-submenu {
  left: 0;
  height: 100%;
  width: 248px;
}
.gradio_wrapper .tui-image-editor-container.left .tui-image-editor-main-container {
  left: 64px;
  width: calc(100% - 64px);
  height: 100%;
}
.gradio_wrapper .tui-image-editor-container.left .tui-image-editor-controls {
  width: 64px;
  height: 100%;
  display: table;
}
.gradio_wrapper .tui-image-editor-container.left .tui-image-editor-menu, .gradio_wrapper .tui-image-editor-container.right .tui-image-editor-menu {
  white-space: inherit;
}
.gradio_wrapper .tui-image-editor-container.left .tui-image-editor-submenu, .gradio_wrapper .tui-image-editor-container.right .tui-image-editor-submenu {
  white-space: normal;
}
.gradio_wrapper .tui-image-editor-container.left .tui-image-editor-submenu > div, .gradio_wrapper .tui-image-editor-container.right .tui-image-editor-submenu > div {
  vertical-align: middle;
}
.gradio_wrapper .tui-image-editor-container.left .tui-image-editor-controls li, .gradio_wrapper .tui-image-editor-container.right .tui-image-editor-controls li {
  display: inline-block;
  margin: 4px auto;
}
.gradio_wrapper .tui-image-editor-container.left .tui-image-editor-icpartition, .gradio_wrapper .tui-image-editor-container.right .tui-image-editor-icpartition {
  position: relative;
  top: -7px;
  width: 24px;
  height: 1px;
}
.gradio_wrapper .tui-image-editor-container.left .tui-image-editor-submenu .tui-image-editor-partition, .gradio_wrapper .tui-image-editor-container.right .tui-image-editor-submenu .tui-image-editor-partition {
  display: block;
  width: 75%;
  margin: auto;
}
.gradio_wrapper .tui-image-editor-container.left .tui-image-editor-submenu .tui-image-editor-partition > div, .gradio_wrapper .tui-image-editor-container.right .tui-image-editor-submenu .tui-image-editor-partition > div {
  border-left: 0;
  height: 10px;
  border-bottom: 1px solid #3c3c3c;
  width: 100%;
  margin: 0;
}
.gradio_wrapper .tui-image-editor-container.left .tui-image-editor-submenu .tui-image-editor-submenu-align, .gradio_wrapper .tui-image-editor-container.right .tui-image-editor-submenu .tui-image-editor-submenu-align {
  margin-right: 0;
}
.gradio_wrapper .tui-image-editor-container.left .tui-image-editor-submenu .tui-image-editor-submenu-item li, .gradio_wrapper .tui-image-editor-container.right .tui-image-editor-submenu .tui-image-editor-submenu-item li {
  margin-top: 15px;
}
.gradio_wrapper .tui-image-editor-container.left .tui-image-editor-submenu .tui-image-editor-submenu-item .tui-colorpicker-clearfix li, .gradio_wrapper .tui-image-editor-container.right .tui-image-editor-submenu .tui-image-editor-submenu-item .tui-colorpicker-clearfix li {
  margin-top: 0;
}
.gradio_wrapper .tui-image-editor-container.left .tui-image-editor-checkbox-wrap.fixed-width, .gradio_wrapper .tui-image-editor-container.right .tui-image-editor-checkbox-wrap.fixed-width {
  width: 182px;
  white-space: normal;
}
.gradio_wrapper .tui-image-editor-container.left .tui-image-editor-range-wrap.tui-image-editor-newline label.range, .gradio_wrapper .tui-image-editor-container.right .tui-image-editor-range-wrap.tui-image-editor-newline label.range {
  display: block;
  text-align: left;
  width: 75%;
  margin: auto;
}
.gradio_wrapper .tui-image-editor-container.left .tui-image-editor-range, .gradio_wrapper .tui-image-editor-container.right .tui-image-editor-range {
  width: 136px;
}
.gradio_wrapper .tui-image-editor-container.right .tui-image-editor-menu > .tui-image-editor-item[tooltip-content]:before {
  left: -3px;
  top: 11px;
  border-left: 7px solid #2f2f2f;
  border-top: 7px solid transparent;
  border-bottom: 7px solid transparent;
}
.gradio_wrapper .tui-image-editor-container.right .tui-image-editor-menu > .tui-image-editor-item[tooltip-content]:after {
  top: 7px;
  left: unset;
  right: 43px;
  white-space: nowrap;
}
.gradio_wrapper .tui-image-editor-container.right .tui-image-editor-submenu {
  right: 0;
  height: 100%;
  width: 248px;
}
.gradio_wrapper .tui-image-editor-container.right .tui-image-editor-main-container {
  right: 64px;
  width: calc(100% - 64px);
  height: 100%;
}
.gradio_wrapper .tui-image-editor-container.right .tui-image-editor-controls {
  right: 0;
  width: 64px;
  height: 100%;
  display: table;
}
.gradio_wrapper .tui-image-editor-container.top .tui-image-editor-submenu .tui-image-editor-partition.only-left-right, .gradio_wrapper .tui-image-editor-container.bottom .tui-image-editor-submenu .tui-image-editor-partition.only-left-right {
  display: none;
}
.gradio_wrapper .tui-image-editor-container.bottom .tui-image-editor-submenu > div {
  padding-bottom: 24px;
}
.gradio_wrapper .tui-image-editor-container.top .color-picker-control .triangle {
  top: -8px;
  border-right: 7px solid transparent;
  border-top: 0px;
  border-left: 7px solid transparent;
  border-bottom: 8px solid #fff;
}
.gradio_wrapper .tui-image-editor-container.top .tui-image-editor-size-wrap {
  height: 100%;
}
.gradio_wrapper .tui-image-editor-container.top .tui-image-editor-main-container {
  bottom: 0;
}
.gradio_wrapper .tui-image-editor-container.top .tui-image-editor-menu > .tui-image-editor-item[tooltip-content]:before {
  left: 13px;
  border-top: 0;
  border-bottom: 7px solid #2f2f2f;
  top: 33px;
}
.gradio_wrapper .tui-image-editor-container.top .tui-image-editor-menu > .tui-image-editor-item[tooltip-content]:after {
  top: 38px;
}
.gradio_wrapper .tui-image-editor-container.top .tui-image-editor-submenu {
  top: 0;
  bottom: auto;
}
.gradio_wrapper .tui-image-editor-container.top .tui-image-editor-submenu > div {
  padding-top: 24px;
  vertical-align: top;
}
.gradio_wrapper .tui-image-editor-container.top .tui-image-editor-controls-logo {
  display: table-cell;
}
.gradio_wrapper .tui-image-editor-container.top .tui-image-editor-controls-buttons {
  display: table-cell;
}
.gradio_wrapper .tui-image-editor-container.top .tui-image-editor-main {
  top: 64px;
  height: calc(100% - 64px);
}
.gradio_wrapper .tui-image-editor-container.top .tui-image-editor-controls {
  top: 0;
  bottom: inherit;
}
.gradio_wrapper .tui-image-editor-container .tui-image-editor-help-menu.top {
  white-space: nowrap;
  width: 506px;
  height: 40px;
  top: 8px;
  left: 50%;
  -webkit-transform: translateX(-50%);
          transform: translateX(-50%);
}
.gradio_wrapper .tui-image-editor-container .tui-image-editor-help-menu.top .tie-panel-history {
  top: 45px;
}
.gradio_wrapper .tui-image-editor-container .tui-image-editor-help-menu.top .opened .tie-panel-history:before {
  border-right: 8px solid transparent;
  border-left: 8px solid transparent;
  border-bottom: 8px solid #fff;
  left: 90px;
  top: -8px;
}
.gradio_wrapper .tui-image-editor-container .tui-image-editor-help-menu.top > .tui-image-editor-item[tooltip-content]:before {
  left: 13px;
  top: 35px;
  border: none;
  border-bottom: 7px solid #2f2f2f;
  border-left: 7px solid transparent;
  border-right: 7px solid transparent;
}
.gradio_wrapper .tui-image-editor-container .tui-image-editor-help-menu.top > .tui-image-editor-item[tooltip-content]:after {
  top: 41px;
  left: -4px;
  white-space: nowrap;
}
.gradio_wrapper .tui-image-editor-container .tui-image-editor-help-menu.top > .tui-image-editor-item[tooltip-content].opened:before, .gradio_wrapper .tui-image-editor-container .tui-image-editor-help-menu.top > .tui-image-editor-item[tooltip-content].opened:after {
  content: none;
}
.gradio_wrapper .tui-image-editor-container .tui-image-editor-help-menu.bottom {
  white-space: nowrap;
  width: 506px;
  height: 40px;
  bottom: 8px;
  left: 50%;
  -webkit-transform: translateX(-50%);
          transform: translateX(-50%);
}
.gradio_wrapper .tui-image-editor-container .tui-image-editor-help-menu.bottom .tie-panel-history {
  bottom: 45px;
}
.gradio_wrapper .tui-image-editor-container .tui-image-editor-help-menu.bottom .opened .tie-panel-history:before {
  border-right: 8px solid transparent;
  border-left: 8px solid transparent;
  border-top: 8px solid #fff;
  left: 90px;
  bottom: -8px;
}
.gradio_wrapper .tui-image-editor-container .tui-image-editor-help-menu.bottom > .tui-image-editor-item[tooltip-content]:before {
  left: 13px;
  top: auto;
  bottom: 36px;
  border: none;
  border-top: 7px solid #2f2f2f;
  border-left: 7px solid transparent;
  border-right: 7px solid transparent;
}
.gradio_wrapper .tui-image-editor-container .tui-image-editor-help-menu.bottom > .tui-image-editor-item[tooltip-content]:after {
  top: auto;
  left: -4px;
  bottom: 41px;
  white-space: nowrap;
}
.gradio_wrapper .tui-image-editor-container .tui-image-editor-help-menu.bottom > .tui-image-editor-item[tooltip-content].opened:before, .gradio_wrapper .tui-image-editor-container .tui-image-editor-help-menu.bottom > .tui-image-editor-item[tooltip-content].opened:after {
  content: none;
}
.gradio_wrapper .tui-image-editor-container .tui-image-editor-help-menu.left {
  white-space: inherit;
  width: 40px;
  height: 506px;
  left: 8px;
  top: 50%;
  -webkit-transform: translateY(-50%);
          transform: translateY(-50%);
}
.gradio_wrapper .tui-image-editor-container .tui-image-editor-help-menu.left .tie-panel-history {
  left: 140px;
  top: -4px;
}
.gradio_wrapper .tui-image-editor-container .tui-image-editor-help-menu.left .opened .tie-panel-history:before {
  border-top: 8px solid transparent;
  border-bottom: 8px solid transparent;
  border-right: 8px solid #fff;
  left: -8px;
  top: 14px;
}
.gradio_wrapper .tui-image-editor-container .tui-image-editor-help-menu.left .tui-image-editor-item {
  margin: 4px auto;
  padding: 6px 8px;
}
.gradio_wrapper .tui-image-editor-container .tui-image-editor-help-menu.left > .tui-image-editor-item[tooltip-content]:before {
  left: 27px;
  top: 11px;
  border: none;
  border-right: 7px solid #2f2f2f;
  border-top: 7px solid transparent;
  border-bottom: 7px solid transparent;
}
.gradio_wrapper .tui-image-editor-container .tui-image-editor-help-menu.left > .tui-image-editor-item[tooltip-content]:after {
  top: 7px;
  left: 40px;
  white-space: nowrap;
}
.gradio_wrapper .tui-image-editor-container .tui-image-editor-help-menu.left > .tui-image-editor-item[tooltip-content].opened:before, .gradio_wrapper .tui-image-editor-container .tui-image-editor-help-menu.left > .tui-image-editor-item[tooltip-content].opened:after {
  content: none;
}
.gradio_wrapper .tui-image-editor-container .tui-image-editor-help-menu.right {
  white-space: inherit;
  width: 40px;
  height: 506px;
  right: 8px;
  top: 50%;
  -webkit-transform: translateY(-50%);
          transform: translateY(-50%);
}
.gradio_wrapper .tui-image-editor-container .tui-image-editor-help-menu.right .tie-panel-history {
  right: -30px;
  top: -4px;
}
.gradio_wrapper .tui-image-editor-container .tui-image-editor-help-menu.right .opened .tie-panel-history:before {
  border-top: 8px solid transparent;
  border-bottom: 8px solid transparent;
  border-left: 8px solid #fff;
  right: -8px;
  top: 14px;
}
.gradio_wrapper .tui-image-editor-container .tui-image-editor-help-menu.right .tui-image-editor-item {
  margin: 4px auto;
  padding: 6px 8px;
}
.gradio_wrapper .tui-image-editor-container .tui-image-editor-help-menu.right > .tui-image-editor-item[tooltip-content]:before {
  left: -6px;
  top: 11px;
  border: none;
  border-left: 7px solid #2f2f2f;
  border-top: 7px solid transparent;
  border-bottom: 7px solid transparent;
}
.gradio_wrapper .tui-image-editor-container .tui-image-editor-help-menu.right > .tui-image-editor-item[tooltip-content]:after {
  top: 7px;
  left: auto;
  right: 39px;
  white-space: nowrap;
}
.gradio_wrapper .tui-image-editor-container .tui-image-editor-help-menu.right > .tui-image-editor-item[tooltip-content].opened:before, .gradio_wrapper .tui-image-editor-container .tui-image-editor-help-menu.right > .tui-image-editor-item[tooltip-content].opened:after {
  content: none;
}
.gradio_wrapper .tui-image-editor-container .tie-icon-add-button .tui-image-editor-button {
  min-width: 42px;
}
.gradio_wrapper .tui-image-editor-container .svg_ic-menu, .gradio_wrapper .tui-image-editor-container .svg_ic-helpmenu {
  width: 24px;
  height: 24px;
}
.gradio_wrapper .tui-image-editor-container .svg_ic-submenu {
  width: 32px;
  height: 32px;
}
.gradio_wrapper .tui-image-editor-container .svg_img-bi {
  width: 257px;
  height: 26px;
}
.gradio_wrapper .tui-image-editor-container .tui-image-editor-help-menu svg > use, .gradio_wrapper .tui-image-editor-container .tui-image-editor-controls svg > use {
  display: none;
}
.gradio_wrapper .tui-image-editor-container .tui-image-editor-help-menu .enabled svg:hover > use.hover, .gradio_wrapper .tui-image-editor-container .tui-image-editor-controls .enabled svg:hover > use.hover, .gradio_wrapper .tui-image-editor-container .tui-image-editor-help-menu .normal svg:hover > use.hover, .gradio_wrapper .tui-image-editor-container .tui-image-editor-controls .normal svg:hover > use.hover {
  display: block;
}
.gradio_wrapper .tui-image-editor-container .tui-image-editor-help-menu .active svg:hover > use.hover, .gradio_wrapper .tui-image-editor-container .tui-image-editor-controls .active svg:hover > use.hover {
  display: none;
}
.gradio_wrapper .tui-image-editor-container .tui-image-editor-help-menu .on svg > use.hover, .gradio_wrapper .tui-image-editor-container .tui-image-editor-controls .on svg > use.hover, .gradio_wrapper .tui-image-editor-container .tui-image-editor-help-menu .opened svg > use.hover, .gradio_wrapper .tui-image-editor-container .tui-image-editor-controls .opened svg > use.hover {
  display: block;
}
.gradio_wrapper .tui-image-editor-container .tui-image-editor-help-menu svg > use.normal, .gradio_wrapper .tui-image-editor-container .tui-image-editor-controls svg > use.normal {
  display: block;
}
.gradio_wrapper .tui-image-editor-container .tui-image-editor-help-menu .active svg > use.active, .gradio_wrapper .tui-image-editor-container .tui-image-editor-controls .active svg > use.active {
  display: block;
}
.gradio_wrapper .tui-image-editor-container .tui-image-editor-help-menu .enabled svg > use.enabled, .gradio_wrapper .tui-image-editor-container .tui-image-editor-controls .enabled svg > use.enabled {
  display: block;
}
.gradio_wrapper .tui-image-editor-container .tui-image-editor-help-menu .active svg > use.normal, .gradio_wrapper .tui-image-editor-container .tui-image-editor-controls .active svg > use.normal, .gradio_wrapper .tui-image-editor-container .tui-image-editor-help-menu .enabled svg > use.normal, .gradio_wrapper .tui-image-editor-container .tui-image-editor-controls .enabled svg > use.normal {
  display: none;
}
.gradio_wrapper .tui-image-editor-container .tui-image-editor-help-menu .help svg > use.disabled, .gradio_wrapper .tui-image-editor-container .tui-image-editor-controls .help svg > use.disabled, .gradio_wrapper .tui-image-editor-container .tui-image-editor-help-menu .help.enabled svg > use.normal, .gradio_wrapper .tui-image-editor-container .tui-image-editor-controls .help.enabled svg > use.normal {
  display: block;
}
.gradio_wrapper .tui-image-editor-container .tui-image-editor-help-menu .help.enabled svg > use.disabled, .gradio_wrapper .tui-image-editor-container .tui-image-editor-controls .help.enabled svg > use.disabled {
  display: none;
}
.gradio_wrapper .tui-image-editor-container .tui-image-editor-controls:hover {
  z-index: 3;
}
.gradio_wrapper .tui-image-editor-container div.tui-colorpicker-clearfix {
  width: 159px;
  height: 28px;
  border: 1px solid #d5d5d5;
  border-radius: 2px;
  background-color: #f5f5f5;
  margin-top: 6px;
  padding: 4px 7px 4px 7px;
}
.gradio_wrapper .tui-image-editor-container .tui-colorpicker-palette-hex {
  width: 114px;
  background-color: #f5f5f5;
  border: 0;
  font-size: 11px;
  margin-top: 2px;
  font-family: 'Noto Sans', sans-serif;
}
.gradio_wrapper .tui-image-editor-container .tui-colorpicker-palette-hex[value='#ffffff'] + .tui-colorpicker-palette-preview, .gradio_wrapper .tui-image-editor-container .tui-colorpicker-palette-hex[value=''] + .tui-colorpicker-palette-preview {
  border: 1px solid #ccc;
}
.gradio_wrapper .tui-image-editor-container .tui-colorpicker-palette-hex[value=''] + .tui-colorpicker-palette-preview {
  background-size: cover;
  background-image: url("data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAACAAAAAgCAYAAABzenr0AAAAAXNSR0IArs4c6QAAAdBJREFUWAnFl0FuwjAQRZ0ukiugHqFSOQNdseuKW3ALzkA4BateICvUGyCxrtRFd4WuunH/TzykaYJrnLEYaTJJsP2+x8GZZCbQrLU5mj7Bn+EP8HvnCObd+R7xBV5lWfaNON4AnsA38E94qLEt+0yiFaBzAV/Bv+Cxxr4co7hKCDpw1q9wLeNYYdlAwyn8TYt8Hme3+8D5ozcTaMCZ68PXa2tnM2sbEcOZAJhrrpl2DAcTOGNjZPSfCdzkw6JrfbiMv+osBe4y9WOedhm4jZfhbENWuxS44H9Wz/xw4WzqLOAqh1+zycgAwzEMzr5k5gaHOa9ULBwuuDkFlHI1Kl4PJ66kgIpnoywOTmRFAYcbwYk9UMApWkD8zAV5ihcwHk4Rx7gl0IFTQL0EFc+CTQ9OZHWH3YhlVJiVpTHbrTGLhTHLZVgff6s9lyBsI9KduSS83oj+34rTwJutmBmCnMsvozRwZqB5GTkBw6/jdPDu69iJ6BYk6eCcfbcgcQIK/MByaaiMqm8rHcjol2TnpWDhyAKSGdA3FrxtJUToX0ODqatetfGE+8tyEUOV8GY5dGRwLP/MBS4RHQr4bT7NRAQjlcOTfZxmv2G+c4hI8nn+Ax5PG/zhI393AAAAAElFTkSuQmCC");
}
.gradio_wrapper .tui-image-editor-container .tui-colorpicker-palette-preview {
  border-radius: 100%;
  float: left;
  width: 17px;
  height: 17px;
  border: 0;
}
.gradio_wrapper .tui-image-editor-container .color-picker-control {
  position: absolute;
  display: none;
  z-index: 99;
  width: 192px;
  background-color: #fff;
  box-shadow: 0 3px 22px 6px rgba(0,0,0,0.15);
  padding: 16px;
  border-radius: 2px;
}
.gradio_wrapper .tui-image-editor-container .color-picker-control .tui-colorpicker-palette-toggle-slider {
  display: none;
}
.gradio_wrapper .tui-image-editor-container .color-picker-control .tui-colorpicker-palette-button {
  border: 0;
  border-radius: 100%;
  margin: 2px;
  background-size: cover;
  font-size: 1px;
}
.gradio_wrapper .tui-image-editor-container .color-picker-control .tui-colorpicker-palette-button[title='#ffffff'] {
  border: 1px solid #ccc;
}
.gradio_wrapper .tui-image-editor-container .color-picker-control .tui-colorpicker-palette-button[title=''] {
  border: 1px solid #ccc;
}
.gradio_wrapper .tui-image-editor-container .color-picker-control .triangle {
  width: 0;
  height: 0;
  border-right: 7px solid transparent;
  border-top: 8px solid #fff;
  border-left: 7px solid transparent;
  position: absolute;
  bottom: -8px;
  left: 84px;
}
.gradio_wrapper .tui-image-editor-container .color-picker-control .tui-colorpicker-container, .gradio_wrapper .tui-image-editor-container .color-picker-control .tui-colorpicker-palette-container ul, .gradio_wrapper .tui-image-editor-container .color-picker-control .tui-colorpicker-palette-container {
  width: 100%;
  height: auto;
}
.gradio_wrapper .tui-image-editor-container .filter-color-item .color-picker-control label {
  font-color: #333;
  font-weight: normal;
  margin-right: 7pxleft;
}
.gradio_wrapper .tui-image-editor-container .filter-color-item .tui-image-editor-checkbox {
  margin-top: 0;
}
.gradio_wrapper .tui-image-editor-container .filter-color-item .tui-image-editor-checkbox input + label:before, .gradio_wrapper .tui-image-editor-container .filter-color-item .tui-image-editor-checkbox > label:before {
  left: -16px;
}
.gradio_wrapper .tui-image-editor-container .color-picker {
  width: 100%;
  height: auto;
}
.gradio_wrapper .tui-image-editor-container .color-picker-value {
  width: 32px;
  height: 32px;
  border: 0px;
  border-radius: 100%;
  margin: auto;
  margin-bottom: 1px;
}
.gradio_wrapper .tui-image-editor-container .color-picker-value.transparent {
  border: 1px solid #cbcbcb;
  background-size: cover;
  background-image: url("data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAACAAAAAgCAYAAABzenr0AAAAAXNSR0IArs4c6QAAAdBJREFUWAnFl0FuwjAQRZ0ukiugHqFSOQNdseuKW3ALzkA4BateICvUGyCxrtRFd4WuunH/TzykaYJrnLEYaTJJsP2+x8GZZCbQrLU5mj7Bn+EP8HvnCObd+R7xBV5lWfaNON4AnsA38E94qLEt+0yiFaBzAV/Bv+Cxxr4co7hKCDpw1q9wLeNYYdlAwyn8TYt8Hme3+8D5ozcTaMCZ68PXa2tnM2sbEcOZAJhrrpl2DAcTOGNjZPSfCdzkw6JrfbiMv+osBe4y9WOedhm4jZfhbENWuxS44H9Wz/xw4WzqLOAqh1+zycgAwzEMzr5k5gaHOa9ULBwuuDkFlHI1Kl4PJ66kgIpnoywOTmRFAYcbwYk9UMApWkD8zAV5ihcwHk4Rx7gl0IFTQL0EFc+CTQ9OZHWH3YhlVJiVpTHbrTGLhTHLZVgff6s9lyBsI9KduSS83oj+34rTwJutmBmCnMsvozRwZqB5GTkBw6/jdPDu69iJ6BYk6eCcfbcgcQIK/MByaaiMqm8rHcjol2TnpWDhyAKSGdA3FrxtJUToX0ODqatetfGE+8tyEUOV8GY5dGRwLP/MBS4RHQr4bT7NRAQjlcOTfZxmv2G+c4hI8nn+Ax5PG/zhI393AAAAAElFTkSuQmCC");
}
.gradio_wrapper .tui-image-editor-container .color-picker-value + label {
  color: #fff;
}
.gradio_wrapper .tui-image-editor-container .tui-image-editor-submenu svg > use {
  display: none;
}
.gradio_wrapper .tui-image-editor-container .tui-image-editor-submenu svg > use.normal {
  display: block;
}
.gradio_wrapper .tie-icon-add-button.icon-bubble .tui-image-editor-button[data-icontype="icon-bubble"] svg > use.active, .gradio_wrapper .tie-icon-add-button.icon-heart .tui-image-editor-button[data-icontype="icon-heart"] svg > use.active, .gradio_wrapper .tie-icon-add-button.icon-location .tui-image-editor-button[data-icontype="icon-location"] svg > use.active, .gradio_wrapper .tie-icon-add-button.icon-polygon .tui-image-editor-button[data-icontype="icon-polygon"] svg > use.active, .gradio_wrapper .tie-icon-add-button.icon-star .tui-image-editor-button[data-icontype="icon-star"] svg > use.active, .gradio_wrapper .tie-icon-add-button.icon-star-2 .tui-image-editor-button[data-icontype="icon-star-2"] svg > use.active, .gradio_wrapper .tie-icon-add-button.icon-arrow-3 .tui-image-editor-button[data-icontype="icon-arrow-3"] svg > use.active, .gradio_wrapper .tie-icon-add-button.icon-arrow-2 .tui-image-editor-button[data-icontype="icon-arrow-2"] svg > use.active, .gradio_wrapper .tie-icon-add-button.icon-arrow .tui-image-editor-button[data-icontype="icon-arrow"] svg > use.active {
  display: block;
}
.gradio_wrapper .tie-draw-line-select-button.line .tui-image-editor-button.line svg > use.normal, .gradio_wrapper .tie-draw-line-select-button.free .tui-image-editor-button.free svg > use.normal {
  display: none;
}
.gradio_wrapper .tie-draw-line-select-button.line .tui-image-editor-button.line svg > use.active, .gradio_wrapper .tie-draw-line-select-button.free .tui-image-editor-button.free svg > use.active {
  display: block;
}
.gradio_wrapper .tie-flip-button.resetFlip .tui-image-editor-button.resetFlip svg > use.normal, .gradio_wrapper .tie-flip-button.flipX .tui-image-editor-button.flipX svg > use.normal, .gradio_wrapper .tie-flip-button.flipY .tui-image-editor-button.flipY svg > use.normal {
  display: none;
}
.gradio_wrapper .tie-flip-button.resetFlip .tui-image-editor-button.resetFlip svg > use.active, .gradio_wrapper .tie-flip-button.flipX .tui-image-editor-button.flipX svg > use.active, .gradio_wrapper .tie-flip-button.flipY .tui-image-editor-button.flipY svg > use.active {
  display: block;
}
.gradio_wrapper .tie-mask-apply.apply.active .tui-image-editor-button.apply label {
  color: #fff;
}
.gradio_wrapper .tie-mask-apply.apply.active .tui-image-editor-button.apply svg > use.active {
  display: block;
}
.gradio_wrapper .tie-crop-button .tui-image-editor-button.apply, .gradio_wrapper .tie-crop-preset-button .tui-image-editor-button.apply {
  margin-right: 24px;
}
.gradio_wrapper .tie-crop-button .tui-image-editor-button.preset.active svg > use.active, .gradio_wrapper .tie-crop-preset-button .tui-image-editor-button.preset.active svg > use.active {
  display: block;
}
.gradio_wrapper .tie-crop-button .tui-image-editor-button.apply.active svg > use.active, .gradio_wrapper .tie-crop-preset-button .tui-image-editor-button.apply.active svg > use.active {
  display: block;
}
.gradio_wrapper .tie-shape-button.rect .tui-image-editor-button.rect svg > use.normal, .gradio_wrapper .tie-shape-button.circle .tui-image-editor-button.circle svg > use.normal, .gradio_wrapper .tie-shape-button.triangle .tui-image-editor-button.triangle svg > use.normal {
  display: none;
}
.gradio_wrapper .tie-shape-button.rect .tui-image-editor-button.rect svg > use.active, .gradio_wrapper .tie-shape-button.circle .tui-image-editor-button.circle svg > use.active, .gradio_wrapper .tie-shape-button.triangle .tui-image-editor-button.triangle svg > use.active {
  display: block;
}
.gradio_wrapper .tie-text-effect-button .tui-image-editor-button.active svg > use.active {
  display: block;
}
.gradio_wrapper .tie-text-align-button.left .tui-image-editor-button.left svg > use.active, .gradio_wrapper .tie-text-align-button.center .tui-image-editor-button.center svg > use.active, .gradio_wrapper .tie-text-align-button.right .tui-image-editor-button.right svg > use.active {
  display: block;
}
.gradio_wrapper .tie-mask-image-file, .gradio_wrapper .tie-icon-image-file {
  opacity: 0;
  position: absolute;
  width: 100%;
  height: 100%;
  border: 1px solid #008000;
  cursor: inherit;
  left: 0;
  top: 0;
}
.gradio_wrapper .tie-zoom-button.resetFlip .tui-image-editor-button.resetFlip svg > use.normal, .gradio_wrapper .tie-zoom-button.flipX .tui-image-editor-button.flipX svg > use.normal, .gradio_wrapper .tie-zoom-button.flipY .tui-image-editor-button.flipY svg > use.normal {
  display: none;
}
.gradio_wrapper .tie-zoom-button.resetFlip .tui-image-editor-button.resetFlip svg > use.active, .gradio_wrapper .tie-zoom-button.flipX .tui-image-editor-button.flipX svg > use.active, .gradio_wrapper .tie-zoom-button.flipY .tui-image-editor-button.flipY svg > use.active {
  display: block;
}
.gradio_wrapper .tui-image-editor-container.top.tui-image-editor-top-optimization .tui-image-editor-controls ul {
  text-align: right;
}
.gradio_wrapper .tui-image-editor-container.top.tui-image-editor-top-optimization .tui-image-editor-controls-logo {
  display: none;
}
/*!
 * Cropper.js v1.5.12
 * https://fengyuanchen.github.io/cropperjs
 *
 * Copyright 2015-present Chen Fengyuan
 * Released under the MIT license
 *
 * Date: 2021-06-12T08:00:11.623Z
 */

.gradio_wrapper .cropper-container {
  direction: ltr;
  font-size: 0;
  line-height: 0;
  position: relative;
  -ms-touch-action: none;
  touch-action: none;
  -webkit-user-select: none;
  -moz-user-select: none;
  -ms-user-select: none;
  user-select: none;
}

.gradio_wrapper .cropper-container img {
  display: block;
  height: 100%;
  image-orientation: 0deg;
  max-height: none !important;
  max-width: none !important;
  min-height: 0 !important;
  min-width: 0 !important;
  width: 100%;
}

.gradio_wrapper .cropper-wrap-box, .gradio_wrapper .cropper-canvas, .gradio_wrapper .cropper-drag-box, .gradio_wrapper .cropper-crop-box, .gradio_wrapper .cropper-modal {
  bottom: 0;
  left: 0;
  position: absolute;
  right: 0;
  top: 0;
}

.gradio_wrapper .cropper-wrap-box, .gradio_wrapper .cropper-canvas {
  overflow: hidden;
}

.gradio_wrapper .cropper-drag-box {
  background-color: #fff;
  opacity: 0;
}

.gradio_wrapper .cropper-modal {
  background-color: #000;
  opacity: 0.5;
}

.gradio_wrapper .cropper-view-box {
  display: block;
  height: 100%;
  outline: 1px solid #39f;
  outline-color: rgba(51, 153, 255, 0.75);
  overflow: hidden;
  width: 100%;
}

.gradio_wrapper .cropper-dashed {
  border: 0 dashed #eee;
  display: block;
  opacity: 0.5;
  position: absolute;
}

.gradio_wrapper .cropper-dashed.dashed-h {
  border-bottom-width: 1px;
  border-top-width: 1px;
  height: calc(100% / 3);
  left: 0;
  top: calc(100% / 3);
  width: 100%;
}

.gradio_wrapper .cropper-dashed.dashed-v {
  border-left-width: 1px;
  border-right-width: 1px;
  height: 100%;
  left: calc(100% / 3);
  top: 0;
  width: calc(100% / 3);
}

.gradio_wrapper .cropper-center {
  display: block;
  height: 0;
  left: 50%;
  opacity: 0.75;
  position: absolute;
  top: 50%;
  width: 0;
}

.gradio_wrapper .cropper-center::before, .gradio_wrapper .cropper-center::after {
  background-color: #eee;
  content: ' ';
  display: block;
  position: absolute;
}

.gradio_wrapper .cropper-center::before {
  height: 1px;
  left: -3px;
  top: 0;
  width: 7px;
}

.gradio_wrapper .cropper-center::after {
  height: 7px;
  left: 0;
  top: -3px;
  width: 1px;
}

.gradio_wrapper .cropper-face, .gradio_wrapper .cropper-line, .gradio_wrapper .cropper-point {
  display: block;
  height: 100%;
  opacity: 0.1;
  position: absolute;
  width: 100%;
}

.gradio_wrapper .cropper-face {
  background-color: #fff;
  left: 0;
  top: 0;
}

.gradio_wrapper .cropper-line {
  background-color: #39f;
}

.gradio_wrapper .cropper-line.line-e {
  cursor: ew-resize;
  right: -3px;
  top: 0;
  width: 5px;
}

.gradio_wrapper .cropper-line.line-n {
  cursor: ns-resize;
  height: 5px;
  left: 0;
  top: -3px;
}

.gradio_wrapper .cropper-line.line-w {
  cursor: ew-resize;
  left: -3px;
  top: 0;
  width: 5px;
}

.gradio_wrapper .cropper-line.line-s {
  bottom: -3px;
  cursor: ns-resize;
  height: 5px;
  left: 0;
}

.gradio_wrapper .cropper-point {
  background-color: #39f;
  height: 5px;
  opacity: 0.75;
  width: 5px;
}

.gradio_wrapper .cropper-point.point-e {
  cursor: ew-resize;
  margin-top: -3px;
  right: -3px;
  top: 50%;
}

.gradio_wrapper .cropper-point.point-n {
  cursor: ns-resize;
  left: 50%;
  margin-left: -3px;
  top: -3px;
}

.gradio_wrapper .cropper-point.point-w {
  cursor: ew-resize;
  left: -3px;
  margin-top: -3px;
  top: 50%;
}

.gradio_wrapper .cropper-point.point-s {
  bottom: -3px;
  cursor: s-resize;
  left: 50%;
  margin-left: -3px;
}

.gradio_wrapper .cropper-point.point-ne {
  cursor: nesw-resize;
  right: -3px;
  top: -3px;
}

.gradio_wrapper .cropper-point.point-nw {
  cursor: nwse-resize;
  left: -3px;
  top: -3px;
}

.gradio_wrapper .cropper-point.point-sw {
  bottom: -3px;
  cursor: nesw-resize;
  left: -3px;
}

.gradio_wrapper .cropper-point.point-se {
  bottom: -3px;
  cursor: nwse-resize;
  height: 20px;
  opacity: 1;
  right: -3px;
  width: 20px;
}

@media (min-width: 768px) {
  .gradio_wrapper .cropper-point.point-se {
    height: 15px;
    width: 15px;
  }
}

@media (min-width: 992px) {
  .gradio_wrapper .cropper-point.point-se {
    height: 10px;
    width: 10px;
  }
}

@media (min-width: 1200px) {
  .gradio_wrapper .cropper-point.point-se {
    height: 5px;
    opacity: 0.75;
    width: 5px;
  }
}

.gradio_wrapper .cropper-point.point-se::before {
  background-color: #39f;
  bottom: -50%;
  content: ' ';
  display: block;
  height: 200%;
  opacity: 0;
  position: absolute;
  right: -50%;
  width: 200%;
}

.gradio_wrapper .cropper-invisible {
  opacity: 0;
}

.gradio_wrapper .cropper-bg {
  background-image: url('data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAABAAAAAQAQMAAAAlPW0iAAAAA3NCSVQICAjb4U/gAAAABlBMVEXMzMz////TjRV2AAAACXBIWXMAAArrAAAK6wGCiw1aAAAAHHRFWHRTb2Z0d2FyZQBBZG9iZSBGaXJld29ya3MgQ1M26LyyjAAAABFJREFUCJlj+M/AgBVhF/0PAH6/D/HkDxOGAAAAAElFTkSuQmCC');
}

.gradio_wrapper .cropper-hide {
  display: block;
  height: 0;
  position: absolute;
  width: 0;
}

.gradio_wrapper .cropper-hidden {
  display: none !important;
}

.gradio_wrapper .cropper-move {
  cursor: move;
}

.gradio_wrapper .cropper-crop {
  cursor: crosshair;
}

.gradio_wrapper .cropper-disabled .cropper-drag-box, .gradio_wrapper .cropper-disabled .cropper-face, .gradio_wrapper .cropper-disabled .cropper-line, .gradio_wrapper .cropper-disabled .cropper-point {
  cursor: not-allowed;
}

.gradio_wrapper .gradio_bg{/*! tailwindcss v2.2.17 | MIT License | https://tailwindcss.com *//*! modern-normalize v1.1.0 | MIT License | https://github.com/sindresorhus/modern-normalize */-moz-tab-size:4;tab-size:4;line-height:1.15;-webkit-text-size-adjust:100%;margin:0;font-family:system-ui,-apple-system,"Segoe UI",Roboto,Helvetica,Arial,sans-serif,"Apple Color Emoji","Segoe UI Emoji";font-family:ui-sans-serif,system-ui,-apple-system,BlinkMacSystemFont,"Segoe UI",Roboto,"Helvetica Neue",Arial,"Noto Sans",sans-serif,"Apple Color Emoji","Segoe UI Emoji","Segoe UI Symbol","Noto Color Emoji";line-height:1.5}.gradio_wrapper .gradio_bg *, .gradio_wrapper .gradio_bg ::before, .gradio_wrapper .gradio_bg ::after{box-sizing:border-box}.gradio_wrapper .gradio_bg hr{height:0;color:inherit}.gradio_wrapper .gradio_bg abbr[title]{-webkit-text-decoration:underline dotted;text-decoration:underline dotted}.gradio_wrapper .gradio_bg b, .gradio_wrapper .gradio_bg strong{font-weight:bolder}.gradio_wrapper .gradio_bg code, .gradio_wrapper .gradio_bg kbd, .gradio_wrapper .gradio_bg samp, .gradio_wrapper .gradio_bg pre{font-family:ui-monospace,SFMono-Regular,Consolas,"Liberation Mono",Menlo,monospace;font-size:1em}.gradio_wrapper .gradio_bg small{font-size:80%}.gradio_wrapper .gradio_bg sub, .gradio_wrapper .gradio_bg sup{font-size:75%;line-height:0;position:relative;vertical-align:baseline}.gradio_wrapper .gradio_bg sub{bottom:-0.25em}.gradio_wrapper .gradio_bg sup{top:-0.5em}.gradio_wrapper .gradio_bg table{text-indent:0;border-color:inherit}.gradio_wrapper .gradio_bg button, .gradio_wrapper .gradio_bg input, .gradio_wrapper .gradio_bg optgroup, .gradio_wrapper .gradio_bg select, .gradio_wrapper .gradio_bg textarea{font-family:inherit;font-size:100%;line-height:1.15;margin:0}.gradio_wrapper .gradio_bg button, .gradio_wrapper .gradio_bg select{text-transform:none}.gradio_wrapper .gradio_bg button, .gradio_wrapper .gradio_bg [type=button], .gradio_wrapper .gradio_bg [type=reset], .gradio_wrapper .gradio_bg [type=submit]{-webkit-appearance:button}.gradio_wrapper .gradio_bg ::-moz-focus-inner{border-style:none;padding:0}.gradio_wrapper .gradio_bg :-moz-focusring{outline:1px dotted ButtonText}.gradio_wrapper .gradio_bg :-moz-ui-invalid{box-shadow:none}.gradio_wrapper .gradio_bg legend{padding:0}.gradio_wrapper .gradio_bg progress{vertical-align:baseline}.gradio_wrapper .gradio_bg ::-webkit-inner-spin-button, .gradio_wrapper .gradio_bg ::-webkit-outer-spin-button{height:auto}.gradio_wrapper .gradio_bg [type=search]{-webkit-appearance:textfield;outline-offset:-2px}.gradio_wrapper .gradio_bg ::-webkit-search-decoration{-webkit-appearance:none}.gradio_wrapper .gradio_bg ::-webkit-file-upload-button{-webkit-appearance:button;font:inherit}.gradio_wrapper .gradio_bg summary{display:list-item}.gradio_wrapper .gradio_bg blockquote, .gradio_wrapper .gradio_bg dl, .gradio_wrapper .gradio_bg dd, .gradio_wrapper .gradio_bg h1, .gradio_wrapper .gradio_bg h2, .gradio_wrapper .gradio_bg h3, .gradio_wrapper .gradio_bg h4, .gradio_wrapper .gradio_bg h5, .gradio_wrapper .gradio_bg h6, .gradio_wrapper .gradio_bg hr, .gradio_wrapper .gradio_bg figure, .gradio_wrapper .gradio_bg p, .gradio_wrapper .gradio_bg pre{margin:0}.gradio_wrapper .gradio_bg button{background-color:transparent;background-image:none}.gradio_wrapper .gradio_bg fieldset{margin:0;padding:0}.gradio_wrapper .gradio_bg ol, .gradio_wrapper .gradio_bg ul{list-style:none;margin:0;padding:0}.gradio_wrapper .gradio_bg *, .gradio_wrapper .gradio_bg ::before, .gradio_wrapper .gradio_bg ::after{box-sizing:border-box;border-width:0;border-style:solid;border-color:currentColor}.gradio_wrapper .gradio_bg hr{border-top-width:1px}.gradio_wrapper .gradio_bg img{border-style:solid}.gradio_wrapper .gradio_bg textarea{resize:vertical}.gradio_wrapper .gradio_bg input::-webkit-input-placeholder, .gradio_wrapper .gradio_bg textarea::-webkit-input-placeholder{opacity:1;color:#9ca3af}.gradio_wrapper .gradio_bg input:-ms-input-placeholder, .gradio_wrapper .gradio_bg textarea:-ms-input-placeholder{opacity:1;color:#9ca3af}.gradio_bg input::-webkit-input-placeholder, .gradio_bg textarea::-webkit-input-placeholder{opacity:1;color:#9ca3af}.gradio_bg input:-ms-input-placeholder, .gradio_bg textarea:-ms-input-placeholder{opacity:1;color:#9ca3af}.gradio_wrapper .gradio_bg input::placeholder, .gradio_wrapper .gradio_bg textarea::placeholder{opacity:1;color:#9ca3af}.gradio_wrapper .gradio_bg button, .gradio_wrapper .gradio_bg [role=button]{cursor:pointer}.gradio_wrapper .gradio_bg :-moz-focusring{outline:auto}.gradio_wrapper .gradio_bg table{border-collapse:collapse}.gradio_wrapper .gradio_bg h1, .gradio_wrapper .gradio_bg h2, .gradio_wrapper .gradio_bg h3, .gradio_wrapper .gradio_bg h4, .gradio_wrapper .gradio_bg h5, .gradio_wrapper .gradio_bg h6{font-size:inherit;font-weight:inherit}.gradio_wrapper .gradio_bg a{color:inherit;text-decoration:inherit}.gradio_wrapper .gradio_bg button, .gradio_wrapper .gradio_bg input, .gradio_wrapper .gradio_bg optgroup, .gradio_wrapper .gradio_bg select, .gradio_wrapper .gradio_bg textarea{padding:0;line-height:inherit;color:inherit}.gradio_wrapper .gradio_bg pre, .gradio_wrapper .gradio_bg code, .gradio_wrapper .gradio_bg kbd, .gradio_wrapper .gradio_bg samp{font-family:ui-monospace,SFMono-Regular,Menlo,Monaco,Consolas,"Liberation Mono","Courier New",monospace}.gradio_wrapper .gradio_bg img, .gradio_wrapper .gradio_bg svg, .gradio_wrapper .gradio_bg video, .gradio_wrapper .gradio_bg canvas, .gradio_wrapper .gradio_bg audio, .gradio_wrapper .gradio_bg iframe, .gradio_wrapper .gradio_bg embed, .gradio_wrapper .gradio_bg object{display:block;vertical-align:middle}.gradio_wrapper .gradio_bg img, .gradio_wrapper .gradio_bg video{max-width:100%;height:auto}.gradio_wrapper .gradio_bg [hidden]{display:none}.gradio_wrapper .gradio_bg *, .gradio_wrapper .gradio_bg ::before, .gradio_wrapper .gradio_bg ::after{--tw-border-opacity: 1;border-color:rgba(229, 231, 235, var(--tw-border-opacity))}.container{width:100%}@media (min-width: 640px){.container{max-width:640px}}@media (min-width: 768px){.container{max-width:768px}}@media (min-width: 1024px){.container{max-width:1024px}}@media (min-width: 1280px){.container{max-width:1280px}}@media (min-width: 1536px){.container{max-width:1536px}}.prose{color:#374151;max-width:65ch;}.prose [class~="lead"]{color:#4b5563;font-size:1.25em;line-height:1.6;margin-top:1.2em;margin-bottom:1.2em}.prose a{color:#111827;text-decoration:underline;font-weight:500}.prose strong{color:#111827;font-weight:600}.prose ol[type="A"]{--list-counter-style:upper-alpha}.prose ol[type="a"]{--list-counter-style:lower-alpha}.prose ol[type="A" s]{--list-counter-style:upper-alpha}.prose ol[type="a" s]{--list-counter-style:lower-alpha}.prose ol[type="I"]{--list-counter-style:upper-roman}.prose ol[type="i"]{--list-counter-style:lower-roman}.prose ol[type="I" s]{--list-counter-style:upper-roman}.prose ol[type="i" s]{--list-counter-style:lower-roman}.prose ol[type="1"]{--list-counter-style:decimal}.prose ol > li{position:relative;padding-left:1.75em}.prose ol > li::before{content:counter(list-item, var(--list-counter-style, decimal)) ".";position:absolute;font-weight:400;color:#6b7280;left:0}.prose ul > li{position:relative;padding-left:1.75em}.prose ul > li::before{content:"";position:absolute;background-color:#d1d5db;border-radius:50%;width:0.375em;height:0.375em;top:calc(0.875em - 0.1875em);left:0.25em}.prose hr{border-color:#e5e7eb;border-top-width:1px;margin-top:3em;margin-bottom:3em}.prose blockquote{font-weight:500;font-style:italic;color:#111827;border-left-width:0.25rem;border-left-color:#e5e7eb;quotes:"\201C""\201D""\2018""\2019";margin-top:1.6em;margin-bottom:1.6em;padding-left:1em}.prose blockquote p:first-of-type::before{content:open-quote}.prose blockquote p:last-of-type::after{content:close-quote}.prose h1{color:#111827;font-weight:semibold;font-size:2.25em;margin-top:0;margin-bottom:0.8888889em;line-height:1.1111111}.prose h2{color:#111827;font-weight:semibold;font-size:1.5em;margin-top:2em;margin-bottom:1em;line-height:1.3333333}.prose h3{color:#111827;font-weight:semibold;font-size:1.25em;margin-top:1.6em;margin-bottom:0.6em;line-height:1.6}.prose h4{color:#111827;font-weight:semibold;margin-top:1.5em;margin-bottom:0.5em;line-height:1.5}.prose figure figcaption{color:#6b7280;font-size:0.875em;line-height:1.4285714;margin-top:0.8571429em}.prose code{color:#111827;font-weight:600;font-size:0.875em}.prose code::before{content:"`"}.prose code::after{content:"`"}.prose a code{color:#111827}.prose pre{color:#e5e7eb;background-color:#1f2937;overflow-x:auto;font-size:0.875em;line-height:1.7142857;margin-top:1.7142857em;margin-bottom:1.7142857em;border-radius:0.375rem;padding-top:0.8571429em;padding-right:1.1428571em;padding-bottom:0.8571429em;padding-left:1.1428571em}.prose pre code{background-color:transparent;border-width:0;border-radius:0;padding:0;font-weight:400;color:inherit;font-size:inherit;font-family:inherit;line-height:inherit}.prose pre code::before{content:none}.prose pre code::after{content:none}.prose table{width:100%;table-layout:auto;text-align:left;margin-top:2em;margin-bottom:2em;font-size:0.875em;line-height:1.7142857}.prose thead{color:#111827;font-weight:600;border-bottom-width:1px;border-bottom-color:#d1d5db}.prose thead th{vertical-align:bottom;padding-right:0.5714286em;padding-bottom:0.5714286em;padding-left:0.5714286em}.prose tbody tr{border-bottom-width:1px;border-bottom-color:#e5e7eb}.prose tbody tr:last-child{border-bottom-width:0}.prose tbody td{vertical-align:top;padding-top:0.5714286em;padding-right:0.5714286em;padding-bottom:0.5714286em;padding-left:0.5714286em}.prose{font-size:1rem;line-height:1.75}.prose p{margin-top:1.25em;margin-bottom:1.25em}.prose img{margin-top:2em;margin-bottom:2em}.prose video{margin-top:2em;margin-bottom:2em}.prose figure{margin-top:2em;margin-bottom:2em}.prose figure > *{margin-top:0;margin-bottom:0}.prose h2 code{font-size:0.875em}.prose h3 code{font-size:0.9em}.prose ol{margin-top:1.25em;margin-bottom:1.25em}.prose ul{margin-top:1.25em;margin-bottom:1.25em}.prose li{margin-top:0.5em;margin-bottom:0.5em}.prose > ul > li p{margin-top:0.75em;margin-bottom:0.75em}.prose > ul > li > *:first-child{margin-top:1.25em}.prose > ul > li > *:last-child{margin-bottom:1.25em}.prose > ol > li > *:first-child{margin-top:1.25em}.prose > ol > li > *:last-child{margin-bottom:1.25em}.prose ul ul, .prose ul ol, .prose ol ul, .prose ol ol{margin-top:0.75em;margin-bottom:0.75em}.prose hr + *{margin-top:0}.prose h2 + *{margin-top:0}.prose h3 + *{margin-top:0}.prose h4 + *{margin-top:0}.prose thead th:first-child{padding-left:0}.prose thead th:last-child{padding-right:0}.prose tbody td:first-child{padding-left:0}.prose tbody td:last-child{padding-right:0}.prose > :first-child{margin-top:0}.prose > :last-child{margin-bottom:0}.prose h5{font-weight:semibold}.prose h6{font-weight:semibold}.static{position:static}.relative{position:relative}.flex{display:flex}.table{display:table}.transform{-webkit-transform:var(--tw-transform);transform:var(--tw-transform)}.resize{resize:both}.flex-col{flex-direction:column}.opacity-50{opacity:0.5}.filter{-webkit-filter:var(--tw-filter);filter:var(--tw-filter)}.gradio_wrapper .gradio_bg{display:flex;flex-direction:column}.dark .gradio_wrapper .gradio_bg{--tw-bg-opacity:1;background-color:rgba(75, 85, 99, var(--tw-bg-opacity))}.gradio_wrapper .gradio_page{width:100%}@media (min-width: 640px){.gradio_wrapper .gradio_page{max-width:640px}}@media (min-width: 768px){.gradio_wrapper .gradio_page{max-width:768px}}@media (min-width: 1024px){.gradio_wrapper .gradio_page{max-width:1024px}}@media (min-width: 1280px){.gradio_wrapper .gradio_page{max-width:1280px}}@media (min-width: 1536px){.gradio_wrapper .gradio_page{max-width:1536px}}.gradio_wrapper .gradio_page{margin-left:auto;margin-right:auto;box-sizing:border-box;display:flex;flex-grow:1;flex-direction:column;--tw-text-opacity:1;color:rgba(55, 65, 81, var(--tw-text-opacity))}.dark .gradio_wrapper .gradio_page{--tw-text-opacity:1;color:rgba(249, 250, 251, var(--tw-text-opacity))}.gradio_wrapper .gradio_page .title{padding:1rem;text-align:center;font-size:2.25rem;line-height:2.5rem}.gradio_wrapper .gradio_page .description{padding-bottom:1rem}.gradio_wrapper .gradio_page .article{max-width:none;padding-top:2rem;padding-bottom:1rem}.dark .gradio_wrapper .gradio_page .article{--tw-text-opacity:1;color:rgba(249, 250, 251, var(--tw-text-opacity))}.gradio_wrapper .gradio_page .content{margin-bottom:1rem;padding-left:1rem;padding-right:1rem;padding-top:1rem}.gradio_wrapper .gradio_page .api{display:inline-flex;flex-shrink:0;align-items:center;justify-content:flex-end;gap:0.25rem;padding-top:0.5rem;padding-bottom:0.5rem;--tw-text-opacity:1;color:rgba(156, 163, 175, var(--tw-text-opacity))}.gradio_wrapper .gradio_page .logo{display:inline-block;height:1.5rem}.gradio_wrapper .gradio_page .api-logo{display:inline;height:1.25rem}.gradio_wrapper .gradio_bg[is_embedded=true] .gradio_page{border-radius:0.25rem;border-width:2px;--tw-border-opacity:1;border-color:rgba(243, 244, 246, var(--tw-border-opacity));--tw-shadow:0 10px 15px -3px rgba(0, 0, 0, 0.1), 0 4px 6px -2px rgba(0, 0, 0, 0.05);box-shadow:var(--tw-ring-offset-shadow, 0 0 #0000), var(--tw-ring-shadow, 0 0 #0000), var(--tw-shadow)}.gradio_wrapper .gradio_bg[is_embedded=true] .gradio_page .footer{border-bottom-right-radius:0.25rem;border-bottom-left-radius:0.25rem;--tw-bg-opacity:1;background-color:rgba(243, 244, 246, var(--tw-bg-opacity));padding:1rem}.gradio_wrapper .gradio_bg[is_embedded=true] .gradio_page .footer a{font-weight:600}.gradio_wrapper .gradio_bg[is_embedded=false]{min-height:100%}.gradio_wrapper .gradio_bg[is_embedded=false] .gradio_page{height:100%}.gradio_wrapper .gradio_bg[is_embedded=false] .gradio_page .content{flex-shrink:0;flex-grow:1;padding-left:1rem;padding-right:1rem;padding-top:1rem}.gradio_wrapper .gradio_bg[is_embedded=false] .gradio_page .footer{display:inline-flex;flex-shrink:0;align-items:center;justify-content:center;gap:0.625rem;padding-top:0.5rem;padding-bottom:0.5rem;--tw-text-opacity:1;color:rgba(156, 163, 175, var(--tw-text-opacity))}.gradio_wrapper .gradio_interface .load_status{position:absolute;right:0.5rem;display:flex;align-items:center;gap:0.5rem;font-size:0.875rem;line-height:1.25rem}.gradio_wrapper .gradio_interface .load_status img{margin-left:0.5rem;display:inline-block;height:1.25rem}.gradio_wrapper .gradio_interface .load_status .loading{-webkit-animation:ld-breath .75s infinite linear;animation:ld-breath .75s infinite linear}@-webkit-keyframes ld-breath{0%{-webkit-animation-timing-function:cubic-bezier(0.9647, 0.2413, -0.0705, 0.7911);animation-timing-function:cubic-bezier(0.9647, 0.2413, -0.0705, 0.7911);-webkit-transform:scale(0.9);transform:scale(0.9)}51%{-webkit-animation-timing-function:cubic-bezier(0.9226, 0.2631, -0.0308, 0.7628);animation-timing-function:cubic-bezier(0.9226, 0.2631, -0.0308, 0.7628);-webkit-transform:scale(1.2);transform:scale(1.2)}100%{-webkit-transform:scale(0.9);transform:scale(0.9)}}@keyframes ld-breath{0%{-webkit-animation-timing-function:cubic-bezier(0.9647, 0.2413, -0.0705, 0.7911);animation-timing-function:cubic-bezier(0.9647, 0.2413, -0.0705, 0.7911);-webkit-transform:scale(0.9);transform:scale(0.9)}51%{-webkit-animation-timing-function:cubic-bezier(0.9226, 0.2631, -0.0308, 0.7628);animation-timing-function:cubic-bezier(0.9226, 0.2631, -0.0308, 0.7628);-webkit-transform:scale(1.2);transform:scale(1.2)}100%{-webkit-transform:scale(0.9);transform:scale(0.9)}}.gradio_wrapper .gradio_interface .panels{display:flex;flex-wrap:wrap;justify-content:center;gap:1rem}.gradio_wrapper .gradio_interface .panels.unaligned{flex-direction:column;align-items:stretch}@media (min-width: 640px){.gradio_wrapper .gradio_interface .panels.unaligned{flex-direction:row}.gradio_wrapper .gradio_interface .panels.unaligned{align-items:flex-start}}.gradio_wrapper .gradio_interface .panels.horizontal{flex-direction:column;align-items:stretch}@media (min-width: 640px){.gradio_wrapper .gradio_interface .panels.horizontal{flex-direction:row}}.gradio_wrapper .gradio_interface .panels.vertical{flex-direction:column;align-items:stretch}.gradio_wrapper .gradio_interface .panel{flex:1 1 0%}.gradio_wrapper .gradio_interface .component_set{display:flex;flex:1 1 0%;flex-direction:column;gap:0.5rem;border-radius:0.25rem;padding:0.5rem;min-height:36px}.gradio_wrapper .gradio_interface .panel_header{margin-bottom:0.375rem}.gradio_wrapper .gradio_interface .panel_button{flex:1 1 0%;border-radius:0.25rem;--tw-bg-opacity:1;background-color:rgba(249, 250, 251, var(--tw-bg-opacity));padding:0.75rem;font-weight:600;transition-property:background-color, border-color, color, fill, stroke, opacity, box-shadow, -webkit-transform, -webkit-filter, -webkit-backdrop-filter;transition-property:background-color, border-color, color, fill, stroke, opacity, box-shadow, transform, filter, backdrop-filter;transition-property:background-color, border-color, color, fill, stroke, opacity, box-shadow, transform, filter, backdrop-filter, -webkit-transform, -webkit-filter, -webkit-backdrop-filter;transition-timing-function:cubic-bezier(0.4, 0, 0.2, 1);transition-duration:150ms}.gradio_wrapper .gradio_interface .panel_button:focus{outline:2px solid transparent;outline-offset:2px}.dark .gradio_wrapper .gradio_interface .panel_button{--tw-bg-opacity:1;background-color:rgba(55, 65, 81, var(--tw-bg-opacity))}.gradio_wrapper .gradio_interface .panel_buttons{margin-top:1rem;margin-bottom:1rem;display:flex;gap:1rem}.gradio_wrapper .gradio_interface .flag{position:relative}.gradio_wrapper .gradio_interface .flag .dropcontent{position:absolute;top:2rem;left:0px;display:none;width:100%;border-width:2px;--tw-border-opacity:1;border-color:rgba(229, 231, 235, var(--tw-border-opacity));--tw-bg-opacity:1;background-color:rgba(255, 255, 255, var(--tw-bg-opacity))}.dark .gradio_wrapper .gradio_interface .flag .dropcontent{border-style:none;--tw-bg-opacity:1;background-color:rgba(107, 114, 128, var(--tw-bg-opacity))}.gradio_wrapper .gradio_interface .flag .dropcontent div{padding:0.5rem}.gradio_wrapper .gradio_interface .flag .dropcontent div:hover{--tw-bg-opacity:1;background-color:rgba(243, 244, 246, var(--tw-bg-opacity))}.gradio_wrapper .gradio_interface .flag:hover:not(.disabled) .dropcontent{display:block}.gradio_wrapper .gradio_interface .examples h4{margin-top:0.5rem;margin-bottom:0.5rem;font-size:1.125rem;line-height:1.75rem;font-weight:600}.gradio_wrapper .gradio_interface .examples .examples_table_holder{margin-top:1rem;display:inline-block;max-width:100%;overflow-x:auto}.gradio_wrapper .gradio_interface .examples .examples_table_holder:not(.gallery) .examples_table{max-width:100%;table-layout:auto;border-collapse:collapse;border-radius:0.25rem;--tw-bg-opacity:1;background-color:rgba(249, 250, 251, var(--tw-bg-opacity));padding:0.5rem}.dark .gradio_wrapper .gradio_interface .examples .examples_table_holder:not(.gallery) .examples_table{--tw-bg-opacity:1;background-color:rgba(75, 85, 99, var(--tw-bg-opacity))}.gradio_wrapper .gradio_interface .examples .examples_table_holder:not(.gallery) .examples_table tbody tr{cursor:pointer;transition-property:background-color, border-color, color, fill, stroke, opacity, box-shadow, -webkit-transform, -webkit-filter, -webkit-backdrop-filter;transition-property:background-color, border-color, color, fill, stroke, opacity, box-shadow, transform, filter, backdrop-filter;transition-property:background-color, border-color, color, fill, stroke, opacity, box-shadow, transform, filter, backdrop-filter, -webkit-transform, -webkit-filter, -webkit-backdrop-filter;transition-timing-function:cubic-bezier(0.4, 0, 0.2, 1);transition-duration:150ms}.gradio_wrapper .gradio_interface .examples .examples_table_holder:not(.gallery) .examples_table thead{border-bottom-width:2px}.dark .gradio_wrapper .gradio_interface .examples .examples_table_holder:not(.gallery) .examples_table thead{--tw-border-opacity:1;border-color:rgba(75, 85, 99, var(--tw-border-opacity))}.gradio_wrapper .gradio_interface .examples .examples_table_holder:not(.gallery) .examples_table tbody tr.selected{font-weight:700}.gradio_wrapper .gradio_interface .examples .examples_table_holder:not(.gallery) .examples_table td, .gradio_wrapper .gradio_interface .examples .examples_table_holder:not(.gallery) .examples_table th{padding-top:0.5rem;padding-bottom:0.5rem;padding-left:1rem;padding-right:1rem}.gradio_wrapper .gradio_interface .examples .examples_table_holder.gallery .examples_table{display:block}.gradio_wrapper .gradio_interface .examples .examples_table_holder.gallery .examples_table tbody{display:flex;flex-wrap:wrap;gap:0.5rem}.gradio_wrapper .gradio_interface .examples .examples_table_holder.gallery .examples_table thead{display:none}.gradio_wrapper .gradio_interface .examples .examples_table_holder.gallery .examples_table tbody tr.selected{font-weight:700}.gradio_wrapper .gradio_interface .examples .examples_table_holder.gallery .examples_table td{cursor:pointer;border-radius:0.25rem;--tw-bg-opacity:1;background-color:rgba(249, 250, 251, var(--tw-bg-opacity));padding:0.5rem;transition-property:background-color, border-color, color, fill, stroke, opacity, box-shadow, -webkit-transform, -webkit-filter, -webkit-backdrop-filter;transition-property:background-color, border-color, color, fill, stroke, opacity, box-shadow, transform, filter, backdrop-filter;transition-property:background-color, border-color, color, fill, stroke, opacity, box-shadow, transform, filter, backdrop-filter, -webkit-transform, -webkit-filter, -webkit-backdrop-filter;transition-timing-function:cubic-bezier(0.4, 0, 0.2, 1);transition-duration:150ms}.dark .gradio_wrapper .gradio_interface .examples .examples_table_holder.gallery .examples_table td{--tw-bg-opacity:1;background-color:rgba(55, 65, 81, var(--tw-bg-opacity))}.gradio_wrapper .gradio_interface .examples .pages{margin-top:0.5rem;display:flex;align-items:center;gap:0.25rem}.gradio_wrapper .gradio_interface .examples .page{border-radius:0.25rem;--tw-bg-opacity:1;background-color:rgba(243, 244, 246, var(--tw-bg-opacity));padding-left:0.5rem;padding-right:0.5rem;padding-top:0.25rem;padding-bottom:0.25rem}.dark .gradio_wrapper .gradio_interface .examples .page{--tw-bg-opacity:1;background-color:rgba(55, 65, 81, var(--tw-bg-opacity))}.gradio_wrapper .gradio_interface .examples .page.selected{--tw-bg-opacity:1;background-color:rgba(229, 231, 235, var(--tw-bg-opacity))}.dark .gradio_wrapper .gradio_interface .examples .page.selected{--tw-bg-opacity:1;background-color:rgba(31, 41, 55, var(--tw-bg-opacity))}.gradio_wrapper .gradio_interface .upload_zone{display:flex;height:100%;width:100%;cursor:pointer;align-items:center;justify-content:center;border-width:8px;border-style:dashed;--tw-border-opacity:1;border-color:rgba(209, 213, 219, var(--tw-border-opacity));text-align:center;font-size:1.875rem;line-height:2.25rem;line-height:2.5rem;--tw-text-opacity:1;color:rgba(156, 163, 175, var(--tw-text-opacity))}.dark .gradio_wrapper .gradio_interface .upload_zone{--tw-border-opacity:1;border-color:rgba(107, 114, 128, var(--tw-border-opacity));--tw-text-opacity:1;color:rgba(107, 114, 128, var(--tw-text-opacity))}.gradio_wrapper .gradio_interface .edit_buttons{position:absolute;top:0px;right:0px;z-index:10}.gradio_wrapper .gradio_interface .edit_buttons img{height:1rem;-webkit-filter:var(--tw-filter);filter:var(--tw-filter)}.dark .gradio_wrapper .gradio_interface .edit_buttons img{--tw-invert:invert(100%);-webkit-filter:var(--tw-filter);filter:var(--tw-filter)}.gradio_wrapper .gradio_interface .edit_button{--tw-bg-opacity:0.3;padding:0.25rem;transition-property:background-color, border-color, color, fill, stroke, opacity, box-shadow, -webkit-transform, -webkit-filter, -webkit-backdrop-filter;transition-property:background-color, border-color, color, fill, stroke, opacity, box-shadow, transform, filter, backdrop-filter;transition-property:background-color, border-color, color, fill, stroke, opacity, box-shadow, transform, filter, backdrop-filter, -webkit-transform, -webkit-filter, -webkit-backdrop-filter;transition-timing-function:cubic-bezier(0.4, 0, 0.2, 1);transition-duration:150ms}.gradio_wrapper .gradio_interface .edit_button:hover{--tw-bg-opacity:1}.gradio_wrapper .gradio_interface .clear_button{--tw-bg-opacity:0.3;padding:0.25rem;transition-property:background-color, border-color, color, fill, stroke, opacity, box-shadow, -webkit-transform, -webkit-filter, -webkit-backdrop-filter;transition-property:background-color, border-color, color, fill, stroke, opacity, box-shadow, transform, filter, backdrop-filter;transition-property:background-color, border-color, color, fill, stroke, opacity, box-shadow, transform, filter, backdrop-filter, -webkit-transform, -webkit-filter, -webkit-backdrop-filter;transition-timing-function:cubic-bezier(0.4, 0, 0.2, 1);transition-duration:150ms}.gradio_wrapper .gradio_interface .clear_button:hover{--tw-bg-opacity:1}.gradio_wrapper .gradio_interface .input_text textarea{box-sizing:border-box;width:100%;resize:none;border-radius:0.25rem;padding:0.5rem}.gradio_wrapper .gradio_interface .input_text textarea:focus{outline:2px solid transparent;outline-offset:2px}.gradio_wrapper .gradio_interface .input_text input{box-sizing:border-box;width:100%;border-radius:0.25rem;padding:0.5rem}.gradio_wrapper .gradio_interface .input_text input:focus{outline:2px solid transparent;outline-offset:2px}.gradio_wrapper .gradio_interface .input_text .interpretation .interpretation_box{display:inline-block;white-space:pre-wrap}.gradio_wrapper .gradio_interface .input_number input{box-sizing:border-box;width:100%;border-radius:0.25rem;padding:0.5rem}.gradio_wrapper .gradio_interface .input_number input:focus{outline:2px solid transparent;outline-offset:2px}.gradio_wrapper .gradio_interface .input_number .interpretation{display:flex;height:1.5rem}.gradio_wrapper .gradio_interface .input_number .interpretation .interpretation_box{flex-grow:1}.gradio_wrapper .gradio_interface .input_image{position:relative;height:20rem;width:100%}.gradio_wrapper .gradio_interface .input_image .image_preview_holder{position:relative;display:flex;height:100%;width:100%;align-items:center;justify-content:center;--tw-bg-opacity:1;background-color:rgba(229, 231, 235, var(--tw-bg-opacity))}.dark .gradio_wrapper .gradio_interface .input_image .image_preview_holder{--tw-bg-opacity:1;background-color:rgba(75, 85, 99, var(--tw-bg-opacity))}.gradio_wrapper .gradio_interface .input_image .image_editor{position:fixed;top:0px;left:0px;z-index:40;display:flex;height:100vh;width:100vw;flex-direction:column;align-items:center;justify-content:center;--tw-bg-opacity:1;background-color:rgba(0, 0, 0, var(--tw-bg-opacity));--tw-bg-opacity:0.5}.gradio_wrapper .gradio_interface .input_image .image_editor .image_editor_buttons{width:800px;display:flex;justify-content:flex-end;gap:0.25rem}.gradio_wrapper .gradio_interface .input_image .image_editor .image_editor_buttons button{border-top-left-radius:0.25rem;border-top-right-radius:0.25rem;--tw-bg-opacity:1;background-color:rgba(0, 0, 0, var(--tw-bg-opacity));padding-left:0.5rem;padding-right:0.5rem;padding-top:0.25rem;padding-bottom:0.25rem;font-size:1.25rem;line-height:1.75rem;font-weight:600;--tw-text-opacity:1;color:rgba(255, 255, 255, var(--tw-text-opacity))}.gradio_wrapper .gradio_interface .input_image .image_editor .tui-image-editor-header-buttons{display:none}.gradio_wrapper .gradio_interface .input_image .image_editor .tui-colorpicker-palette-button{width:12px;height:12px}.gradio_wrapper .gradio_interface .input_image .image_preview, .gradio_wrapper .gradio_interface .input_image video{height:100%;width:100%;object-fit:contain}.gradio_wrapper .gradio_interface .input_image .sketch>div{--tw-bg-opacity:1;background-color:rgba(255, 255, 255, var(--tw-bg-opacity))}.gradio_wrapper .gradio_interface .input_image .snapshot{position:absolute;bottom:1rem;width:100%;padding-top:0.75rem;padding-bottom:0.75rem;text-align:center;font-size:1.125rem;line-height:1.75rem;font-weight:700}.gradio_wrapper .gradio_interface .input_image .snapshot button{display:inline-block;border-radius:0.25rem;--tw-bg-opacity:1;background-color:rgba(255, 255, 255, var(--tw-bg-opacity));padding:0.5rem;font-weight:600;opacity:0.8;transition-property:background-color, border-color, color, fill, stroke, opacity, box-shadow, -webkit-transform, -webkit-filter, -webkit-backdrop-filter;transition-property:background-color, border-color, color, fill, stroke, opacity, box-shadow, transform, filter, backdrop-filter;transition-property:background-color, border-color, color, fill, stroke, opacity, box-shadow, transform, filter, backdrop-filter, -webkit-transform, -webkit-filter, -webkit-backdrop-filter;transition-timing-function:cubic-bezier(0.4, 0, 0.2, 1);transition-duration:150ms}.gradio_wrapper .gradio_interface .input_image .snapshot button:hover{opacity:1}.dark .gradio_wrapper .gradio_interface .input_image .snapshot button{--tw-bg-opacity:1;background-color:rgba(75, 85, 99, var(--tw-bg-opacity))}.gradio_wrapper .gradio_interface .input_image .interpretation{position:absolute;top:0px;left:0px;display:flex;height:100%;width:100%;align-items:center;justify-content:center;opacity:0.9;transition-property:background-color, border-color, color, fill, stroke, opacity, box-shadow, -webkit-transform, -webkit-filter, -webkit-backdrop-filter;transition-property:background-color, border-color, color, fill, stroke, opacity, box-shadow, transform, filter, backdrop-filter;transition-property:background-color, border-color, color, fill, stroke, opacity, box-shadow, transform, filter, backdrop-filter, -webkit-transform, -webkit-filter, -webkit-backdrop-filter;transition-timing-function:cubic-bezier(0.4, 0, 0.2, 1);transition-duration:150ms}.gradio_wrapper .gradio_interface .input_image .interpretation:hover{opacity:0.2}.gradio_wrapper .gradio_interface .input_image_example{height:6rem;max-width:none}.gradio_wrapper .gradio_interface .input_radio{display:flex;flex-wrap:wrap;gap:0.5rem}.gradio_wrapper .gradio_interface .input_radio .radio_item{display:flex;cursor:pointer;align-items:center;gap:0.5rem;border-radius:0.25rem;padding-top:0.5rem;padding-bottom:0.5rem;padding-left:0.75rem;padding-right:0.75rem;font-weight:600}.gradio_wrapper .gradio_interface .input_radio .radio_circle{box-sizing:border-box;height:1rem;width:1rem;border-radius:9999px}.gradio_wrapper .gradio_interface .input_checkbox_group, .gradio_wrapper .gradio_interface .input_checkbox{display:flex;flex-wrap:wrap;gap:0.5rem}.gradio_wrapper .gradio_interface .input_checkbox_group .checkbox_item, .gradio_wrapper .gradio_interface .input_checkbox .checkbox_item{display:flex;cursor:pointer;align-items:center;gap:0.5rem;border-radius:0.25rem;padding-top:0.5rem;padding-bottom:0.5rem;padding-left:0.75rem;padding-right:0.75rem;font-weight:600}.gradio_wrapper .gradio_interface .input_checkbox_group .checkbox, .gradio_wrapper .gradio_interface .input_checkbox .checkbox{display:flex;height:1rem;width:1rem;align-items:center;justify-content:center;--tw-bg-opacity:1;background-color:rgba(255, 255, 255, var(--tw-bg-opacity))}.gradio_wrapper .gradio_interface .input_checkbox_group .checkbox .check, .gradio_wrapper .gradio_interface .input_checkbox .checkbox .check{display:none;height:0.75rem;width:1rem}.gradio_wrapper .gradio_interface .input_checkbox_group .selected .checkbox .check, .gradio_wrapper .gradio_interface .input_checkbox .selected .checkbox .check{display:block}.gradio_wrapper .gradio_interface .input_checkbox_group .check line, .gradio_wrapper .gradio_interface .input_checkbox .check line{stroke:#fff;stroke-width:4;stroke-linecap:round}.gradio_wrapper .gradio_interface .input_checkbox_group .interpretation, .gradio_wrapper .gradio_interface .input_checkbox .interpretation{display:flex}.gradio_wrapper .gradio_interface .input_checkbox_group .interpretation .interpretation_box, .gradio_wrapper .gradio_interface .input_checkbox .interpretation .interpretation_box{height:1rem;width:1rem;flex-grow:1}.gradio_wrapper .gradio_interface .input_checkbox_group .interpretation .interpret_check, .gradio_wrapper .gradio_interface .input_checkbox .interpretation .interpret_check{height:100%;width:100%}.gradio_wrapper .gradio_interface .input_checkbox_group .interpretation .interpret_check line, .gradio_wrapper .gradio_interface .input_checkbox .interpretation .interpret_check line{stroke:gray;stroke-width:4;stroke-linecap:round}.gradio_wrapper .gradio_interface .input_dropdown{position:relative;display:inline-block}.gradio_wrapper .gradio_interface .input_dropdown .dropdown{position:relative;display:inline-block}.gradio_wrapper .gradio_interface .input_dropdown .selector{display:inline-flex;align-items:center;border-radius:0.25rem;padding-top:0.5rem;padding-bottom:0.5rem;padding-left:0.75rem;padding-right:0.75rem;font-weight:600}.gradio_wrapper .gradio_interface .input_dropdown .caret{margin-left:0.5rem;height:1rem;width:1rem;fill:currentColor}.gradio_wrapper .gradio_interface .input_dropdown .dropdown_menu_holder{position:absolute;z-index:10;display:none;background-image:none;padding-top:0.25rem}.gradio_wrapper .gradio_interface .input_dropdown .dropdown_menu{max-height:20rem;overflow-y:auto}.gradio_wrapper .gradio_interface .input_dropdown .dropdown_item:first-child{border-top-left-radius:0.25rem;border-top-right-radius:0.25rem}.gradio_wrapper .gradio_interface .input_dropdown .dropdown_item{display:block;cursor:pointer;white-space:nowrap;padding-top:0.5rem;padding-bottom:0.5rem;padding-left:0.75rem;padding-right:0.75rem}.gradio_wrapper .gradio_interface .input_dropdown .dropdown_item:last-child{border-bottom-right-radius:0.25rem;border-bottom-left-radius:0.25rem}.gradio_wrapper .gradio_interface .input_dropdown :hover .dropdown_menu_holder{display:block}.gradio_wrapper .gradio_interface .input_dropdown .interpretation_box{padding:0.25rem}.gradio_wrapper .gradio_interface .input_slider{text-align:center}.gradio_wrapper .gradio_interface .input_slider .range{height:1rem;width:100%;-webkit-appearance:none;appearance:none;border-radius:0.25rem;transition-property:background-color, border-color, color, fill, stroke, opacity, box-shadow, -webkit-transform, -webkit-filter, -webkit-backdrop-filter;transition-property:background-color, border-color, color, fill, stroke, opacity, box-shadow, transform, filter, backdrop-filter;transition-property:background-color, border-color, color, fill, stroke, opacity, box-shadow, transform, filter, backdrop-filter, -webkit-transform, -webkit-filter, -webkit-backdrop-filter;transition-timing-function:cubic-bezier(0.4, 0, 0.2, 1);transition-duration:150ms}.gradio_wrapper .gradio_interface .input_slider .range::-webkit-slider-thumb{-webkit-appearance:none;height:1.25rem;width:1.25rem;cursor:pointer;appearance:none;border-radius:0.25rem}.gradio_wrapper .gradio_interface .input_slider .range::-moz-range-thumb{height:1.25rem;width:1.25rem;cursor:pointer;appearance:none;border-radius:0.25rem}.gradio_wrapper .gradio_interface .input_slider .value{margin-left:auto;margin-right:auto;margin-top:0.25rem;display:inline-block;border-radius:0.25rem;padding-left:0.5rem;padding-right:0.5rem;padding-top:0.125rem;padding-bottom:0.125rem}.gradio_wrapper .gradio_interface .input_slider .interpret_range{display:flex;height:1.5rem}.gradio_wrapper .gradio_interface .input_slider .interpret_range div{flex-grow:1}.gradio_wrapper .gradio_interface .input_audio .audio-react-recorder{display:none}.gradio_wrapper .gradio_interface .input_audio .start, .gradio_wrapper .gradio_interface .input_audio .stop{border-radius:0.25rem;padding:0.5rem;font-weight:600}.gradio_wrapper .gradio_interface .input_audio .start{--tw-bg-opacity:1;background-color:rgba(229, 231, 235, var(--tw-bg-opacity))}.dark .gradio_wrapper .gradio_interface .input_audio .start{--tw-bg-opacity:1;background-color:rgba(75, 85, 99, var(--tw-bg-opacity))}.gradio_wrapper .gradio_interface .input_audio .stop{--tw-bg-opacity:1;background-color:rgba(254, 202, 202, var(--tw-bg-opacity));--tw-text-opacity:1;color:rgba(239, 68, 68, var(--tw-text-opacity))}.dark .gradio_wrapper .gradio_interface .input_audio .stop{--tw-bg-opacity:1;background-color:rgba(220, 38, 38, var(--tw-bg-opacity));--tw-text-opacity:1;color:rgba(254, 226, 226, var(--tw-text-opacity))}.gradio_wrapper .gradio_interface .input_audio audio{width:100%}.gradio_wrapper .gradio_interface .input_audio .edit_buttons{position:static;display:flex;justify-content:flex-end}.gradio_wrapper .gradio_interface .input_audio .interpret_range{display:flex;height:1rem}.gradio_wrapper .gradio_interface .input_audio .interpret_range div{height:100%;flex-grow:1}.gradio_wrapper .gradio_interface .input_video{position:relative;height:20rem;width:100%}.gradio_wrapper .gradio_interface .input_video .video_recorder{height:100%;width:100%;--tw-bg-opacity:1;background-color:rgba(0, 0, 0, var(--tw-bg-opacity))}.gradio_wrapper .gradio_interface .input_video .record_holder{position:absolute;left:50%;bottom:1rem;--tw-translate-x:-50%;-webkit-transform:var(--tw-transform);transform:var(--tw-transform);--tw-translate-y:-50%;transform:var(--tw-transform);text-align:center}.gradio_wrapper .gradio_interface .input_video .record_message{margin-bottom:1rem;font-weight:700;--tw-text-opacity:1;color:rgba(255, 255, 255, var(--tw-text-opacity))}.gradio_wrapper .gradio_interface .input_video .record{height:3rem;width:3rem;border-radius:9999px;border-width:4px;--tw-border-opacity:1;border-color:rgba(220, 38, 38, var(--tw-border-opacity));--tw-bg-opacity:1;background-color:rgba(239, 68, 68, var(--tw-bg-opacity))}.gradio_wrapper .gradio_interface .input_video .record:hover{--tw-bg-opacity:1;background-color:rgba(220, 38, 38, var(--tw-bg-opacity))}.gradio_wrapper .gradio_interface .input_video .video_preview_holder{display:flex;height:100%;width:100%;align-items:center;justify-content:center;--tw-bg-opacity:1;background-color:rgba(229, 231, 235, var(--tw-bg-opacity))}.gradio_wrapper .gradio_interface .input_video .video_file_holder{display:flex;height:100%;width:100%;align-items:center;justify-content:center;word-break:break-all;padding:1.5rem;font-size:3.75rem;line-height:1}.gradio_wrapper .gradio_interface .input_video .video_preview{height:100%;width:100%;--tw-bg-opacity:1;background-color:rgba(0, 0, 0, var(--tw-bg-opacity));object-fit:contain}.gradio_wrapper .gradio_interface .input_video_example .video_holder{display:flex;height:9rem;justify-content:center;object-fit:contain}.gradio_wrapper .gradio_interface .input_video_example .video_preview{max-width:none}.gradio_wrapper .gradio_interface .input_file{height:20rem;width:100%}.gradio_wrapper .gradio_interface .input_file .file_preview_holder{position:relative;display:flex;height:100%;width:100%;flex-direction:column;align-items:center;justify-content:center}.gradio_wrapper .gradio_interface .input_file .file_name{word-break:break-all;padding:1.5rem;font-size:3.75rem;line-height:1}.gradio_wrapper .gradio_interface .input_file .file_size{padding:0.5rem;font-size:1.5rem;line-height:2rem}.gradio_wrapper .gradio_interface .input_dataframe table{border-collapse:separate;border-bottom-width:1px;border-right-width:1px;--tw-border-opacity:1;border-color:rgba(209, 213, 219, var(--tw-border-opacity))}.dark .gradio_wrapper .gradio_interface .input_dataframe table{--tw-border-opacity:1;border-color:rgba(75, 85, 99, var(--tw-border-opacity))}.dark .gradio_wrapper .gradio_interface .input_dataframe table td{--tw-border-opacity:1;border-color:rgba(75, 85, 99, var(--tw-border-opacity));--tw-bg-opacity:1;background-color:rgba(55, 65, 81, var(--tw-bg-opacity))}.dark .gradio_wrapper .gradio_interface .input_dataframe table td.selected, .dark .gradio_wrapper .gradio_interface .input_dataframe table tr.selected td:first-child{--tw-bg-opacity:1;background-color:rgba(75, 85, 99, var(--tw-bg-opacity))}.dark .gradio_wrapper .gradio_interface .input_dataframe table td.highlight{--tw-bg-opacity:1;background-color:rgba(31, 41, 55, var(--tw-bg-opacity))}.gradio_wrapper .gradio_interface .input_dataframe .jexcel_contextmenu{display:none}.gradio_wrapper .gradio_interface .input_timeseries{height:24rem;width:100%}.gradio_wrapper .gradio_interface .output_text{word-break:break-word;box-sizing:border-box;width:100%;white-space:pre-wrap;border-radius:0.25rem;--tw-bg-opacity:1;background-color:rgba(255, 255, 255, var(--tw-bg-opacity));padding:0.5rem}.dark .gradio_wrapper .gradio_interface .output_text{--tw-bg-opacity:1;background-color:rgba(31, 41, 55, var(--tw-bg-opacity))}.gradio_wrapper .gradio_interface .output_label .output_class, .gradio_wrapper .gradio_interface .output_label .output_class_without_confidences{display:flex;flex-grow:1;align-items:center;justify-content:center;padding-top:1.5rem;padding-bottom:1.5rem;padding-left:1rem;padding-right:1rem;font-size:1.5rem;line-height:2rem;font-weight:700}.gradio_wrapper .gradio_interface .output_label .confidence_intervals{display:flex;font-size:1.25rem;line-height:1.75rem}.gradio_wrapper .gradio_interface .output_label .labels{margin-right:0.5rem}.gradio_wrapper .gradio_interface .output_label .confidences{display:flex;flex-grow:1;flex-direction:column;align-items:baseline}.gradio_wrapper .gradio_interface .output_label .label{margin-bottom:0.5rem;height:1.75rem;overflow:hidden;text-overflow:ellipsis;white-space:nowrap;text-align:right}.gradio_wrapper .gradio_interface .output_label .confidence{margin-bottom:0.5rem;display:flex;height:1.75rem;justify-content:flex-end;overflow:hidden;white-space:nowrap;padding-left:0.25rem;padding-right:0.25rem}.gradio_wrapper .gradio_interface .output_image{height:20rem;width:100%}.gradio_wrapper .gradio_interface .output_image .image_preview_holder{position:relative;display:flex;height:100%;width:100%;align-items:center;justify-content:center;--tw-bg-opacity:1;background-color:rgba(229, 231, 235, var(--tw-bg-opacity))}.dark .gradio_wrapper .gradio_interface .output_image .image_preview_holder{--tw-bg-opacity:1;background-color:rgba(75, 85, 99, var(--tw-bg-opacity))}.gradio_wrapper .gradio_interface .output_image .image_preview, .gradio_wrapper .gradio_interface .output_image video{height:100%;width:100%;object-fit:contain}.gradio_wrapper .gradio_interface .output_audio audio{width:100%}.gradio_wrapper .gradio_interface .output_highlightedtext .category_legend{margin-bottom:0.5rem;display:flex;flex-wrap:wrap;gap:0.25rem}.gradio_wrapper .gradio_interface .output_highlightedtext .category_legend .category-label{border-radius:0.25rem;padding-left:0.5rem;padding-right:0.5rem;padding-top:0.25rem;padding-bottom:0.25rem;font-weight:600;--tw-text-opacity:1;color:rgba(255, 255, 255, var(--tw-text-opacity))}.gradio_wrapper .gradio_interface .output_highlightedtext .color_legend{margin-bottom:0.75rem;display:flex;justify-content:space-between;border-radius:0.25rem;padding-left:0.5rem;padding-right:0.5rem;padding-top:0.25rem;padding-bottom:0.25rem;font-weight:600;background:linear-gradient(to right, #8d83d6, rgba(255, 255, 255, 0), #eb4d4b)}.gradio_wrapper .gradio_interface .output_highlightedtext .textfield{box-sizing:border-box;max-width:100%;word-break:break-all;border-radius:0.25rem;--tw-bg-opacity:1;background-color:rgba(255, 255, 255, var(--tw-bg-opacity));padding:0.5rem;line-height:2rem}.dark .gradio_wrapper .gradio_interface .output_highlightedtext .textfield{--tw-bg-opacity:1;background-color:rgba(31, 41, 55, var(--tw-bg-opacity))}.gradio_wrapper .gradio_interface .output_highlightedtext .textfield .textspan{margin-right:0.125rem;border-radius:0.125rem;--tw-bg-opacity:0.2;padding:0.25rem}.dark .gradio_wrapper .gradio_interface .output_highlightedtext .textfield .textspan{--tw-bg-opacity:0.8}.dark .gradio_wrapper .gradio_interface .output_highlightedtext .textfield .textspan .text{--tw-text-opacity:1;color:rgba(255, 255, 255, var(--tw-text-opacity))}.gradio_wrapper .gradio_interface .output_highlightedtext .textfield .inline_label{margin-left:0.125rem;border-radius:0.125rem;padding-left:0.125rem;padding-right:0.125rem;font-size:0.75rem;line-height:1rem;--tw-text-opacity:1;color:rgba(255, 255, 255, var(--tw-text-opacity))}.gradio_wrapper .gradio_interface .output_json{font-family:ui-monospace, SFMono-Regular, Menlo, Monaco, Consolas, "Liberation Mono", "Courier New", monospace;font-weight:600}.gradio_wrapper .gradio_interface .output_json .json_node{display:inline}.gradio_wrapper .gradio_interface .output_json .json_node[type=string]{--tw-text-opacity:1;color:rgba(16, 185, 129, var(--tw-text-opacity))}.gradio_wrapper .gradio_interface .output_json .json_node[type=number]{--tw-text-opacity:1;color:rgba(59, 130, 246, var(--tw-text-opacity))}.gradio_wrapper .gradio_interface .output_json .json_node[type=boolean]{--tw-text-opacity:1;color:rgba(239, 68, 68, var(--tw-text-opacity))}.gradio_wrapper .gradio_interface .output_json .json_node[type=null]{--tw-text-opacity:1;color:rgba(107, 114, 128, var(--tw-text-opacity))}.dark .gradio_wrapper .gradio_interface .output_json .json_node[type=null]{--tw-text-opacity:1;color:rgba(156, 163, 175, var(--tw-text-opacity))}.gradio_wrapper .gradio_interface .output_json .json_item{display:block}.gradio_wrapper .gradio_interface .output_json .json_children{display:block;padding-left:1rem}.gradio_wrapper .gradio_interface .output_keyvalues table{--tw-bg-opacity:1;background-color:rgba(255, 255, 255, var(--tw-bg-opacity))}.gradio_wrapper .gradio_interface .output_keyvalues table thead{font-weight:700}.gradio_wrapper .gradio_interface .output_keyvalues table td, .gradio_wrapper .gradio_interface .output_keyvalues table th{padding:0.5rem}.gradio_wrapper .gradio_interface .output_video{display:flex;height:20rem;width:100%;justify-content:center;object-fit:contain}.gradio_wrapper .gradio_interface .output_video video{height:100%}.gradio_wrapper .gradio_interface .output_video .video_file_holder{display:flex;height:100%;width:100%;align-items:center;justify-content:center;word-break:break-all;padding:1.5rem;font-size:3.75rem;line-height:1}.gradio_wrapper .gradio_interface .output_file{height:20rem;width:100%}.gradio_wrapper .gradio_interface .output_file .file_display{position:relative;display:flex;height:100%;width:100%;flex-direction:column;align-items:center;justify-content:center}.gradio_wrapper .gradio_interface .output_file .file_name{word-break:break-all;padding:1.5rem;font-size:3.75rem;line-height:1}.gradio_wrapper .gradio_interface .output_file .file_size{padding:0.5rem;font-size:1.5rem;line-height:2rem}.gradio_wrapper .gradio_interface .output_dataframe table thead{border-bottom-width:2px;--tw-border-opacity:1;border-color:rgba(229, 231, 235, var(--tw-border-opacity));font-weight:700}.gradio_wrapper .gradio_interface .output_dataframe table th{cursor:pointer;transition-property:background-color, border-color, color, fill, stroke, opacity, box-shadow, -webkit-transform, -webkit-filter, -webkit-backdrop-filter;transition-property:background-color, border-color, color, fill, stroke, opacity, box-shadow, transform, filter, backdrop-filter;transition-property:background-color, border-color, color, fill, stroke, opacity, box-shadow, transform, filter, backdrop-filter, -webkit-transform, -webkit-filter, -webkit-backdrop-filter;transition-timing-function:cubic-bezier(0.4, 0, 0.2, 1);transition-duration:150ms}.gradio_wrapper .gradio_interface .output_dataframe table th:hover{--tw-bg-opacity:1;background-color:rgba(229, 231, 235, var(--tw-bg-opacity))}.dark .gradio_wrapper .gradio_interface .output_dataframe table th:hover{--tw-bg-opacity:1;background-color:rgba(75, 85, 99, var(--tw-bg-opacity))}.gradio_wrapper .gradio_interface .output_dataframe table td, .gradio_wrapper .gradio_interface .output_dataframe table th{padding-left:1rem;padding-right:1rem}.gradio_wrapper .gradio_interface .output_dataframe table .caret{margin-left:0.25rem;margin-bottom:0.125rem;display:inline-block;height:0.75rem;fill:currentColor}.gradio_wrapper .gradio_interface .output_dataframe .pages{display:flex;align-items:center;gap:0.25rem}.gradio_wrapper .gradio_interface .output_dataframe .page{--tw-bg-opacity:1;background-color:rgba(229, 231, 235, var(--tw-bg-opacity));padding-left:0.5rem;padding-right:0.5rem;padding-top:0.25rem;padding-bottom:0.25rem}.gradio_wrapper .gradio_interface .output_dataframe .page.selected{--tw-bg-opacity:1;background-color:rgba(229, 231, 235, var(--tw-bg-opacity))}.gradio_wrapper .gradio_interface .output_carousel{display:flex;flex-direction:column;gap:0.5rem}.gradio_wrapper .gradio_interface .output_carousel .carousel_control{margin-top:0.25rem;margin-bottom:0.25rem;display:flex;align-items:center;justify-content:center;gap:1rem}.gradio_wrapper .gradio_interface .output_carousel .carousel_control .carousel_index{min-width:60px;text-align:center;font-size:1.25rem;line-height:1.75rem;font-weight:600}.gradio_wrapper .gradio_interface .output_carousel .carousel_control button .caret{margin-top:0.125rem;height:0.75rem;fill:currentColor}
.dark .gradio_wrapper .gradio_bg[theme=grass] {--tw-bg-opacity: 1;background-color: rgba(55, 65, 81, var(--tw-bg-opacity))
}.gradio_wrapper .gradio_bg[theme=grass] .gradio_interface .component_set {border-radius: 0px;--tw-bg-opacity: 1;background-color: rgba(249, 250, 251, var(--tw-bg-opacity))
}.dark .gradio_wrapper .gradio_bg[theme=grass] .gradio_interface .component_set {--tw-bg-opacity: 1;background-color: rgba(31, 41, 55, var(--tw-bg-opacity))
}.gradio_wrapper .gradio_bg[theme=grass] .gradio_interface .component {padding: 0.25rem;transition-property: background-color, border-color, color, fill, stroke, opacity, box-shadow, -webkit-transform, -webkit-filter, -webkit-backdrop-filter;transition-property: background-color, border-color, color, fill, stroke, opacity, box-shadow, transform, filter, backdrop-filter;transition-property: background-color, border-color, color, fill, stroke, opacity, box-shadow, transform, filter, backdrop-filter, -webkit-transform, -webkit-filter, -webkit-backdrop-filter;transition-timing-function: cubic-bezier(0.4, 0, 0.2, 1);transition-duration: 150ms
}.gradio_wrapper .gradio_bg[theme=grass] .gradio_interface .panel_header {font-weight: 600;--tw-text-opacity: 1;color: rgba(156, 163, 175, var(--tw-text-opacity))
}.dark .gradio_wrapper .gradio_bg[theme=grass] .gradio_interface .panel_header {--tw-text-opacity: 1;color: rgba(229, 231, 235, var(--tw-text-opacity))
}.gradio_wrapper .gradio_bg[theme=grass] .gradio_interface .panel_button {border-radius: 0px;--tw-bg-opacity: 1;background-color: rgba(243, 244, 246, var(--tw-bg-opacity));--tw-shadow: 0 1px 3px 0 rgba(0, 0, 0, 0.1), 0 1px 2px 0 rgba(0, 0, 0, 0.06);box-shadow: var(--tw-ring-offset-shadow, 0 0 #0000), var(--tw-ring-shadow, 0 0 #0000), var(--tw-shadow)
}.dark .gradio_wrapper .gradio_bg[theme=grass] .gradio_interface .panel_button {--tw-bg-opacity: 1;background-color: rgba(31, 41, 55, var(--tw-bg-opacity))
}.gradio_wrapper .gradio_bg[theme=grass] .gradio_interface .panel_button.submit {--tw-bg-opacity: 1;background-color: rgba(52, 211, 153, var(--tw-bg-opacity));--tw-text-opacity: 1;color: rgba(255, 255, 255, var(--tw-text-opacity))
}.dark .gradio_wrapper .gradio_bg[theme=grass] .gradio_interface .examples .examples_table_holder:not(.gallery) .examples_table {--tw-bg-opacity: 1;background-color: rgba(31, 41, 55, var(--tw-bg-opacity))
}.gradio_wrapper .gradio_bg[theme=grass] .gradio_interface .examples .examples_table_holder:not(.gallery) .examples_table tbody tr:hover {--tw-bg-opacity: 1;background-color: rgba(52, 211, 153, var(--tw-bg-opacity))
}.dark .gradio_wrapper .gradio_bg[theme=grass] .gradio_interface .examples .examples_table_holder.gallery .examples_table tbody td {--tw-bg-opacity: 1;background-color: rgba(31, 41, 55, var(--tw-bg-opacity))
}.gradio_wrapper .gradio_bg[theme=grass] .gradio_interface .examples .examples_table_holder.gallery .examples_table tbody td:hover {--tw-bg-opacity: 1;background-color: rgba(52, 211, 153, var(--tw-bg-opacity))
}.gradio_wrapper .gradio_bg[theme=grass] .gradio_interface .input_text textarea, .gradio_wrapper .gradio_bg[theme=grass] .gradio_interface .input_text input {box-sizing: border-box;border-radius: 0px;border-width: 4px;--tw-border-opacity: 1;border-color: rgba(255, 255, 255, var(--tw-border-opacity));padding: 0.5rem
}.gradio_wrapper .gradio_bg[theme=grass] .gradio_interface .input_text textarea:focus, .gradio_wrapper .gradio_bg[theme=grass] .gradio_interface .input_text input:focus {--tw-border-opacity: 1;border-color: rgba(52, 211, 153, var(--tw-border-opacity))
}.dark .gradio_wrapper .gradio_bg[theme=grass] .gradio_interface .input_text textarea, .dark .gradio_wrapper .gradio_bg[theme=grass] .gradio_interface .input_text input {--tw-border-opacity: 1;border-color: rgba(75, 85, 99, var(--tw-border-opacity));--tw-bg-opacity: 1;background-color: rgba(55, 65, 81, var(--tw-bg-opacity));--tw-text-opacity: 1;color: rgba(249, 250, 251, var(--tw-text-opacity))
}.dark .gradio_wrapper .gradio_bg[theme=grass] .gradio_interface .input_text textarea:focus, .dark .gradio_wrapper .gradio_bg[theme=grass] .gradio_interface .input_text input:focus {--tw-border-opacity: 1;border-color: rgba(52, 211, 153, var(--tw-border-opacity))
}.gradio_wrapper .gradio_bg[theme=grass] .gradio_interface .input_number input {box-sizing: border-box;border-radius: 0px;border-width: 4px;--tw-border-opacity: 1;border-color: rgba(255, 255, 255, var(--tw-border-opacity));padding: 0.5rem
}.gradio_wrapper .gradio_bg[theme=grass] .gradio_interface .input_number input:focus {--tw-border-opacity: 1;border-color: rgba(52, 211, 153, var(--tw-border-opacity))
}.dark .gradio_wrapper .gradio_bg[theme=grass] .gradio_interface .input_number input {--tw-border-opacity: 1;border-color: rgba(75, 85, 99, var(--tw-border-opacity));--tw-bg-opacity: 1;background-color: rgba(55, 65, 81, var(--tw-bg-opacity));--tw-text-opacity: 1;color: rgba(249, 250, 251, var(--tw-text-opacity))
}.dark .gradio_wrapper .gradio_bg[theme=grass] .gradio_interface .input_number input:focus {--tw-border-opacity: 1;border-color: rgba(52, 211, 153, var(--tw-border-opacity))
}.gradio_wrapper .gradio_bg[theme=grass] .gradio_interface .input_slider .range {border-radius: 0px
}.dark .gradio_wrapper .gradio_bg[theme=grass] .gradio_interface .input_slider .range {--tw-bg-opacity: 1;background-color: rgba(55, 65, 81, var(--tw-bg-opacity))
}.gradio_wrapper .gradio_bg[theme=grass] .gradio_interface .input_slider .range::-webkit-slider-thumb {border-radius: 0px;--tw-bg-opacity: 1;background-color: rgba(52, 211, 153, var(--tw-bg-opacity));--tw-shadow: 0 1px 2px 0 rgba(0, 0, 0, 0.05);box-shadow: var(--tw-ring-offset-shadow, 0 0 #0000), var(--tw-ring-shadow, 0 0 #0000), var(--tw-shadow)
}.gradio_wrapper .gradio_bg[theme=grass] .gradio_interface .input_slider .range::-moz-range-thumb {border-radius: 0px;--tw-bg-opacity: 1;background-color: rgba(52, 211, 153, var(--tw-bg-opacity));--tw-shadow: 0 1px 2px 0 rgba(0, 0, 0, 0.05);box-shadow: var(--tw-ring-offset-shadow, 0 0 #0000), var(--tw-ring-shadow, 0 0 #0000), var(--tw-shadow)
}.gradio_wrapper .gradio_bg[theme=grass] .gradio_interface .input_slider .value {font-weight: 600;--tw-text-opacity: 1;color: rgba(107, 114, 128, var(--tw-text-opacity))
}.dark .gradio_wrapper .gradio_bg[theme=grass] .gradio_interface .input_slider .value {--tw-bg-opacity: 1;background-color: rgba(55, 65, 81, var(--tw-bg-opacity));--tw-text-opacity: 1;color: rgba(249, 250, 251, var(--tw-text-opacity))
}.gradio_wrapper .gradio_bg[theme=grass] .gradio_interface .input_radio .radio_item {border-radius: 0px;--tw-bg-opacity: 1;background-color: rgba(243, 244, 246, var(--tw-bg-opacity))
}.dark .gradio_wrapper .gradio_bg[theme=grass] .gradio_interface .input_radio .radio_item {--tw-bg-opacity: 1;background-color: rgba(55, 65, 81, var(--tw-bg-opacity));--tw-text-opacity: 1;color: rgba(249, 250, 251, var(--tw-text-opacity))
}.gradio_wrapper .gradio_bg[theme=grass] .gradio_interface .input_radio .radio_circle {display: none
}.gradio_wrapper .gradio_bg[theme=grass] .gradio_interface .input_radio .radio_item.selected {--tw-bg-opacity: 1;background-color: rgba(52, 211, 153, var(--tw-bg-opacity));--tw-text-opacity: 1;color: rgba(255, 255, 255, var(--tw-text-opacity));--tw-shadow: 0 1px 3px 0 rgba(0, 0, 0, 0.1), 0 1px 2px 0 rgba(0, 0, 0, 0.06);box-shadow: var(--tw-ring-offset-shadow, 0 0 #0000), var(--tw-ring-shadow, 0 0 #0000), var(--tw-shadow)
}.gradio_wrapper .gradio_bg[theme=grass] .gradio_interface .input_radio .radio_circle {box-sizing: border-box;height: 1rem;width: 1rem;border-radius: 9999px;--tw-bg-opacity: 1;background-color: rgba(255, 255, 255, var(--tw-bg-opacity));transition-property: background-color, border-color, color, fill, stroke, opacity, box-shadow, -webkit-transform, -webkit-filter, -webkit-backdrop-filter;transition-property: background-color, border-color, color, fill, stroke, opacity, box-shadow, transform, filter, backdrop-filter;transition-property: background-color, border-color, color, fill, stroke, opacity, box-shadow, transform, filter, backdrop-filter, -webkit-transform, -webkit-filter, -webkit-backdrop-filter;transition-timing-function: cubic-bezier(0.4, 0, 0.2, 1);transition-duration: 150ms
}.gradio_wrapper .gradio_bg[theme=grass] .gradio_interface .input_checkbox_group .checkbox_item, .gradio_wrapper .gradio_bg[theme=grass] .gradio_interface .input_checkbox .checkbox_item {border-radius: 0px;--tw-bg-opacity: 1;background-color: rgba(243, 244, 246, var(--tw-bg-opacity))
}.dark .gradio_wrapper .gradio_bg[theme=grass] .gradio_interface .input_checkbox_group .checkbox_item, .dark .gradio_wrapper .gradio_bg[theme=grass] .gradio_interface .input_checkbox .checkbox_item {--tw-bg-opacity: 1;background-color: rgba(55, 65, 81, var(--tw-bg-opacity));--tw-text-opacity: 1;color: rgba(249, 250, 251, var(--tw-text-opacity))
}.gradio_wrapper .gradio_bg[theme=grass] .gradio_interface .input_checkbox_group .checkbox_item.selected, .gradio_wrapper .gradio_bg[theme=grass] .gradio_interface .input_checkbox .checkbox_item.selected {--tw-bg-opacity: 1;background-color: rgba(52, 211, 153, var(--tw-bg-opacity));--tw-text-opacity: 1;color: rgba(255, 255, 255, var(--tw-text-opacity));--tw-shadow: 0 1px 3px 0 rgba(0, 0, 0, 0.1), 0 1px 2px 0 rgba(0, 0, 0, 0.06);box-shadow: var(--tw-ring-offset-shadow, 0 0 #0000), var(--tw-ring-shadow, 0 0 #0000), var(--tw-shadow)
}.gradio_wrapper .gradio_bg[theme=grass] .gradio_interface .input_checkbox .checkbox {--tw-bg-opacity: 1;background-color: rgba(229, 231, 235, var(--tw-bg-opacity))
}.gradio_wrapper .gradio_bg[theme=grass] .gradio_interface .input_checkbox .selected .checkbox {--tw-bg-opacity: 1;background-color: rgba(16, 185, 129, var(--tw-bg-opacity))
}.gradio_wrapper .gradio_bg[theme=grass] .gradio_interface .input_checkbox_group .checkbox {display: none
}.gradio_wrapper .gradio_bg[theme=grass] .gradio_interface .input_dropdown .selector {border-radius: 0px;--tw-bg-opacity: 1;background-color: rgba(243, 244, 246, var(--tw-bg-opacity))
}.dark .gradio_wrapper .gradio_bg[theme=grass] .gradio_interface .input_dropdown .selector {--tw-bg-opacity: 1;background-color: rgba(55, 65, 81, var(--tw-bg-opacity));--tw-text-opacity: 1;color: rgba(249, 250, 251, var(--tw-text-opacity))
}.gradio_wrapper .gradio_bg[theme=grass] .gradio_interface .input_dropdown .dropdown_menu {--tw-shadow: 0 1px 3px 0 rgba(0, 0, 0, 0.1), 0 1px 2px 0 rgba(0, 0, 0, 0.06);box-shadow: var(--tw-ring-offset-shadow, 0 0 #0000), var(--tw-ring-shadow, 0 0 #0000), var(--tw-shadow)
}.gradio_wrapper .gradio_bg[theme=grass] .gradio_interface .input_dropdown .dropdown_item {--tw-bg-opacity: 1;background-color: rgba(243, 244, 246, var(--tw-bg-opacity))
}.gradio_wrapper .gradio_bg[theme=grass] .gradio_interface .input_dropdown .dropdown_item:hover {--tw-bg-opacity: 1;background-color: rgba(52, 211, 153, var(--tw-bg-opacity));font-weight: 600;--tw-text-opacity: 1;color: rgba(249, 250, 251, var(--tw-text-opacity))
}.dark .gradio_wrapper .gradio_bg[theme=grass] .gradio_interface .input_dropdown .dropdown_item {--tw-bg-opacity: 1;background-color: rgba(31, 41, 55, var(--tw-bg-opacity))
}.gradio_wrapper .gradio_bg[theme=grass] .gradio_interface .input_dropdown .dropdown_item:first-child, .gradio_wrapper .gradio_bg[theme=grass] .gradio_interface .input_dropdown .dropdown_item:last-child {border-radius: 0px
}.gradio_wrapper .gradio_bg[theme=grass] .gradio_interface .output_label .confidence {--tw-bg-opacity: 1;background-color: rgba(209, 213, 219, var(--tw-bg-opacity));font-weight: 600;--tw-text-opacity: 1;color: rgba(255, 255, 255, var(--tw-text-opacity))
}.dark .gradio_wrapper .gradio_bg[theme=grass] .gradio_interface .output_label .confidence {--tw-bg-opacity: 1;background-color: rgba(75, 85, 99, var(--tw-bg-opacity))
}.gradio_wrapper .gradio_bg[theme=grass] .gradio_interface .output_label .confidence:first-child {--tw-bg-opacity: 1;background-color: rgba(52, 211, 153, var(--tw-bg-opacity))
}
.gradio_wrapper .gradio_bg[theme=peach] {background-image: linear-gradient(to right, var(--tw-gradient-stops));--tw-gradient-from: #fef2f2;--tw-gradient-stops: var(--tw-gradient-from), var(--tw-gradient-to, rgba(254, 242, 242, 0));--tw-gradient-to: #fef3c7
}.dark .gradio_wrapper .gradio_bg[theme=peach] {--tw-gradient-from: #111827;--tw-gradient-stops: var(--tw-gradient-from), var(--tw-gradient-to, rgba(17, 24, 39, 0));--tw-gradient-to: #1f2937
}.gradio_wrapper .gradio_bg[theme=peach] .gradio_interface .component_set {border-radius: 0.5rem;--tw-bg-opacity: 1;background-color: rgba(255, 255, 255, var(--tw-bg-opacity))
}.dark .gradio_wrapper .gradio_bg[theme=peach] .gradio_interface .component_set {--tw-bg-opacity: 1;background-color: rgba(31, 41, 55, var(--tw-bg-opacity))
}.gradio_wrapper .gradio_bg[theme=peach] .gradio_interface .component {padding: 0.25rem;transition-property: background-color, border-color, color, fill, stroke, opacity, box-shadow, -webkit-transform, -webkit-filter, -webkit-backdrop-filter;transition-property: background-color, border-color, color, fill, stroke, opacity, box-shadow, transform, filter, backdrop-filter;transition-property: background-color, border-color, color, fill, stroke, opacity, box-shadow, transform, filter, backdrop-filter, -webkit-transform, -webkit-filter, -webkit-backdrop-filter;transition-timing-function: cubic-bezier(0.4, 0, 0.2, 1);transition-duration: 150ms
}.gradio_wrapper .gradio_bg[theme=peach] .gradio_interface .panel_header {font-weight: 600;--tw-text-opacity: 1;color: rgba(75, 85, 99, var(--tw-text-opacity))
}.dark .gradio_wrapper .gradio_bg[theme=peach] .gradio_interface .panel_header {--tw-text-opacity: 1;color: rgba(229, 231, 235, var(--tw-text-opacity))
}.gradio_wrapper .gradio_bg[theme=peach] .gradio_interface .panel_button {border-radius: 0.5rem;--tw-bg-opacity: 1;background-color: rgba(255, 255, 255, var(--tw-bg-opacity));--tw-shadow: 0 1px 3px 0 rgba(0, 0, 0, 0.1), 0 1px 2px 0 rgba(0, 0, 0, 0.06);box-shadow: var(--tw-ring-offset-shadow, 0 0 #0000), var(--tw-ring-shadow, 0 0 #0000), var(--tw-shadow)
}.dark .gradio_wrapper .gradio_bg[theme=peach] .gradio_interface .panel_button {--tw-bg-opacity: 1;background-color: rgba(31, 41, 55, var(--tw-bg-opacity))
}.gradio_wrapper .gradio_bg[theme=peach] .gradio_interface .panel_button.submit {background-image: linear-gradient(to top right, var(--tw-gradient-stops));--tw-gradient-from: #ef4444;--tw-gradient-stops: var(--tw-gradient-from), var(--tw-gradient-to, rgba(239, 68, 68, 0));--tw-gradient-to: #fbbf24;--tw-text-opacity: 1;color: rgba(255, 255, 255, var(--tw-text-opacity))
}.gradio_wrapper .gradio_bg[theme=peach] .gradio_interface .examples .examples_table_holder:not(.gallery) .examples_table {--tw-bg-opacity: 1;background-color: rgba(255, 255, 255, var(--tw-bg-opacity))
}.dark .gradio_wrapper .gradio_bg[theme=peach] .gradio_interface .examples .examples_table_holder:not(.gallery) .examples_table {--tw-bg-opacity: 1;background-color: rgba(31, 41, 55, var(--tw-bg-opacity))
}.gradio_wrapper .gradio_bg[theme=peach] .gradio_interface .examples .examples_table_holder:not(.gallery) .examples_table tbody tr:hover {--tw-bg-opacity: 1;background-color: rgba(245, 158, 11, var(--tw-bg-opacity))
}.dark .gradio_wrapper .gradio_bg[theme=peach] .gradio_interface .examples .examples_table_holder:not(.gallery) .examples_table tbody tr:hover {--tw-bg-opacity: 1;background-color: rgba(153, 27, 27, var(--tw-bg-opacity))
}.gradio_wrapper .gradio_bg[theme=peach] .gradio_interface .examples .examples_table_holder.gallery .examples_table tbody td {--tw-bg-opacity: 1;background-color: rgba(255, 255, 255, var(--tw-bg-opacity))
}.dark .gradio_wrapper .gradio_bg[theme=peach] .gradio_interface .examples .examples_table_holder.gallery .examples_table tbody td {--tw-bg-opacity: 1;background-color: rgba(31, 41, 55, var(--tw-bg-opacity))
}.gradio_wrapper .gradio_bg[theme=peach] .gradio_interface .examples .examples_table_holder.gallery .examples_table tbody td:hover {--tw-bg-opacity: 1;background-color: rgba(245, 158, 11, var(--tw-bg-opacity))
}.dark .gradio_wrapper .gradio_bg[theme=peach] .gradio_interface .examples .examples_table_holder.gallery .examples_table tbody td:hover {--tw-bg-opacity: 1;background-color: rgba(153, 27, 27, var(--tw-bg-opacity))
}.gradio_wrapper .gradio_bg[theme=peach] .gradio_interface .input_text textarea, .gradio_wrapper .gradio_bg[theme=peach] .gradio_interface .input_text input {border-radius: 0.5rem;--tw-bg-opacity: 1;background-color: rgba(249, 250, 251, var(--tw-bg-opacity))
}.dark .gradio_wrapper .gradio_bg[theme=peach] .gradio_interface .input_text textarea, .dark .gradio_wrapper .gradio_bg[theme=peach] .gradio_interface .input_text input {--tw-bg-opacity: 1;background-color: rgba(55, 65, 81, var(--tw-bg-opacity));--tw-text-opacity: 1;color: rgba(249, 250, 251, var(--tw-text-opacity))
}.gradio_wrapper .gradio_bg[theme=peach] .gradio_interface .input_number input {border-radius: 0.5rem;--tw-bg-opacity: 1;background-color: rgba(249, 250, 251, var(--tw-bg-opacity))
}.dark .gradio_wrapper .gradio_bg[theme=peach] .gradio_interface .input_number input {--tw-bg-opacity: 1;background-color: rgba(55, 65, 81, var(--tw-bg-opacity));--tw-text-opacity: 1;color: rgba(249, 250, 251, var(--tw-text-opacity))
}.gradio_wrapper .gradio_bg[theme=peach] .gradio_interface .input_slider .range {border-radius: 0.5rem;--tw-bg-opacity: 1;background-color: rgba(249, 250, 251, var(--tw-bg-opacity))
}.dark .gradio_wrapper .gradio_bg[theme=peach] .gradio_interface .input_slider .range {--tw-bg-opacity: 1;background-color: rgba(55, 65, 81, var(--tw-bg-opacity))
}.gradio_wrapper .gradio_bg[theme=peach] .gradio_interface .input_slider .range::-webkit-slider-thumb {border-radius: 0.5rem;background-image: linear-gradient(to top right, var(--tw-gradient-stops));--tw-gradient-from: #ef4444;--tw-gradient-stops: var(--tw-gradient-from), var(--tw-gradient-to, rgba(239, 68, 68, 0));--tw-gradient-to: #fbbf24;--tw-shadow: 0 1px 2px 0 rgba(0, 0, 0, 0.05);box-shadow: var(--tw-ring-offset-shadow, 0 0 #0000), var(--tw-ring-shadow, 0 0 #0000), var(--tw-shadow)
}.gradio_wrapper .gradio_bg[theme=peach] .gradio_interface .input_slider .range::-moz-range-thumb {border-radius: 0.5rem;background-image: linear-gradient(to top right, var(--tw-gradient-stops));--tw-gradient-from: #ef4444;--tw-gradient-stops: var(--tw-gradient-from), var(--tw-gradient-to, rgba(239, 68, 68, 0));--tw-gradient-to: #fbbf24;--tw-shadow: 0 1px 2px 0 rgba(0, 0, 0, 0.05);box-shadow: var(--tw-ring-offset-shadow, 0 0 #0000), var(--tw-ring-shadow, 0 0 #0000), var(--tw-shadow)
}.gradio_wrapper .gradio_bg[theme=peach] .gradio_interface .input_slider .value {font-weight: 600;--tw-text-opacity: 1;color: rgba(107, 114, 128, var(--tw-text-opacity))
}.dark .gradio_wrapper .gradio_bg[theme=peach] .gradio_interface .input_slider .value {--tw-bg-opacity: 1;background-color: rgba(55, 65, 81, var(--tw-bg-opacity));--tw-text-opacity: 1;color: rgba(249, 250, 251, var(--tw-text-opacity))
}.gradio_wrapper .gradio_bg[theme=peach] .gradio_interface .input_radio .radio_item {border-radius: 0.5rem;--tw-bg-opacity: 1;background-color: rgba(243, 244, 246, var(--tw-bg-opacity))
}.dark .gradio_wrapper .gradio_bg[theme=peach] .gradio_interface .input_radio .radio_item {--tw-bg-opacity: 1;background-color: rgba(55, 65, 81, var(--tw-bg-opacity));--tw-text-opacity: 1;color: rgba(249, 250, 251, var(--tw-text-opacity))
}.gradio_wrapper .gradio_bg[theme=peach] .gradio_interface .input_radio .radio_item.selected {background-image: linear-gradient(to top right, var(--tw-gradient-stops));--tw-gradient-from: #ef4444;--tw-gradient-stops: var(--tw-gradient-from), var(--tw-gradient-to, rgba(239, 68, 68, 0));--tw-gradient-to: #fbbf24;--tw-text-opacity: 1;color: rgba(255, 255, 255, var(--tw-text-opacity));--tw-shadow: 0 1px 3px 0 rgba(0, 0, 0, 0.1), 0 1px 2px 0 rgba(0, 0, 0, 0.06);box-shadow: var(--tw-ring-offset-shadow, 0 0 #0000), var(--tw-ring-shadow, 0 0 #0000), var(--tw-shadow)
}.gradio_wrapper .gradio_bg[theme=peach] .gradio_interface .input_radio .radio_circle {box-sizing: border-box;height: 1rem;width: 1rem;border-radius: 9999px;--tw-bg-opacity: 1;background-color: rgba(255, 255, 255, var(--tw-bg-opacity));transition-property: background-color, border-color, color, fill, stroke, opacity, box-shadow, -webkit-transform, -webkit-filter, -webkit-backdrop-filter;transition-property: background-color, border-color, color, fill, stroke, opacity, box-shadow, transform, filter, backdrop-filter;transition-property: background-color, border-color, color, fill, stroke, opacity, box-shadow, transform, filter, backdrop-filter, -webkit-transform, -webkit-filter, -webkit-backdrop-filter;transition-timing-function: cubic-bezier(0.4, 0, 0.2, 1);transition-duration: 150ms
}.gradio_wrapper .gradio_bg[theme=peach] .gradio_interface .input_checkbox_group .checkbox_item, .gradio_wrapper .gradio_bg[theme=peach] .gradio_interface .input_checkbox .checkbox_item {border-radius: 0.5rem;--tw-bg-opacity: 1;background-color: rgba(243, 244, 246, var(--tw-bg-opacity))
}.dark .gradio_wrapper .gradio_bg[theme=peach] .gradio_interface .input_checkbox_group .checkbox_item, .dark .gradio_wrapper .gradio_bg[theme=peach] .gradio_interface .input_checkbox .checkbox_item {--tw-bg-opacity: 1;background-color: rgba(55, 65, 81, var(--tw-bg-opacity));--tw-text-opacity: 1;color: rgba(249, 250, 251, var(--tw-text-opacity))
}.gradio_wrapper .gradio_bg[theme=peach] .gradio_interface .input_checkbox_group .checkbox_item.selected, .gradio_wrapper .gradio_bg[theme=peach] .gradio_interface .input_checkbox .checkbox_item.selected {background-image: linear-gradient(to top right, var(--tw-gradient-stops));--tw-gradient-from: #ef4444;--tw-gradient-stops: var(--tw-gradient-from), var(--tw-gradient-to, rgba(239, 68, 68, 0));--tw-gradient-to: #fbbf24;--tw-text-opacity: 1;color: rgba(255, 255, 255, var(--tw-text-opacity));--tw-shadow: 0 1px 3px 0 rgba(0, 0, 0, 0.1), 0 1px 2px 0 rgba(0, 0, 0, 0.06);box-shadow: var(--tw-ring-offset-shadow, 0 0 #0000), var(--tw-ring-shadow, 0 0 #0000), var(--tw-shadow)
}.gradio_wrapper .gradio_bg[theme=peach] .gradio_interface .input_checkbox_group .selected .checkbox, .gradio_wrapper .gradio_bg[theme=peach] .gradio_interface .input_checkbox .selected .checkbox {--tw-bg-opacity: 1;background-color: rgba(229, 231, 235, var(--tw-bg-opacity));--tw-bg-opacity: 0.2
}.gradio_wrapper .gradio_bg[theme=peach] .gradio_interface .input_dropdown .selector {border-radius: 0.5rem;--tw-bg-opacity: 1;background-color: rgba(243, 244, 246, var(--tw-bg-opacity))
}.dark .gradio_wrapper .gradio_bg[theme=peach] .gradio_interface .input_dropdown .selector {--tw-bg-opacity: 1;background-color: rgba(55, 65, 81, var(--tw-bg-opacity));--tw-text-opacity: 1;color: rgba(249, 250, 251, var(--tw-text-opacity))
}.gradio_wrapper .gradio_bg[theme=peach] .gradio_interface .input_dropdown .dropdown_menu {--tw-shadow: 0 1px 3px 0 rgba(0, 0, 0, 0.1), 0 1px 2px 0 rgba(0, 0, 0, 0.06);box-shadow: var(--tw-ring-offset-shadow, 0 0 #0000), var(--tw-ring-shadow, 0 0 #0000), var(--tw-shadow)
}.gradio_wrapper .gradio_bg[theme=peach] .gradio_interface .input_dropdown .dropdown_item {--tw-bg-opacity: 1;background-color: rgba(243, 244, 246, var(--tw-bg-opacity))
}.gradio_wrapper .gradio_bg[theme=peach] .gradio_interface .input_dropdown .dropdown_item:hover {--tw-bg-opacity: 1;background-color: rgba(239, 68, 68, var(--tw-bg-opacity));font-weight: 600;--tw-text-opacity: 1;color: rgba(249, 250, 251, var(--tw-text-opacity))
}.dark .gradio_wrapper .gradio_bg[theme=peach] .gradio_interface .input_dropdown .dropdown_item {--tw-bg-opacity: 1;background-color: rgba(31, 41, 55, var(--tw-bg-opacity))
}.gradio_wrapper .gradio_bg[theme=peach] .gradio_interface .input_dropdown .dropdown_item:first-child, .gradio_wrapper .gradio_bg[theme=peach] .gradio_interface .input_dropdown .dropdown_item:last-child {border-radius: 0.5rem
}.gradio_wrapper .gradio_bg[theme=peach] .gradio_interface .output_label .confidence {border-radius: 0.5rem;--tw-bg-opacity: 1;background-color: rgba(209, 213, 219, var(--tw-bg-opacity));font-weight: 600;--tw-text-opacity: 1;color: rgba(255, 255, 255, var(--tw-text-opacity))
}.dark .gradio_wrapper .gradio_bg[theme=peach] .gradio_interface .output_label .confidence {--tw-bg-opacity: 1;background-color: rgba(75, 85, 99, var(--tw-bg-opacity))
}.gradio_wrapper .gradio_bg[theme=peach] .gradio_interface .output_label .confidence:first-child {background-image: linear-gradient(to top right, var(--tw-gradient-stops));--tw-gradient-from: #ef4444;--tw-gradient-stops: var(--tw-gradient-from), var(--tw-gradient-to, rgba(239, 68, 68, 0));--tw-gradient-to: #fbbf24
}
.dark .gradio_wrapper .gradio_bg[theme=huggingface]{--tw-bg-opacity:1;background-color:rgba(11, 15, 25, var(--tw-bg-opacity))}.gradio_wrapper .gradio_bg[theme=huggingface] .gradio_interface .load_status{--tw-text-opacity:1;color:rgba(55, 65, 81, var(--tw-text-opacity))}.gradio_wrapper .gradio_bg[theme=huggingface] .gradio_interface .component_set{gap:0.75rem;border-radius:0.5rem;border-width:1px;--tw-border-opacity:1;border-color:rgba(243, 244, 246, var(--tw-border-opacity));background-image:linear-gradient(to bottom right, var(--tw-gradient-stops));--tw-gradient-from:#f9fafb;--tw-gradient-stops:var(--tw-gradient-from), var(--tw-gradient-to, rgba(249, 250, 251, 0));--tw-gradient-to:#fff;padding:1rem}.dark .gradio_wrapper .gradio_bg[theme=huggingface] .gradio_interface .component_set{border-style:none;--tw-gradient-from:#374151;--tw-gradient-stops:var(--tw-gradient-from), var(--tw-gradient-to, rgba(55, 65, 81, 0));--tw-gradient-to:#1f2937}.gradio_wrapper .gradio_bg[theme=huggingface] .gradio_interface .panel_header{margin-bottom:0.375rem;display:flex;align-items:center;font-size:0.875rem;line-height:1.25rem;--tw-text-opacity:1;color:rgba(55, 65, 81, var(--tw-text-opacity))}.dark .gradio_wrapper .gradio_bg[theme=huggingface] .gradio_interface .panel_header{--tw-text-opacity:1;color:rgba(249, 250, 251, var(--tw-text-opacity))}.gradio_wrapper .gradio_bg[theme=huggingface] .gradio_interface .panel_button{border-radius:0.5rem;border-width:1px;background-image:linear-gradient(to bottom, var(--tw-gradient-stops));--tw-gradient-from:#f9fafb;--tw-gradient-stops:var(--tw-gradient-from), var(--tw-gradient-to, rgba(249, 250, 251, 0));--tw-gradient-to:#f3f4f6;--tw-shadow:0 1px 2px 0 rgba(0, 0, 0, 0.05);box-shadow:var(--tw-ring-offset-shadow, 0 0 #0000), var(--tw-ring-shadow, 0 0 #0000), var(--tw-shadow)}.gradio_wrapper .gradio_bg[theme=huggingface] .gradio_interface .panel_button:hover{--tw-gradient-from:#f3f4f6;--tw-gradient-stops:var(--tw-gradient-from), var(--tw-gradient-to, rgba(243, 244, 246, 0))}.gradio_wrapper .gradio_bg[theme=huggingface] .gradio_interface .panel_button:focus{--tw-ring-offset-color:#a5b4fc}.dark .gradio_wrapper .gradio_bg[theme=huggingface] .gradio_interface .panel_button{border-style:none;--tw-gradient-from:#374151;--tw-gradient-stops:var(--tw-gradient-from), var(--tw-gradient-to, rgba(55, 65, 81, 0));--tw-gradient-to:#1f2937}.dark .gradio_wrapper .gradio_bg[theme=huggingface] .gradio_interface .panel_button:hover{--tw-gradient-from:#1f2937;--tw-gradient-stops:var(--tw-gradient-from), var(--tw-gradient-to, rgba(31, 41, 55, 0))}.dark .gradio_wrapper .gradio_bg[theme=huggingface] .gradio_interface .panel_button:focus{--tw-ring-offset-color:#4338ca}.gradio_wrapper .gradio_bg[theme=huggingface] .gradio_interface .examples .examples_table_holder:not(.gallery) .examples_table{background-image:linear-gradient(to bottom right, var(--tw-gradient-stops))}.dark .gradio_wrapper .gradio_bg[theme=huggingface] .gradio_interface .examples .examples_table_holder:not(.gallery) .examples_table{--tw-gradient-from:#374151;--tw-gradient-stops:var(--tw-gradient-from), var(--tw-gradient-to, rgba(55, 65, 81, 0));--tw-gradient-to:#1f2937}.gradio_wrapper .gradio_bg[theme=huggingface] .gradio_interface .examples .examples_table_holder:not(.gallery) .examples_table thead{--tw-border-opacity:1;border-color:rgba(243, 244, 246, var(--tw-border-opacity))}.dark .gradio_wrapper .gradio_bg[theme=huggingface] .gradio_interface .examples .examples_table_holder:not(.gallery) .examples_table thead{--tw-border-opacity:1;border-color:rgba(75, 85, 99, var(--tw-border-opacity))}.gradio_wrapper .gradio_bg[theme=huggingface] .gradio_interface .examples .examples_table_holder:not(.gallery) .examples_table tbody tr:hover{--tw-bg-opacity:1;background-color:rgba(99, 102, 241, var(--tw-bg-opacity));--tw-text-opacity:1;color:rgba(255, 255, 255, var(--tw-text-opacity))}.dark .gradio_wrapper .gradio_bg[theme=huggingface] .gradio_interface .examples .examples_table_holder:not(.gallery) .examples_table tbody tr:hover{--tw-bg-opacity:1;background-color:rgba(49, 46, 129, var(--tw-bg-opacity))}.gradio_wrapper .gradio_bg[theme=huggingface] .gradio_interface .examples .examples_table_holder.gallery .examples_table tbody td:hover{--tw-bg-opacity:1;background-color:rgba(99, 102, 241, var(--tw-bg-opacity));--tw-text-opacity:1;color:rgba(255, 255, 255, var(--tw-text-opacity))}.dark .gradio_wrapper .gradio_bg[theme=huggingface] .gradio_interface .examples .examples_table_holder.gallery .examples_table tbody td:hover{--tw-bg-opacity:1;background-color:rgba(49, 46, 129, var(--tw-bg-opacity))}.gradio_wrapper .gradio_bg[theme=huggingface] .gradio_interface .edit_buttons{margin:0.25rem;display:flex;gap:0.25rem}.gradio_wrapper .gradio_bg[theme=huggingface] .gradio_interface .edit_buttons button{border-radius:9999px}.gradio_wrapper .gradio_bg[theme=huggingface] .gradio_interface .edit_buttons img{height:0.75rem}.gradio_wrapper .gradio_bg[theme=huggingface] .gradio_interface .edit_button{--tw-bg-opacity:1;background-color:rgba(129, 140, 248, var(--tw-bg-opacity))}.gradio_wrapper .gradio_bg[theme=huggingface] .gradio_interface .edit_button:hover{--tw-bg-opacity:1;background-color:rgba(99, 102, 241, var(--tw-bg-opacity))}.dark .gradio_wrapper .gradio_bg[theme=huggingface] .gradio_interface .edit_button{--tw-bg-opacity:1;background-color:rgba(99, 102, 241, var(--tw-bg-opacity))}.dark .gradio_wrapper .gradio_bg[theme=huggingface] .gradio_interface .edit_button:hover{--tw-bg-opacity:1;background-color:rgba(129, 140, 248, var(--tw-bg-opacity))}.gradio_wrapper .gradio_bg[theme=huggingface] .gradio_interface .clear_button{--tw-bg-opacity:1;background-color:rgba(209, 213, 219, var(--tw-bg-opacity))}.gradio_wrapper .gradio_bg[theme=huggingface] .gradio_interface .clear_button:hover{--tw-bg-opacity:1;background-color:rgba(156, 163, 175, var(--tw-bg-opacity))}.dark .gradio_wrapper .gradio_bg[theme=huggingface] .gradio_interface .clear_button{--tw-bg-opacity:1;background-color:rgba(156, 163, 175, var(--tw-bg-opacity))}.dark .gradio_wrapper .gradio_bg[theme=huggingface] .gradio_interface .clear_button:hover{--tw-bg-opacity:1;background-color:rgba(209, 213, 219, var(--tw-bg-opacity))}.gradio_wrapper .gradio_bg[theme=huggingface] .gradio_interface .input_text textarea{border-radius:0.5rem;border-width:1px;padding:0.75rem}.gradio_wrapper .gradio_bg[theme=huggingface] .gradio_interface .input_text textarea::-webkit-input-placeholder{--tw-placeholder-opacity:1;color:rgba(156, 163, 175, var(--tw-placeholder-opacity))}.gradio_wrapper .gradio_bg[theme=huggingface] .gradio_interface .input_text textarea:-ms-input-placeholder{--tw-placeholder-opacity:1;color:rgba(156, 163, 175, var(--tw-placeholder-opacity))}.gradio_wrapper .gradio_bg[theme=huggingface] .gradio_interface .input_text textarea::placeholder{--tw-placeholder-opacity:1;color:rgba(156, 163, 175, var(--tw-placeholder-opacity))}.gradio_wrapper .gradio_bg[theme=huggingface] .gradio_interface .input_text textarea{--tw-shadow:inset 0 2px 4px 0 rgba(0, 0, 0, 0.06);box-shadow:var(--tw-ring-offset-shadow, 0 0 #0000), var(--tw-ring-shadow, 0 0 #0000), var(--tw-shadow);outline:2px solid transparent;outline-offset:2px}.gradio_wrapper .gradio_bg[theme=huggingface] .gradio_interface .input_text textarea:focus{--tw-shadow:inset 0 2px 4px 0 rgba(0, 0, 0, 0.06);box-shadow:var(--tw-ring-offset-shadow, 0 0 #0000), var(--tw-ring-shadow, 0 0 #0000), var(--tw-shadow);--tw-ring-offset-shadow:var(--tw-ring-inset) 0 0 0 var(--tw-ring-offset-width) var(--tw-ring-offset-color);--tw-ring-shadow:var(--tw-ring-inset) 0 0 0 calc(1px + var(--tw-ring-offset-width)) var(--tw-ring-color);box-shadow:var(--tw-ring-offset-shadow), var(--tw-ring-shadow), var(--tw-shadow, 0 0 #0000);--tw-ring-inset:inset;--tw-ring-opacity:1;--tw-ring-color:rgba(199, 210, 254, var(--tw-ring-opacity))}.dark .gradio_wrapper .gradio_bg[theme=huggingface] .gradio_interface .input_text textarea{border-style:none;--tw-bg-opacity:1;background-color:rgba(75, 85, 99, var(--tw-bg-opacity))}.dark .gradio_wrapper .gradio_bg[theme=huggingface] .gradio_interface .input_text textarea::-webkit-input-placeholder{--tw-placeholder-opacity:1;color:rgba(243, 244, 246, var(--tw-placeholder-opacity))}.dark .gradio_wrapper .gradio_bg[theme=huggingface] .gradio_interface .input_text textarea:-ms-input-placeholder{--tw-placeholder-opacity:1;color:rgba(243, 244, 246, var(--tw-placeholder-opacity))}.dark .gradio_wrapper .gradio_bg[theme=huggingface] .gradio_interface .input_text textarea::placeholder{--tw-placeholder-opacity:1;color:rgba(243, 244, 246, var(--tw-placeholder-opacity))}.gradio_wrapper .gradio_bg[theme=huggingface] .gradio_interface .input_text input{border-radius:0.5rem;border-width:1px;padding:0.75rem}.gradio_wrapper .gradio_bg[theme=huggingface] .gradio_interface .input_text input::-webkit-input-placeholder{--tw-placeholder-opacity:1;color:rgba(156, 163, 175, var(--tw-placeholder-opacity))}.gradio_wrapper .gradio_bg[theme=huggingface] .gradio_interface .input_text input:-ms-input-placeholder{--tw-placeholder-opacity:1;color:rgba(156, 163, 175, var(--tw-placeholder-opacity))}.gradio_wrapper .gradio_bg[theme=huggingface] .gradio_interface .input_text input::placeholder{--tw-placeholder-opacity:1;color:rgba(156, 163, 175, var(--tw-placeholder-opacity))}.gradio_wrapper .gradio_bg[theme=huggingface] .gradio_interface .input_text input{--tw-shadow:inset 0 2px 4px 0 rgba(0, 0, 0, 0.06);box-shadow:var(--tw-ring-offset-shadow, 0 0 #0000), var(--tw-ring-shadow, 0 0 #0000), var(--tw-shadow);outline:2px solid transparent;outline-offset:2px}.gradio_wrapper .gradio_bg[theme=huggingface] .gradio_interface .input_text input:focus{--tw-shadow:inset 0 2px 4px 0 rgba(0, 0, 0, 0.06);box-shadow:var(--tw-ring-offset-shadow, 0 0 #0000), var(--tw-ring-shadow, 0 0 #0000), var(--tw-shadow);--tw-ring-offset-shadow:var(--tw-ring-inset) 0 0 0 var(--tw-ring-offset-width) var(--tw-ring-offset-color);--tw-ring-shadow:var(--tw-ring-inset) 0 0 0 calc(1px + var(--tw-ring-offset-width)) var(--tw-ring-color);box-shadow:var(--tw-ring-offset-shadow), var(--tw-ring-shadow), var(--tw-shadow, 0 0 #0000);--tw-ring-inset:inset;--tw-ring-opacity:1;--tw-ring-color:rgba(199, 210, 254, var(--tw-ring-opacity))}.dark .gradio_wrapper .gradio_bg[theme=huggingface] .gradio_interface .input_text input{border-style:none;--tw-bg-opacity:1;background-color:rgba(75, 85, 99, var(--tw-bg-opacity))}.dark .gradio_wrapper .gradio_bg[theme=huggingface] .gradio_interface .input_text input::-webkit-input-placeholder{--tw-placeholder-opacity:1;color:rgba(243, 244, 246, var(--tw-placeholder-opacity))}.dark .gradio_wrapper .gradio_bg[theme=huggingface] .gradio_interface .input_text input:-ms-input-placeholder{--tw-placeholder-opacity:1;color:rgba(243, 244, 246, var(--tw-placeholder-opacity))}.dark .gradio_wrapper .gradio_bg[theme=huggingface] .gradio_interface .input_text input::placeholder{--tw-placeholder-opacity:1;color:rgba(243, 244, 246, var(--tw-placeholder-opacity))}.gradio_wrapper .gradio_bg[theme=huggingface] .gradio_interface .input_number input{border-radius:0.5rem;border-width:1px;padding:0.75rem}.gradio_wrapper .gradio_bg[theme=huggingface] .gradio_interface .input_number input::-webkit-input-placeholder{--tw-placeholder-opacity:1;color:rgba(156, 163, 175, var(--tw-placeholder-opacity))}.gradio_wrapper .gradio_bg[theme=huggingface] .gradio_interface .input_number input:-ms-input-placeholder{--tw-placeholder-opacity:1;color:rgba(156, 163, 175, var(--tw-placeholder-opacity))}.gradio_wrapper .gradio_bg[theme=huggingface] .gradio_interface .input_number input::placeholder{--tw-placeholder-opacity:1;color:rgba(156, 163, 175, var(--tw-placeholder-opacity))}.gradio_wrapper .gradio_bg[theme=huggingface] .gradio_interface .input_number input{--tw-shadow:inset 0 2px 4px 0 rgba(0, 0, 0, 0.06);box-shadow:var(--tw-ring-offset-shadow, 0 0 #0000), var(--tw-ring-shadow, 0 0 #0000), var(--tw-shadow);outline:2px solid transparent;outline-offset:2px}.gradio_wrapper .gradio_bg[theme=huggingface] .gradio_interface .input_number input:focus{--tw-shadow:inset 0 2px 4px 0 rgba(0, 0, 0, 0.06);box-shadow:var(--tw-ring-offset-shadow, 0 0 #0000), var(--tw-ring-shadow, 0 0 #0000), var(--tw-shadow);--tw-ring-offset-shadow:var(--tw-ring-inset) 0 0 0 var(--tw-ring-offset-width) var(--tw-ring-offset-color);--tw-ring-shadow:var(--tw-ring-inset) 0 0 0 calc(1px + var(--tw-ring-offset-width)) var(--tw-ring-color);box-shadow:var(--tw-ring-offset-shadow), var(--tw-ring-shadow), var(--tw-shadow, 0 0 #0000);--tw-ring-inset:inset;--tw-ring-opacity:1;--tw-ring-color:rgba(199, 210, 254, var(--tw-ring-opacity))}.dark .gradio_wrapper .gradio_bg[theme=huggingface] .gradio_interface .input_number input{border-style:none;--tw-bg-opacity:1;background-color:rgba(75, 85, 99, var(--tw-bg-opacity))}.dark .gradio_wrapper .gradio_bg[theme=huggingface] .gradio_interface .input_number input::-webkit-input-placeholder{--tw-placeholder-opacity:1;color:rgba(243, 244, 246, var(--tw-placeholder-opacity))}.dark .gradio_wrapper .gradio_bg[theme=huggingface] .gradio_interface .input_number input:-ms-input-placeholder{--tw-placeholder-opacity:1;color:rgba(243, 244, 246, var(--tw-placeholder-opacity))}.dark .gradio_wrapper .gradio_bg[theme=huggingface] .gradio_interface .input_number input::placeholder{--tw-placeholder-opacity:1;color:rgba(243, 244, 246, var(--tw-placeholder-opacity))}.gradio_wrapper .gradio_bg[theme=huggingface] .gradio_interface .input_radio .radio_item{border-width:1px;background-image:linear-gradient(to top, var(--tw-gradient-stops));--tw-gradient-from:#f3f4f6;--tw-gradient-stops:var(--tw-gradient-from), var(--tw-gradient-to, rgba(243, 244, 246, 0));--tw-gradient-to:#f9fafb;padding-top:0.375rem;padding-bottom:0.375rem;padding-left:0.75rem;padding-right:0.75rem;--tw-text-opacity:1;color:rgba(75, 85, 99, var(--tw-text-opacity))}.gradio_wrapper .gradio_bg[theme=huggingface] .gradio_interface .input_radio .radio_item:hover{--tw-gradient-to:#f3f4f6}.dark .gradio_wrapper .gradio_bg[theme=huggingface] .gradio_interface .input_radio .radio_item{border-style:none;--tw-gradient-from:#4b5563;--tw-gradient-stops:var(--tw-gradient-from), var(--tw-gradient-to, rgba(75, 85, 99, 0));--tw-gradient-to:#6b7280;--tw-text-opacity:1;color:rgba(249, 250, 251, var(--tw-text-opacity))}.dark .gradio_wrapper .gradio_bg[theme=huggingface] .gradio_interface .input_radio .radio_item:hover{--tw-gradient-to:#4b5563}.gradio_wrapper .gradio_bg[theme=huggingface] .gradio_interface .input_radio .radio_item.selected{--tw-text-opacity:1;color:rgba(99, 102, 241, var(--tw-text-opacity))}.dark .gradio_wrapper .gradio_bg[theme=huggingface] .gradio_interface .input_radio .radio_item.selected{--tw-gradient-from:#4f46e5;--tw-gradient-stops:var(--tw-gradient-from), var(--tw-gradient-to, rgba(79, 70, 229, 0));--tw-gradient-to:#6366f1;--tw-text-opacity:1;color:rgba(255, 255, 255, var(--tw-text-opacity))}.gradio_wrapper .gradio_bg[theme=huggingface] .gradio_interface .input_radio .radio_circle{--tw-bg-opacity:1;background-color:rgba(255, 255, 255, var(--tw-bg-opacity))}.gradio_wrapper .gradio_bg[theme=huggingface] .gradio_interface .input_radio .selected .radio_circle{border-width:4px;--tw-border-opacity:1;border-color:rgba(79, 70, 229, var(--tw-border-opacity))}.dark .gradio_wrapper .gradio_bg[theme=huggingface] .gradio_interface .input_radio .selected .radio_circle{--tw-border-opacity:1;border-color:rgba(129, 140, 248, var(--tw-border-opacity))}.gradio_wrapper .gradio_bg[theme=huggingface] .gradio_interface .input_checkbox_group .checkbox_item, .gradio_wrapper .gradio_bg[theme=huggingface] .gradio_interface .input_checkbox .checkbox_item{border-width:1px;background-image:linear-gradient(to top, var(--tw-gradient-stops));--tw-gradient-from:#f3f4f6;--tw-gradient-stops:var(--tw-gradient-from), var(--tw-gradient-to, rgba(243, 244, 246, 0));--tw-gradient-to:#f9fafb;padding-top:0.375rem;padding-bottom:0.375rem;padding-left:0.75rem;padding-right:0.75rem;--tw-text-opacity:1;color:rgba(75, 85, 99, var(--tw-text-opacity))}.gradio_wrapper .gradio_bg[theme=huggingface] .gradio_interface .input_checkbox_group .checkbox_item:hover, .gradio_wrapper .gradio_bg[theme=huggingface] .gradio_interface .input_checkbox .checkbox_item:hover{--tw-gradient-to:#f3f4f6}.dark .gradio_wrapper .gradio_bg[theme=huggingface] .gradio_interface .input_checkbox_group .checkbox_item, .dark .gradio_wrapper .gradio_bg[theme=huggingface] .gradio_interface .input_checkbox .checkbox_item{border-style:none;--tw-gradient-from:#4b5563;--tw-gradient-stops:var(--tw-gradient-from), var(--tw-gradient-to, rgba(75, 85, 99, 0));--tw-gradient-to:#6b7280;--tw-text-opacity:1;color:rgba(249, 250, 251, var(--tw-text-opacity))}.dark .gradio_wrapper .gradio_bg[theme=huggingface] .gradio_interface .input_checkbox_group .checkbox_item:hover, .dark .gradio_wrapper .gradio_bg[theme=huggingface] .gradio_interface .input_checkbox .checkbox_item:hover{--tw-gradient-to:#4b5563}.gradio_wrapper .gradio_bg[theme=huggingface] .gradio_interface .input_checkbox_group .checkbox_item.selected, .gradio_wrapper .gradio_bg[theme=huggingface] .gradio_interface .input_checkbox .checkbox_item.selected{--tw-text-opacity:1;color:rgba(99, 102, 241, var(--tw-text-opacity))}.dark .gradio_wrapper .gradio_bg[theme=huggingface] .gradio_interface .input_checkbox_group .checkbox_item.selected, .dark .gradio_wrapper .gradio_bg[theme=huggingface] .gradio_interface .input_checkbox .checkbox_item.selected{--tw-gradient-from:#4f46e5;--tw-gradient-stops:var(--tw-gradient-from), var(--tw-gradient-to, rgba(79, 70, 229, 0));--tw-gradient-to:#6366f1;--tw-text-opacity:1;color:rgba(255, 255, 255, var(--tw-text-opacity))}.gradio_wrapper .gradio_bg[theme=huggingface] .gradio_interface .input_checkbox_group .selected .checkbox, .gradio_wrapper .gradio_bg[theme=huggingface] .gradio_interface .input_checkbox .selected .checkbox{--tw-bg-opacity:1;background-color:rgba(79, 70, 229, var(--tw-bg-opacity))}.dark .gradio_wrapper .gradio_bg[theme=huggingface] .gradio_interface .input_checkbox_group .selected .checkbox, .dark .gradio_wrapper .gradio_bg[theme=huggingface] .gradio_interface .input_checkbox .selected .checkbox{--tw-bg-opacity:1;background-color:rgba(129, 140, 248, var(--tw-bg-opacity))}.gradio_wrapper .gradio_bg[theme=huggingface] .gradio_interface .input_dropdown .selector{border-width:1px;background-image:linear-gradient(to top, var(--tw-gradient-stops));--tw-gradient-from:#f3f4f6;--tw-gradient-stops:var(--tw-gradient-from), var(--tw-gradient-to, rgba(243, 244, 246, 0));--tw-gradient-to:#f9fafb;padding-top:0.375rem;padding-bottom:0.375rem;padding-left:0.75rem;padding-right:0.75rem;--tw-text-opacity:1;color:rgba(75, 85, 99, var(--tw-text-opacity))}.gradio_wrapper .gradio_bg[theme=huggingface] .gradio_interface .input_dropdown .selector:hover{--tw-gradient-to:#f3f4f6}.dark .gradio_wrapper .gradio_bg[theme=huggingface] .gradio_interface .input_dropdown .selector{border-style:none;--tw-gradient-from:#4b5563;--tw-gradient-stops:var(--tw-gradient-from), var(--tw-gradient-to, rgba(75, 85, 99, 0));--tw-gradient-to:#6b7280;--tw-text-opacity:1;color:rgba(249, 250, 251, var(--tw-text-opacity))}.dark .gradio_wrapper .gradio_bg[theme=huggingface] .gradio_interface .input_dropdown .selector:hover{--tw-gradient-to:#4b5563}.gradio_wrapper .gradio_bg[theme=huggingface] .gradio_interface .input_dropdown .dropdown_item{--tw-bg-opacity:1;background-color:rgba(249, 250, 251, var(--tw-bg-opacity))}.gradio_wrapper .gradio_bg[theme=huggingface] .gradio_interface .input_dropdown .dropdown_item:hover{--tw-bg-opacity:1;background-color:rgba(156, 163, 175, var(--tw-bg-opacity));--tw-text-opacity:1;color:rgba(249, 250, 251, var(--tw-text-opacity))}.dark .gradio_wrapper .gradio_bg[theme=huggingface] .gradio_interface .input_dropdown .dropdown_item{--tw-bg-opacity:1;background-color:rgba(107, 114, 128, var(--tw-bg-opacity))}.dark .gradio_wrapper .gradio_bg[theme=huggingface] .gradio_interface .input_dropdown .dropdown_item:hover{--tw-bg-opacity:1;background-color:rgba(79, 70, 229, var(--tw-bg-opacity))}.gradio_wrapper .gradio_bg[theme=huggingface] .gradio_interface .input_slider{text-align:center}.gradio_wrapper .gradio_bg[theme=huggingface] .gradio_interface .input_slider .range{border-radius:9999px;border-width:1px;--tw-bg-opacity:1;background-color:rgba(255, 255, 255, var(--tw-bg-opacity))}.gradio_wrapper .gradio_bg[theme=huggingface] .gradio_interface .input_slider .range:hover{--tw-bg-opacity:1;background-color:rgba(243, 244, 246, var(--tw-bg-opacity))}.dark .gradio_wrapper .gradio_bg[theme=huggingface] .gradio_interface .input_slider .range{border-style:none;--tw-bg-opacity:1;background-color:rgba(75, 85, 99, var(--tw-bg-opacity))}.gradio_wrapper .gradio_bg[theme=huggingface] .gradio_interface .input_slider .range::-webkit-slider-thumb{border-radius:9999px;border-width:1px;--tw-bg-opacity:1;background-color:rgba(99, 102, 241, var(--tw-bg-opacity));--tw-shadow:0 1px 3px 0 rgba(0, 0, 0, 0.1), 0 1px 2px 0 rgba(0, 0, 0, 0.06);box-shadow:var(--tw-ring-offset-shadow, 0 0 #0000), var(--tw-ring-shadow, 0 0 #0000), var(--tw-shadow)}.dark .gradio_wrapper .gradio_bg[theme=huggingface] .gradio_interface .input_slider .range::-webkit-slider-thumb{--tw-bg-opacity:1;background-color:rgba(255, 255, 255, var(--tw-bg-opacity))}.gradio_wrapper .gradio_bg[theme=huggingface] .gradio_interface .input_slider .range::-moz-range-thumb{border-radius:9999px;border-width:1px;--tw-bg-opacity:1;background-color:rgba(99, 102, 241, var(--tw-bg-opacity));--tw-shadow:0 1px 3px 0 rgba(0, 0, 0, 0.1), 0 1px 2px 0 rgba(0, 0, 0, 0.06);box-shadow:var(--tw-ring-offset-shadow, 0 0 #0000), var(--tw-ring-shadow, 0 0 #0000), var(--tw-shadow)}.dark .gradio_wrapper .gradio_bg[theme=huggingface] .gradio_interface .input_slider .range::-moz-range-thumb{--tw-bg-opacity:1;background-color:rgba(255, 255, 255, var(--tw-bg-opacity))}.gradio_wrapper .gradio_bg[theme=huggingface] .gradio_interface .input_slider .value{--tw-bg-opacity:1;background-color:rgba(243, 244, 246, var(--tw-bg-opacity));--tw-text-opacity:1;color:rgba(55, 65, 81, var(--tw-text-opacity));--tw-shadow:inset 0 2px 4px 0 rgba(0, 0, 0, 0.06);box-shadow:var(--tw-ring-offset-shadow, 0 0 #0000), var(--tw-ring-shadow, 0 0 #0000), var(--tw-shadow)}.dark .gradio_wrapper .gradio_bg[theme=huggingface] .gradio_interface .input_slider .value{border-style:none;--tw-bg-opacity:1;background-color:rgba(75, 85, 99, var(--tw-bg-opacity));--tw-text-opacity:1;color:rgba(249, 250, 251, var(--tw-text-opacity))}.gradio_wrapper .gradio_bg[theme=huggingface] .gradio_interface .input_audio .start{border-width:1px;background-image:linear-gradient(to top, var(--tw-gradient-stops));--tw-gradient-from:#f3f4f6;--tw-gradient-stops:var(--tw-gradient-from), var(--tw-gradient-to, rgba(243, 244, 246, 0));--tw-gradient-to:#f9fafb;padding-top:0.375rem;padding-bottom:0.375rem;padding-left:0.75rem;padding-right:0.75rem;--tw-text-opacity:1;color:rgba(75, 85, 99, var(--tw-text-opacity))}.gradio_wrapper .gradio_bg[theme=huggingface] .gradio_interface .input_audio .start:hover{--tw-gradient-to:#f3f4f6}.dark .gradio_wrapper .gradio_bg[theme=huggingface] .gradio_interface .input_audio .start{border-style:none;--tw-gradient-from:#4b5563;--tw-gradient-stops:var(--tw-gradient-from), var(--tw-gradient-to, rgba(75, 85, 99, 0));--tw-gradient-to:#6b7280;--tw-text-opacity:1;color:rgba(249, 250, 251, var(--tw-text-opacity))}.dark .gradio_wrapper .gradio_bg[theme=huggingface] .gradio_interface .input_audio .start:hover{--tw-gradient-to:#4b5563}.gradio_wrapper .gradio_bg[theme=huggingface] .gradio_interface .input_audio .stop{border-width:1px;--tw-border-opacity:1;border-color:rgba(254, 202, 202, var(--tw-border-opacity));background-image:linear-gradient(to top, var(--tw-gradient-stops));--tw-gradient-from:#fecaca;--tw-gradient-stops:var(--tw-gradient-from), var(--tw-gradient-to, rgba(254, 202, 202, 0));--tw-gradient-to:#fef2f2;padding-top:0.375rem;padding-bottom:0.375rem;padding-left:0.75rem;padding-right:0.75rem;--tw-text-opacity:1;color:rgba(220, 38, 38, var(--tw-text-opacity))}.gradio_wrapper .gradio_bg[theme=huggingface] .gradio_interface .input_audio .stop:hover{--tw-gradient-to:#fee2e2}.dark .gradio_wrapper .gradio_bg[theme=huggingface] .gradio_interface .input_audio .stop{--tw-gradient-from:#b91c1c;--tw-gradient-stops:var(--tw-gradient-from), var(--tw-gradient-to, rgba(185, 28, 28, 0));--tw-gradient-to:#dc2626;--tw-text-opacity:1;color:rgba(254, 226, 226, var(--tw-text-opacity))}.gradio_wrapper .gradio_bg[theme=huggingface] .gradio_interface .output_text{white-space:pre-wrap;border-radius:0.5rem;border-width:1px;padding:0.75rem;--tw-shadow:inset 0 2px 4px 0 rgba(0, 0, 0, 0.06);box-shadow:var(--tw-ring-offset-shadow, 0 0 #0000), var(--tw-ring-shadow, 0 0 #0000), var(--tw-shadow);outline:2px solid transparent;outline-offset:2px}.gradio_wrapper .gradio_bg[theme=huggingface] .gradio_interface .output_text:focus{--tw-shadow:inset 0 2px 4px 0 rgba(0, 0, 0, 0.06);box-shadow:var(--tw-ring-offset-shadow, 0 0 #0000), var(--tw-ring-shadow, 0 0 #0000), var(--tw-shadow);--tw-ring-offset-shadow:var(--tw-ring-inset) 0 0 0 var(--tw-ring-offset-width) var(--tw-ring-offset-color);--tw-ring-shadow:var(--tw-ring-inset) 0 0 0 calc(1px + var(--tw-ring-offset-width)) var(--tw-ring-color);box-shadow:var(--tw-ring-offset-shadow), var(--tw-ring-shadow), var(--tw-shadow, 0 0 #0000);--tw-ring-inset:inset;--tw-ring-opacity:1;--tw-ring-color:rgba(199, 210, 254, var(--tw-ring-opacity))}.dark .gradio_wrapper .gradio_bg[theme=huggingface] .gradio_interface .output_text{border-style:none;--tw-bg-opacity:1;background-color:rgba(75, 85, 99, var(--tw-bg-opacity))}.gradio_wrapper .gradio_bg[theme=huggingface] .gradio_interface .output_label .output_class{display:none}.gradio_wrapper .gradio_bg[theme=huggingface] .gradio_interface .output_label .confidence{border-radius:0.25rem;background-image:linear-gradient(to right, var(--tw-gradient-stops));--tw-gradient-from:#c7d2fe;--tw-gradient-stops:var(--tw-gradient-from), var(--tw-gradient-to, rgba(199, 210, 254, 0));--tw-gradient-to:#6366f1;--tw-text-opacity:1;color:rgba(255, 255, 255, var(--tw-text-opacity))}.dark .gradio_wrapper .gradio_bg[theme=huggingface] .gradio_interface .output_label .confidence{--tw-gradient-from:#6366f1;--tw-gradient-stops:var(--tw-gradient-from), var(--tw-gradient-to, rgba(99, 102, 241, 0));--tw-gradient-to:#4338ca}.gradio_wrapper .gradio_bg[theme=huggingface] .gradio_interface .output_label .confidence{color:transparent}
.gradio_wrapper .gradio_bg[theme=default] .gradio_interface .component_set {--tw-bg-opacity: 1;background-color: rgba(249, 250, 251, var(--tw-bg-opacity));--tw-shadow: 0 1px 3px 0 rgba(0, 0, 0, 0.1), 0 1px 2px 0 rgba(0, 0, 0, 0.06);box-shadow: var(--tw-ring-offset-shadow, 0 0 #0000), var(--tw-ring-shadow, 0 0 #0000), var(--tw-shadow)
}.dark .gradio_wrapper .gradio_bg[theme=default] .gradio_interface .component_set {--tw-bg-opacity: 1;background-color: rgba(55, 65, 81, var(--tw-bg-opacity));--tw-drop-shadow: drop-shadow(0 20px 13px rgba(0, 0, 0, 0.03)) drop-shadow(0 8px 5px rgba(0, 0, 0, 0.08));-webkit-filter: var(--tw-filter);filter: var(--tw-filter)
}.gradio_wrapper .gradio_bg[theme=default] .gradio_interface .component {margin-bottom: 0.5rem
}.gradio_wrapper .gradio_bg[theme=default] .gradio_interface .panel_header {font-size: 0.75rem;line-height: 1rem;text-transform: uppercase
}.gradio_wrapper .gradio_bg[theme=default] .gradio_interface .panel_button {--tw-shadow: 0 1px 3px 0 rgba(0, 0, 0, 0.1), 0 1px 2px 0 rgba(0, 0, 0, 0.06);box-shadow: var(--tw-ring-offset-shadow, 0 0 #0000), var(--tw-ring-shadow, 0 0 #0000), var(--tw-shadow)
}.gradio_wrapper .gradio_bg[theme=default] .gradio_interface .panel_button:hover {--tw-bg-opacity: 1;background-color: rgba(243, 244, 246, var(--tw-bg-opacity))
}.dark .gradio_wrapper .gradio_bg[theme=default] .gradio_interface .panel_button:hover {--tw-bg-opacity: 1;background-color: rgba(75, 85, 99, var(--tw-bg-opacity))
}.gradio_wrapper .gradio_bg[theme=default] .gradio_interface .panel_button.disabled {cursor: not-allowed;--tw-text-opacity: 1;color: rgba(156, 163, 175, var(--tw-text-opacity))
}.gradio_wrapper .gradio_bg[theme=default] .gradio_interface .panel_button.submit {--tw-bg-opacity: 1;background-color: rgba(245, 158, 11, var(--tw-bg-opacity));--tw-text-opacity: 1;color: rgba(255, 255, 255, var(--tw-text-opacity))
}.gradio_wrapper .gradio_bg[theme=default] .gradio_interface .panel_button.submit:hover {--tw-bg-opacity: 1;background-color: rgba(251, 191, 36, var(--tw-bg-opacity))
}.dark .gradio_wrapper .gradio_bg[theme=default] .gradio_interface .panel_button.submit {--tw-bg-opacity: 1;background-color: rgba(185, 28, 28, var(--tw-bg-opacity))
}.dark .gradio_wrapper .gradio_bg[theme=default] .gradio_interface .panel_button.submit:hover {--tw-bg-opacity: 1;background-color: rgba(220, 38, 38, var(--tw-bg-opacity))
}.gradio_wrapper .gradio_bg[theme=default] .gradio_interface .examples .examples_table_holder:not(.gallery) {--tw-shadow: 0 1px 3px 0 rgba(0, 0, 0, 0.1), 0 1px 2px 0 rgba(0, 0, 0, 0.06);box-shadow: var(--tw-ring-offset-shadow, 0 0 #0000), var(--tw-ring-shadow, 0 0 #0000), var(--tw-shadow)
}.gradio_wrapper .gradio_bg[theme=default] .gradio_interface .examples .examples_table_holder:not(.gallery) .examples_table {border-radius: 0.25rem
}.dark .gradio_wrapper .gradio_bg[theme=default] .gradio_interface .examples .examples_table_holder:not(.gallery) .examples_table {--tw-bg-opacity: 1;background-color: rgba(55, 65, 81, var(--tw-bg-opacity))
}.gradio_wrapper .gradio_bg[theme=default] .gradio_interface .examples .examples_table_holder:not(.gallery) .examples_table thead {--tw-border-opacity: 1;border-color: rgba(209, 213, 219, var(--tw-border-opacity))
}.dark .gradio_wrapper .gradio_bg[theme=default] .gradio_interface .examples .examples_table_holder:not(.gallery) .examples_table thead {--tw-border-opacity: 1;border-color: rgba(75, 85, 99, var(--tw-border-opacity))
}.gradio_wrapper .gradio_bg[theme=default] .gradio_interface .examples .examples_table_holder:not(.gallery) .examples_table tbody tr:hover {--tw-bg-opacity: 1;background-color: rgba(245, 158, 11, var(--tw-bg-opacity));--tw-text-opacity: 1;color: rgba(255, 255, 255, var(--tw-text-opacity))
}.dark .gradio_wrapper .gradio_bg[theme=default] .gradio_interface .examples .examples_table_holder:not(.gallery) .examples_table tbody tr:hover {--tw-bg-opacity: 1;background-color: rgba(185, 28, 28, var(--tw-bg-opacity))
}.gradio_wrapper .gradio_bg[theme=default] .gradio_interface .examples .examples_table_holder.gallery .examples_table tbody td {--tw-shadow: 0 1px 3px 0 rgba(0, 0, 0, 0.1), 0 1px 2px 0 rgba(0, 0, 0, 0.06);box-shadow: var(--tw-ring-offset-shadow, 0 0 #0000), var(--tw-ring-shadow, 0 0 #0000), var(--tw-shadow)
}.gradio_wrapper .gradio_bg[theme=default] .gradio_interface .examples .examples_table_holder.gallery .examples_table tbody td:hover {--tw-bg-opacity: 1;background-color: rgba(245, 158, 11, var(--tw-bg-opacity));--tw-text-opacity: 1;color: rgba(255, 255, 255, var(--tw-text-opacity))
}.gradio_wrapper .gradio_bg[theme=default] .gradio_interface .edit_buttons {margin: 0.25rem;display: flex;gap: 0.25rem
}.gradio_wrapper .gradio_bg[theme=default] .gradio_interface .edit_button {border-radius: 0.25rem;--tw-bg-opacity: 1;background-color: rgba(245, 158, 11, var(--tw-bg-opacity));--tw-shadow: 0 1px 3px 0 rgba(0, 0, 0, 0.1), 0 1px 2px 0 rgba(0, 0, 0, 0.06);box-shadow: var(--tw-ring-offset-shadow, 0 0 #0000), var(--tw-ring-shadow, 0 0 #0000), var(--tw-shadow)
}.dark .gradio_wrapper .gradio_bg[theme=default] .gradio_interface .edit_button {--tw-bg-opacity: 1;background-color: rgba(220, 38, 38, var(--tw-bg-opacity))
}.gradio_wrapper .gradio_bg[theme=default] .gradio_interface .clear_button {border-radius: 0.25rem;--tw-bg-opacity: 1;background-color: rgba(249, 250, 251, var(--tw-bg-opacity));--tw-shadow: 0 1px 3px 0 rgba(0, 0, 0, 0.1), 0 1px 2px 0 rgba(0, 0, 0, 0.06);box-shadow: var(--tw-ring-offset-shadow, 0 0 #0000), var(--tw-ring-shadow, 0 0 #0000), var(--tw-shadow)
}.dark .gradio_wrapper .gradio_bg[theme=default] .gradio_interface .clear_button {--tw-bg-opacity: 1;background-color: rgba(107, 114, 128, var(--tw-bg-opacity))
}.gradio_wrapper .gradio_bg[theme=default] .gradio_interface .upload_zone {transition-property: background-color, border-color, color, fill, stroke, opacity, box-shadow, -webkit-transform, -webkit-filter, -webkit-backdrop-filter;transition-property: background-color, border-color, color, fill, stroke, opacity, box-shadow, transform, filter, backdrop-filter;transition-property: background-color, border-color, color, fill, stroke, opacity, box-shadow, transform, filter, backdrop-filter, -webkit-transform, -webkit-filter, -webkit-backdrop-filter;transition-timing-function: cubic-bezier(0.4, 0, 0.2, 1);transition-duration: 150ms
}.gradio_wrapper .gradio_bg[theme=default] .gradio_interface .upload_zone:hover {--tw-border-opacity: 1;border-color: rgba(156, 163, 175, var(--tw-border-opacity));--tw-text-opacity: 1;color: rgba(107, 114, 128, var(--tw-text-opacity))
}.dark .gradio_wrapper .gradio_bg[theme=default] .gradio_interface .upload_zone:hover {--tw-border-opacity: 1;border-color: rgba(209, 213, 219, var(--tw-border-opacity));--tw-text-opacity: 1;color: rgba(209, 213, 219, var(--tw-text-opacity))
}.gradio_wrapper .gradio_bg[theme=default] .gradio_interface .input_text input, .gradio_wrapper .gradio_bg[theme=default] .gradio_interface .input_text textarea {--tw-shadow: 0 1px 3px 0 rgba(0, 0, 0, 0.1), 0 1px 2px 0 rgba(0, 0, 0, 0.06);box-shadow: var(--tw-ring-offset-shadow, 0 0 #0000), var(--tw-ring-shadow, 0 0 #0000), var(--tw-shadow);transition-property: background-color, border-color, color, fill, stroke, opacity, box-shadow, -webkit-transform, -webkit-filter, -webkit-backdrop-filter;transition-property: background-color, border-color, color, fill, stroke, opacity, box-shadow, transform, filter, backdrop-filter;transition-property: background-color, border-color, color, fill, stroke, opacity, box-shadow, transform, filter, backdrop-filter, -webkit-transform, -webkit-filter, -webkit-backdrop-filter;transition-timing-function: cubic-bezier(0.4, 0, 0.2, 1);transition-duration: 150ms
}.gradio_wrapper .gradio_bg[theme=default] .gradio_interface .input_text input:hover, .gradio_wrapper .gradio_bg[theme=default] .gradio_interface .input_text textarea:hover {--tw-shadow: 0 4px 6px -1px rgba(0, 0, 0, 0.1), 0 2px 4px -1px rgba(0, 0, 0, 0.06);box-shadow: var(--tw-ring-offset-shadow, 0 0 #0000), var(--tw-ring-shadow, 0 0 #0000), var(--tw-shadow)
}.dark .gradio_wrapper .gradio_bg[theme=default] .gradio_interface .input_text input, .dark .gradio_wrapper .gradio_bg[theme=default] .gradio_interface .input_text textarea {--tw-bg-opacity: 1;background-color: rgba(31, 41, 55, var(--tw-bg-opacity))
}.gradio_wrapper .gradio_bg[theme=default] .gradio_interface .input_number input {--tw-shadow: 0 1px 3px 0 rgba(0, 0, 0, 0.1), 0 1px 2px 0 rgba(0, 0, 0, 0.06);box-shadow: var(--tw-ring-offset-shadow, 0 0 #0000), var(--tw-ring-shadow, 0 0 #0000), var(--tw-shadow);transition-property: background-color, border-color, color, fill, stroke, opacity, box-shadow, -webkit-transform, -webkit-filter, -webkit-backdrop-filter;transition-property: background-color, border-color, color, fill, stroke, opacity, box-shadow, transform, filter, backdrop-filter;transition-property: background-color, border-color, color, fill, stroke, opacity, box-shadow, transform, filter, backdrop-filter, -webkit-transform, -webkit-filter, -webkit-backdrop-filter;transition-timing-function: cubic-bezier(0.4, 0, 0.2, 1);transition-duration: 150ms
}.gradio_wrapper .gradio_bg[theme=default] .gradio_interface .input_number input:hover {--tw-shadow: 0 4px 6px -1px rgba(0, 0, 0, 0.1), 0 2px 4px -1px rgba(0, 0, 0, 0.06);box-shadow: var(--tw-ring-offset-shadow, 0 0 #0000), var(--tw-ring-shadow, 0 0 #0000), var(--tw-shadow)
}.dark .gradio_wrapper .gradio_bg[theme=default] .gradio_interface .input_number input {--tw-bg-opacity: 1;background-color: rgba(31, 41, 55, var(--tw-bg-opacity))
}.gradio_wrapper .gradio_bg[theme=default] .gradio_interface .input_radio .radio_item {--tw-bg-opacity: 1;background-color: rgba(255, 255, 255, var(--tw-bg-opacity));--tw-shadow: 0 1px 3px 0 rgba(0, 0, 0, 0.1), 0 1px 2px 0 rgba(0, 0, 0, 0.06);box-shadow: var(--tw-ring-offset-shadow, 0 0 #0000), var(--tw-ring-shadow, 0 0 #0000), var(--tw-shadow);transition-property: background-color, border-color, color, fill, stroke, opacity, box-shadow, -webkit-transform, -webkit-filter, -webkit-backdrop-filter;transition-property: background-color, border-color, color, fill, stroke, opacity, box-shadow, transform, filter, backdrop-filter;transition-property: background-color, border-color, color, fill, stroke, opacity, box-shadow, transform, filter, backdrop-filter, -webkit-transform, -webkit-filter, -webkit-backdrop-filter;transition-timing-function: cubic-bezier(0.4, 0, 0.2, 1);transition-duration: 150ms
}.gradio_wrapper .gradio_bg[theme=default] .gradio_interface .input_radio .radio_item:hover {--tw-shadow: 0 4px 6px -1px rgba(0, 0, 0, 0.1), 0 2px 4px -1px rgba(0, 0, 0, 0.06);box-shadow: var(--tw-ring-offset-shadow, 0 0 #0000), var(--tw-ring-shadow, 0 0 #0000), var(--tw-shadow)
}.dark .gradio_wrapper .gradio_bg[theme=default] .gradio_interface .input_radio .radio_item {--tw-bg-opacity: 1;background-color: rgba(31, 41, 55, var(--tw-bg-opacity))
}.gradio_wrapper .gradio_bg[theme=default] .gradio_interface .input_radio .radio_circle {border-width: 4px;--tw-border-opacity: 1;border-color: rgba(229, 231, 235, var(--tw-border-opacity));--tw-bg-opacity: 1;background-color: rgba(249, 250, 251, var(--tw-bg-opacity))
}.dark .gradio_wrapper .gradio_bg[theme=default] .gradio_interface .input_radio .radio_circle {--tw-border-opacity: 1;border-color: rgba(75, 85, 99, var(--tw-border-opacity));--tw-bg-opacity: 1;background-color: rgba(156, 163, 175, var(--tw-bg-opacity))
}.gradio_wrapper .gradio_bg[theme=default] .gradio_interface .input_radio .radio_item.selected {--tw-bg-opacity: 1;background-color: rgba(245, 158, 11, var(--tw-bg-opacity));--tw-text-opacity: 1;color: rgba(255, 255, 255, var(--tw-text-opacity));--tw-shadow: 0 1px 3px 0 rgba(0, 0, 0, 0.1), 0 1px 2px 0 rgba(0, 0, 0, 0.06);box-shadow: var(--tw-ring-offset-shadow, 0 0 #0000), var(--tw-ring-shadow, 0 0 #0000), var(--tw-shadow)
}.dark .gradio_wrapper .gradio_bg[theme=default] .gradio_interface .input_radio .radio_item.selected {--tw-bg-opacity: 1;background-color: rgba(220, 38, 38, var(--tw-bg-opacity))
}.gradio_wrapper .gradio_bg[theme=default] .gradio_interface .input_radio .radio_circle {box-sizing: border-box;height: 1rem;width: 1rem;border-radius: 9999px;--tw-bg-opacity: 1;background-color: rgba(255, 255, 255, var(--tw-bg-opacity));transition-property: background-color, border-color, color, fill, stroke, opacity, box-shadow, -webkit-transform, -webkit-filter, -webkit-backdrop-filter;transition-property: background-color, border-color, color, fill, stroke, opacity, box-shadow, transform, filter, backdrop-filter;transition-property: background-color, border-color, color, fill, stroke, opacity, box-shadow, transform, filter, backdrop-filter, -webkit-transform, -webkit-filter, -webkit-backdrop-filter;transition-timing-function: cubic-bezier(0.4, 0, 0.2, 1);transition-duration: 150ms
}.gradio_wrapper .gradio_bg[theme=default] .gradio_interface .input_radio .selected .radio_circle {--tw-border-opacity: 1;border-color: rgba(217, 119, 6, var(--tw-border-opacity))
}.dark .gradio_wrapper .gradio_bg[theme=default] .gradio_interface .input_radio .selected .radio_circle {--tw-border-opacity: 1;border-color: rgba(185, 28, 28, var(--tw-border-opacity))
}.dark .gradio_wrapper .gradio_bg[theme=default] .gradio_interface .input_image .snapshot button {--tw-bg-opacity: 1;background-color: rgba(220, 38, 38, var(--tw-bg-opacity))
}.gradio_wrapper .gradio_bg[theme=default] .gradio_interface .input_checkbox_group .checkbox_item, .gradio_wrapper .gradio_bg[theme=default] .gradio_interface .input_checkbox .checkbox_item {--tw-bg-opacity: 1;background-color: rgba(255, 255, 255, var(--tw-bg-opacity));--tw-shadow: 0 1px 3px 0 rgba(0, 0, 0, 0.1), 0 1px 2px 0 rgba(0, 0, 0, 0.06);box-shadow: var(--tw-ring-offset-shadow, 0 0 #0000), var(--tw-ring-shadow, 0 0 #0000), var(--tw-shadow);transition-property: background-color, border-color, color, fill, stroke, opacity, box-shadow, -webkit-transform, -webkit-filter, -webkit-backdrop-filter;transition-property: background-color, border-color, color, fill, stroke, opacity, box-shadow, transform, filter, backdrop-filter;transition-property: background-color, border-color, color, fill, stroke, opacity, box-shadow, transform, filter, backdrop-filter, -webkit-transform, -webkit-filter, -webkit-backdrop-filter;transition-timing-function: cubic-bezier(0.4, 0, 0.2, 1);transition-duration: 150ms
}.gradio_wrapper .gradio_bg[theme=default] .gradio_interface .input_checkbox_group .checkbox_item:hover, .gradio_wrapper .gradio_bg[theme=default] .gradio_interface .input_checkbox .checkbox_item:hover {--tw-shadow: 0 4px 6px -1px rgba(0, 0, 0, 0.1), 0 2px 4px -1px rgba(0, 0, 0, 0.06);box-shadow: var(--tw-ring-offset-shadow, 0 0 #0000), var(--tw-ring-shadow, 0 0 #0000), var(--tw-shadow)
}.dark .gradio_wrapper .gradio_bg[theme=default] .gradio_interface .input_checkbox_group .checkbox_item, .dark .gradio_wrapper .gradio_bg[theme=default] .gradio_interface .input_checkbox .checkbox_item {--tw-bg-opacity: 1;background-color: rgba(31, 41, 55, var(--tw-bg-opacity))
}.gradio_wrapper .gradio_bg[theme=default] .gradio_interface .input_checkbox_group .checkbox, .gradio_wrapper .gradio_bg[theme=default] .gradio_interface .input_checkbox .checkbox {--tw-bg-opacity: 1;background-color: rgba(243, 244, 246, var(--tw-bg-opacity));transition-property: background-color, border-color, color, fill, stroke, opacity, box-shadow, -webkit-transform, -webkit-filter, -webkit-backdrop-filter;transition-property: background-color, border-color, color, fill, stroke, opacity, box-shadow, transform, filter, backdrop-filter;transition-property: background-color, border-color, color, fill, stroke, opacity, box-shadow, transform, filter, backdrop-filter, -webkit-transform, -webkit-filter, -webkit-backdrop-filter;transition-timing-function: cubic-bezier(0.4, 0, 0.2, 1);transition-duration: 150ms
}.dark .gradio_wrapper .gradio_bg[theme=default] .gradio_interface .input_checkbox_group .checkbox, .dark .gradio_wrapper .gradio_bg[theme=default] .gradio_interface .input_checkbox .checkbox {--tw-bg-opacity: 1;background-color: rgba(156, 163, 175, var(--tw-bg-opacity))
}.gradio_wrapper .gradio_bg[theme=default] .gradio_interface .input_checkbox_group .checkbox_item.selected, .gradio_wrapper .gradio_bg[theme=default] .gradio_interface .input_checkbox .checkbox_item.selected {--tw-bg-opacity: 1;background-color: rgba(245, 158, 11, var(--tw-bg-opacity));--tw-text-opacity: 1;color: rgba(255, 255, 255, var(--tw-text-opacity))
}.dark .gradio_wrapper .gradio_bg[theme=default] .gradio_interface .input_checkbox_group .checkbox_item.selected, .dark .gradio_wrapper .gradio_bg[theme=default] .gradio_interface .input_checkbox .checkbox_item.selected {--tw-bg-opacity: 1;background-color: rgba(220, 38, 38, var(--tw-bg-opacity))
}.gradio_wrapper .gradio_bg[theme=default] .gradio_interface .input_checkbox_group .selected .checkbox, .gradio_wrapper .gradio_bg[theme=default] .gradio_interface .input_checkbox .selected .checkbox {--tw-bg-opacity: 1;background-color: rgba(217, 119, 6, var(--tw-bg-opacity))
}.dark .gradio_wrapper .gradio_bg[theme=default] .gradio_interface .input_checkbox_group .selected .checkbox, .dark .gradio_wrapper .gradio_bg[theme=default] .gradio_interface .input_checkbox .selected .checkbox {--tw-bg-opacity: 1;background-color: rgba(185, 28, 28, var(--tw-bg-opacity))
}.gradio_wrapper .gradio_bg[theme=default] .gradio_interface .input_slider .range {height: 0.75rem;--tw-bg-opacity: 1;background-color: rgba(255, 255, 255, var(--tw-bg-opacity));--tw-shadow: 0 1px 3px 0 rgba(0, 0, 0, 0.1), 0 1px 2px 0 rgba(0, 0, 0, 0.06);box-shadow: var(--tw-ring-offset-shadow, 0 0 #0000), var(--tw-ring-shadow, 0 0 #0000), var(--tw-shadow);transition-property: background-color, border-color, color, fill, stroke, opacity, box-shadow, -webkit-transform, -webkit-filter, -webkit-backdrop-filter;transition-property: background-color, border-color, color, fill, stroke, opacity, box-shadow, transform, filter, backdrop-filter;transition-property: background-color, border-color, color, fill, stroke, opacity, box-shadow, transform, filter, backdrop-filter, -webkit-transform, -webkit-filter, -webkit-backdrop-filter;transition-timing-function: cubic-bezier(0.4, 0, 0.2, 1);transition-duration: 150ms
}.gradio_wrapper .gradio_bg[theme=default] .gradio_interface .input_slider .range:hover {--tw-shadow: 0 4px 6px -1px rgba(0, 0, 0, 0.1), 0 2px 4px -1px rgba(0, 0, 0, 0.06);box-shadow: var(--tw-ring-offset-shadow, 0 0 #0000), var(--tw-ring-shadow, 0 0 #0000), var(--tw-shadow)
}.dark .gradio_wrapper .gradio_bg[theme=default] .gradio_interface .input_slider .range {--tw-bg-opacity: 1;background-color: rgba(31, 41, 55, var(--tw-bg-opacity))
}.gradio_wrapper .gradio_bg[theme=default] .gradio_interface .input_slider .range::-webkit-slider-thumb {background-image: linear-gradient(to bottom, var(--tw-gradient-stops));--tw-gradient-from: #fbbf24;--tw-gradient-stops: var(--tw-gradient-from), var(--tw-gradient-to, rgba(251, 191, 36, 0));--tw-gradient-to: #f59e0b;--tw-shadow: 0 1px 3px 0 rgba(0, 0, 0, 0.1), 0 1px 2px 0 rgba(0, 0, 0, 0.06);box-shadow: var(--tw-ring-offset-shadow, 0 0 #0000), var(--tw-ring-shadow, 0 0 #0000), var(--tw-shadow)
}.dark .gradio_wrapper .gradio_bg[theme=default] .gradio_interface .input_slider .range::-webkit-slider-thumb {--tw-gradient-from: #ef4444;--tw-gradient-stops: var(--tw-gradient-from), var(--tw-gradient-to, rgba(239, 68, 68, 0));--tw-gradient-to: #dc2626
}.gradio_wrapper .gradio_bg[theme=default] .gradio_interface .input_slider .range::-moz-range-thumb {background-image: linear-gradient(to bottom, var(--tw-gradient-stops));--tw-gradient-from: #fbbf24;--tw-gradient-stops: var(--tw-gradient-from), var(--tw-gradient-to, rgba(251, 191, 36, 0));--tw-gradient-to: #f59e0b;--tw-shadow: 0 1px 3px 0 rgba(0, 0, 0, 0.1), 0 1px 2px 0 rgba(0, 0, 0, 0.06);box-shadow: var(--tw-ring-offset-shadow, 0 0 #0000), var(--tw-ring-shadow, 0 0 #0000), var(--tw-shadow)
}.gradio_wrapper .gradio_bg[theme=default] .gradio_interface .input_slider .value {--tw-bg-opacity: 1;background-color: rgba(243, 244, 246, var(--tw-bg-opacity));font-weight: 600
}.dark .gradio_wrapper .gradio_bg[theme=default] .gradio_interface .input_slider .value {--tw-bg-opacity: 1;background-color: rgba(75, 85, 99, var(--tw-bg-opacity))
}.gradio_wrapper .gradio_bg[theme=default] .gradio_interface .input_dropdown .selector {--tw-bg-opacity: 1;background-color: rgba(255, 255, 255, var(--tw-bg-opacity));--tw-shadow: 0 1px 3px 0 rgba(0, 0, 0, 0.1), 0 1px 2px 0 rgba(0, 0, 0, 0.06);box-shadow: var(--tw-ring-offset-shadow, 0 0 #0000), var(--tw-ring-shadow, 0 0 #0000), var(--tw-shadow);transition-property: background-color, border-color, color, fill, stroke, opacity, box-shadow, -webkit-transform, -webkit-filter, -webkit-backdrop-filter;transition-property: background-color, border-color, color, fill, stroke, opacity, box-shadow, transform, filter, backdrop-filter;transition-property: background-color, border-color, color, fill, stroke, opacity, box-shadow, transform, filter, backdrop-filter, -webkit-transform, -webkit-filter, -webkit-backdrop-filter;transition-timing-function: cubic-bezier(0.4, 0, 0.2, 1);transition-duration: 150ms
}.gradio_wrapper .gradio_bg[theme=default] .gradio_interface .input_dropdown .selector:hover {--tw-shadow: 0 4px 6px -1px rgba(0, 0, 0, 0.1), 0 2px 4px -1px rgba(0, 0, 0, 0.06);box-shadow: var(--tw-ring-offset-shadow, 0 0 #0000), var(--tw-ring-shadow, 0 0 #0000), var(--tw-shadow)
}.dark .gradio_wrapper .gradio_bg[theme=default] .gradio_interface .input_dropdown .selector {--tw-bg-opacity: 1;background-color: rgba(31, 41, 55, var(--tw-bg-opacity))
}.gradio_wrapper .gradio_bg[theme=default] .gradio_interface .input_dropdown .dropdown_menu {--tw-shadow: 0 1px 3px 0 rgba(0, 0, 0, 0.1), 0 1px 2px 0 rgba(0, 0, 0, 0.06);box-shadow: var(--tw-ring-offset-shadow, 0 0 #0000), var(--tw-ring-shadow, 0 0 #0000), var(--tw-shadow)
}.gradio_wrapper .gradio_bg[theme=default] .gradio_interface .input_dropdown .dropdown_item {--tw-bg-opacity: 1;background-color: rgba(255, 255, 255, var(--tw-bg-opacity))
}.gradio_wrapper .gradio_bg[theme=default] .gradio_interface .input_dropdown .dropdown_item:hover {--tw-bg-opacity: 1;background-color: rgba(245, 158, 11, var(--tw-bg-opacity));font-weight: 600;--tw-text-opacity: 1;color: rgba(249, 250, 251, var(--tw-text-opacity))
}.dark .gradio_wrapper .gradio_bg[theme=default] .gradio_interface .input_dropdown .dropdown_item {--tw-bg-opacity: 1;background-color: rgba(31, 41, 55, var(--tw-bg-opacity))
}.dark .gradio_wrapper .gradio_bg[theme=default] .gradio_interface .input_dropdown .dropdown_item:hover {--tw-bg-opacity: 1;background-color: rgba(220, 38, 38, var(--tw-bg-opacity))
}.gradio_wrapper .gradio_bg[theme=default] .gradio_interface .input_audio .start, .gradio_wrapper .gradio_bg[theme=default] .gradio_interface .input_audio .stop {--tw-shadow: 0 1px 3px 0 rgba(0, 0, 0, 0.1), 0 1px 2px 0 rgba(0, 0, 0, 0.06);box-shadow: var(--tw-ring-offset-shadow, 0 0 #0000), var(--tw-ring-shadow, 0 0 #0000), var(--tw-shadow);transition-property: background-color, border-color, color, fill, stroke, opacity, box-shadow, -webkit-transform, -webkit-filter, -webkit-backdrop-filter;transition-property: background-color, border-color, color, fill, stroke, opacity, box-shadow, transform, filter, backdrop-filter;transition-property: background-color, border-color, color, fill, stroke, opacity, box-shadow, transform, filter, backdrop-filter, -webkit-transform, -webkit-filter, -webkit-backdrop-filter;transition-timing-function: cubic-bezier(0.4, 0, 0.2, 1);transition-duration: 150ms
}.gradio_wrapper .gradio_bg[theme=default] .gradio_interface .input_audio .start:hover, .gradio_wrapper .gradio_bg[theme=default] .gradio_interface .input_audio .stop:hover {--tw-shadow: 0 4px 6px -1px rgba(0, 0, 0, 0.1), 0 2px 4px -1px rgba(0, 0, 0, 0.06);box-shadow: var(--tw-ring-offset-shadow, 0 0 #0000), var(--tw-ring-shadow, 0 0 #0000), var(--tw-shadow)
}.gradio_wrapper .gradio_bg[theme=default] .gradio_interface .input_audio .start {--tw-bg-opacity: 1;background-color: rgba(255, 255, 255, var(--tw-bg-opacity))
}.dark .gradio_wrapper .gradio_bg[theme=default] .gradio_interface .input_audio .start {--tw-bg-opacity: 1;background-color: rgba(31, 41, 55, var(--tw-bg-opacity))
}.gradio_wrapper .gradio_bg[theme=default] .gradio_interface .output_text {--tw-shadow: 0 1px 3px 0 rgba(0, 0, 0, 0.1), 0 1px 2px 0 rgba(0, 0, 0, 0.06);box-shadow: var(--tw-ring-offset-shadow, 0 0 #0000), var(--tw-ring-shadow, 0 0 #0000), var(--tw-shadow)
}.dark .gradio_wrapper .gradio_bg[theme=default] .gradio_interface .output_image {--tw-bg-opacity: 1;background-color: rgba(75, 85, 99, var(--tw-bg-opacity))
}.gradio_wrapper .gradio_bg[theme=default] .gradio_interface .output_label .label {height: 1.25rem;font-size: 0.875rem;line-height: 1.25rem
}.gradio_wrapper .gradio_bg[theme=default] .gradio_interface .output_label .confidence {box-sizing: border-box;height: 1.25rem;border-radius: 0.25rem;border-bottom-width: 2px;--tw-border-opacity: 1;border-color: rgba(209, 213, 219, var(--tw-border-opacity));--tw-bg-opacity: 1;background-color: rgba(229, 231, 235, var(--tw-bg-opacity));font-family: ui-monospace, SFMono-Regular, Menlo, Monaco, Consolas, "Liberation Mono", "Courier New", monospace;font-size: 0.875rem;line-height: 1.25rem;font-weight: 600
}.dark .gradio_wrapper .gradio_bg[theme=default] .gradio_interface .output_label .confidence {--tw-border-opacity: 1;border-color: rgba(75, 85, 99, var(--tw-border-opacity));--tw-bg-opacity: 1;background-color: rgba(107, 114, 128, var(--tw-bg-opacity))
}.gradio_wrapper .gradio_bg[theme=default] .gradio_interface .output_label .confidence:first-child {--tw-border-opacity: 1;border-color: rgba(217, 119, 6, var(--tw-border-opacity));--tw-border-opacity: 1;border-color: rgba(185, 28, 28, var(--tw-border-opacity));--tw-bg-opacity: 1;background-color: rgba(245, 158, 11, var(--tw-bg-opacity));--tw-text-opacity: 1;color: rgba(255, 255, 255, var(--tw-text-opacity))
}.dark .gradio_wrapper .gradio_bg[theme=default] .gradio_interface .output_label .confidence:first-child {--tw-bg-opacity: 1;background-color: rgba(220, 38, 38, var(--tw-bg-opacity))
}.gradio_wrapper .gradio_bg[theme=default] .gradio_interface .output_highlightedtext .textfield {--tw-shadow: 0 1px 3px 0 rgba(0, 0, 0, 0.1), 0 1px 2px 0 rgba(0, 0, 0, 0.06);box-shadow: var(--tw-ring-offset-shadow, 0 0 #0000), var(--tw-ring-shadow, 0 0 #0000), var(--tw-shadow)
}
.gradio_wrapper .gradio_bg{/*! tailwindcss v2.2.17 | MIT License | https://tailwindcss.com *//*! modern-normalize v1.1.0 | MIT License | https://github.com/sindresorhus/modern-normalize */-moz-tab-size:4;tab-size:4;line-height:1.15;-webkit-text-size-adjust:100%;margin:0;font-family:system-ui,-apple-system,"Segoe UI",Roboto,Helvetica,Arial,sans-serif,"Apple Color Emoji","Segoe UI Emoji";font-family:ui-sans-serif,system-ui,-apple-system,BlinkMacSystemFont,"Segoe UI",Roboto,"Helvetica Neue",Arial,"Noto Sans",sans-serif,"Apple Color Emoji","Segoe UI Emoji","Segoe UI Symbol","Noto Color Emoji";line-height:1.5}.gradio_wrapper .gradio_bg *, .gradio_wrapper .gradio_bg ::before, .gradio_wrapper .gradio_bg ::after{box-sizing:border-box}.gradio_wrapper .gradio_bg hr{height:0;color:inherit}.gradio_wrapper .gradio_bg abbr[title]{-webkit-text-decoration:underline dotted;text-decoration:underline dotted}.gradio_wrapper .gradio_bg b, .gradio_wrapper .gradio_bg strong{font-weight:bolder}.gradio_wrapper .gradio_bg code, .gradio_wrapper .gradio_bg kbd, .gradio_wrapper .gradio_bg samp, .gradio_wrapper .gradio_bg pre{font-family:ui-monospace,SFMono-Regular,Consolas,"Liberation Mono",Menlo,monospace;font-size:1em}.gradio_wrapper .gradio_bg small{font-size:80%}.gradio_wrapper .gradio_bg sub, .gradio_wrapper .gradio_bg sup{font-size:75%;line-height:0;position:relative;vertical-align:baseline}.gradio_wrapper .gradio_bg sub{bottom:-0.25em}.gradio_wrapper .gradio_bg sup{top:-0.5em}.gradio_wrapper .gradio_bg table{text-indent:0;border-color:inherit}.gradio_wrapper .gradio_bg button, .gradio_wrapper .gradio_bg input, .gradio_wrapper .gradio_bg optgroup, .gradio_wrapper .gradio_bg select, .gradio_wrapper .gradio_bg textarea{font-family:inherit;font-size:100%;line-height:1.15;margin:0}.gradio_wrapper .gradio_bg button, .gradio_wrapper .gradio_bg select{text-transform:none}.gradio_wrapper .gradio_bg button, .gradio_wrapper .gradio_bg [type=button], .gradio_wrapper .gradio_bg [type=reset], .gradio_wrapper .gradio_bg [type=submit]{-webkit-appearance:button}.gradio_wrapper .gradio_bg ::-moz-focus-inner{border-style:none;padding:0}.gradio_wrapper .gradio_bg :-moz-focusring{outline:1px dotted ButtonText}.gradio_wrapper .gradio_bg :-moz-ui-invalid{box-shadow:none}.gradio_wrapper .gradio_bg legend{padding:0}.gradio_wrapper .gradio_bg progress{vertical-align:baseline}.gradio_wrapper .gradio_bg ::-webkit-inner-spin-button, .gradio_wrapper .gradio_bg ::-webkit-outer-spin-button{height:auto}.gradio_wrapper .gradio_bg [type=search]{-webkit-appearance:textfield;outline-offset:-2px}.gradio_wrapper .gradio_bg ::-webkit-search-decoration{-webkit-appearance:none}.gradio_wrapper .gradio_bg ::-webkit-file-upload-button{-webkit-appearance:button;font:inherit}.gradio_wrapper .gradio_bg summary{display:list-item}.gradio_wrapper .gradio_bg blockquote, .gradio_wrapper .gradio_bg dl, .gradio_wrapper .gradio_bg dd, .gradio_wrapper .gradio_bg h1, .gradio_wrapper .gradio_bg h2, .gradio_wrapper .gradio_bg h3, .gradio_wrapper .gradio_bg h4, .gradio_wrapper .gradio_bg h5, .gradio_wrapper .gradio_bg h6, .gradio_wrapper .gradio_bg hr, .gradio_wrapper .gradio_bg figure, .gradio_wrapper .gradio_bg p, .gradio_wrapper .gradio_bg pre{margin:0}.gradio_wrapper .gradio_bg button{background-color:transparent;background-image:none}.gradio_wrapper .gradio_bg fieldset{margin:0;padding:0}.gradio_wrapper .gradio_bg ol, .gradio_wrapper .gradio_bg ul{list-style:none;margin:0;padding:0}.gradio_wrapper .gradio_bg *, .gradio_wrapper .gradio_bg ::before, .gradio_wrapper .gradio_bg ::after{box-sizing:border-box;border-width:0;border-style:solid;border-color:currentColor}.gradio_wrapper .gradio_bg hr{border-top-width:1px}.gradio_wrapper .gradio_bg img{border-style:solid}.gradio_wrapper .gradio_bg textarea{resize:vertical}.gradio_wrapper .gradio_bg input::-webkit-input-placeholder, .gradio_wrapper .gradio_bg textarea::-webkit-input-placeholder{opacity:1;color:#9ca3af}.gradio_wrapper .gradio_bg input:-ms-input-placeholder, .gradio_wrapper .gradio_bg textarea:-ms-input-placeholder{opacity:1;color:#9ca3af}.gradio_bg input::-webkit-input-placeholder, .gradio_bg textarea::-webkit-input-placeholder{opacity:1;color:#9ca3af}.gradio_bg input:-ms-input-placeholder, .gradio_bg textarea:-ms-input-placeholder{opacity:1;color:#9ca3af}.gradio_wrapper .gradio_bg input::placeholder, .gradio_wrapper .gradio_bg textarea::placeholder{opacity:1;color:#9ca3af}.gradio_wrapper .gradio_bg button, .gradio_wrapper .gradio_bg [role=button]{cursor:pointer}.gradio_wrapper .gradio_bg :-moz-focusring{outline:auto}.gradio_wrapper .gradio_bg table{border-collapse:collapse}.gradio_wrapper .gradio_bg h1, .gradio_wrapper .gradio_bg h2, .gradio_wrapper .gradio_bg h3, .gradio_wrapper .gradio_bg h4, .gradio_wrapper .gradio_bg h5, .gradio_wrapper .gradio_bg h6{font-size:inherit;font-weight:inherit}.gradio_wrapper .gradio_bg a{color:inherit;text-decoration:inherit}.gradio_wrapper .gradio_bg button, .gradio_wrapper .gradio_bg input, .gradio_wrapper .gradio_bg optgroup, .gradio_wrapper .gradio_bg select, .gradio_wrapper .gradio_bg textarea{padding:0;line-height:inherit;color:inherit}.gradio_wrapper .gradio_bg pre, .gradio_wrapper .gradio_bg code, .gradio_wrapper .gradio_bg kbd, .gradio_wrapper .gradio_bg samp{font-family:ui-monospace,SFMono-Regular,Menlo,Monaco,Consolas,"Liberation Mono","Courier New",monospace}.gradio_wrapper .gradio_bg img, .gradio_wrapper .gradio_bg svg, .gradio_wrapper .gradio_bg video, .gradio_wrapper .gradio_bg canvas, .gradio_wrapper .gradio_bg audio, .gradio_wrapper .gradio_bg iframe, .gradio_wrapper .gradio_bg embed, .gradio_wrapper .gradio_bg object{display:block;vertical-align:middle}.gradio_wrapper .gradio_bg img, .gradio_wrapper .gradio_bg video{max-width:100%;height:auto}.gradio_wrapper .gradio_bg [hidden]{display:none}.gradio_wrapper .gradio_bg *, .gradio_wrapper .gradio_bg ::before, .gradio_wrapper .gradio_bg ::after{--tw-border-opacity: 1;border-color:rgba(229, 231, 235, var(--tw-border-opacity))}.container{width:100%}@media (min-width: 640px){.container{max-width:640px}}@media (min-width: 768px){.container{max-width:768px}}@media (min-width: 1024px){.container{max-width:1024px}}@media (min-width: 1280px){.container{max-width:1280px}}@media (min-width: 1536px){.container{max-width:1536px}}.prose{color:#374151;max-width:65ch;}.prose [class~="lead"]{color:#4b5563;font-size:1.25em;line-height:1.6;margin-top:1.2em;margin-bottom:1.2em}.prose a{color:#111827;text-decoration:underline;font-weight:500}.prose strong{color:#111827;font-weight:600}.prose ol[type="A"]{--list-counter-style:upper-alpha}.prose ol[type="a"]{--list-counter-style:lower-alpha}.prose ol[type="A" s]{--list-counter-style:upper-alpha}.prose ol[type="a" s]{--list-counter-style:lower-alpha}.prose ol[type="I"]{--list-counter-style:upper-roman}.prose ol[type="i"]{--list-counter-style:lower-roman}.prose ol[type="I" s]{--list-counter-style:upper-roman}.prose ol[type="i" s]{--list-counter-style:lower-roman}.prose ol[type="1"]{--list-counter-style:decimal}.prose ol > li{position:relative;padding-left:1.75em}.prose ol > li::before{content:counter(list-item, var(--list-counter-style, decimal)) ".";position:absolute;font-weight:400;color:#6b7280;left:0}.prose ul > li{position:relative;padding-left:1.75em}.prose ul > li::before{content:"";position:absolute;background-color:#d1d5db;border-radius:50%;width:0.375em;height:0.375em;top:calc(0.875em - 0.1875em);left:0.25em}.prose hr{border-color:#e5e7eb;border-top-width:1px;margin-top:3em;margin-bottom:3em}.prose blockquote{font-weight:500;font-style:italic;color:#111827;border-left-width:0.25rem;border-left-color:#e5e7eb;quotes:"\201C""\201D""\2018""\2019";margin-top:1.6em;margin-bottom:1.6em;padding-left:1em}.prose blockquote p:first-of-type::before{content:open-quote}.prose blockquote p:last-of-type::after{content:close-quote}.prose h1{color:#111827;font-weight:semibold;font-size:2.25em;margin-top:0;margin-bottom:0.8888889em;line-height:1.1111111}.prose h2{color:#111827;font-weight:semibold;font-size:1.5em;margin-top:2em;margin-bottom:1em;line-height:1.3333333}.prose h3{color:#111827;font-weight:semibold;font-size:1.25em;margin-top:1.6em;margin-bottom:0.6em;line-height:1.6}.prose h4{color:#111827;font-weight:semibold;margin-top:1.5em;margin-bottom:0.5em;line-height:1.5}.prose figure figcaption{color:#6b7280;font-size:0.875em;line-height:1.4285714;margin-top:0.8571429em}.prose code{color:#111827;font-weight:600;font-size:0.875em}.prose code::before{content:"`"}.prose code::after{content:"`"}.prose a code{color:#111827}.prose pre{color:#e5e7eb;background-color:#1f2937;overflow-x:auto;font-size:0.875em;line-height:1.7142857;margin-top:1.7142857em;margin-bottom:1.7142857em;border-radius:0.375rem;padding-top:0.8571429em;padding-right:1.1428571em;padding-bottom:0.8571429em;padding-left:1.1428571em}.prose pre code{background-color:transparent;border-width:0;border-radius:0;padding:0;font-weight:400;color:inherit;font-size:inherit;font-family:inherit;line-height:inherit}.prose pre code::before{content:none}.prose pre code::after{content:none}.prose table{width:100%;table-layout:auto;text-align:left;margin-top:2em;margin-bottom:2em;font-size:0.875em;line-height:1.7142857}.prose thead{color:#111827;font-weight:600;border-bottom-width:1px;border-bottom-color:#d1d5db}.prose thead th{vertical-align:bottom;padding-right:0.5714286em;padding-bottom:0.5714286em;padding-left:0.5714286em}.prose tbody tr{border-bottom-width:1px;border-bottom-color:#e5e7eb}.prose tbody tr:last-child{border-bottom-width:0}.prose tbody td{vertical-align:top;padding-top:0.5714286em;padding-right:0.5714286em;padding-bottom:0.5714286em;padding-left:0.5714286em}.prose{font-size:1rem;line-height:1.75}.prose p{margin-top:1.25em;margin-bottom:1.25em}.prose img{margin-top:2em;margin-bottom:2em}.prose video{margin-top:2em;margin-bottom:2em}.prose figure{margin-top:2em;margin-bottom:2em}.prose figure > *{margin-top:0;margin-bottom:0}.prose h2 code{font-size:0.875em}.prose h3 code{font-size:0.9em}.prose ol{margin-top:1.25em;margin-bottom:1.25em}.prose ul{margin-top:1.25em;margin-bottom:1.25em}.prose li{margin-top:0.5em;margin-bottom:0.5em}.prose > ul > li p{margin-top:0.75em;margin-bottom:0.75em}.prose > ul > li > *:first-child{margin-top:1.25em}.prose > ul > li > *:last-child{margin-bottom:1.25em}.prose > ol > li > *:first-child{margin-top:1.25em}.prose > ol > li > *:last-child{margin-bottom:1.25em}.prose ul ul, .prose ul ol, .prose ol ul, .prose ol ol{margin-top:0.75em;margin-bottom:0.75em}.prose hr + *{margin-top:0}.prose h2 + *{margin-top:0}.prose h3 + *{margin-top:0}.prose h4 + *{margin-top:0}.prose thead th:first-child{padding-left:0}.prose thead th:last-child{padding-right:0}.prose tbody td:first-child{padding-left:0}.prose tbody td:last-child{padding-right:0}.prose > :first-child{margin-top:0}.prose > :last-child{margin-bottom:0}.prose h5{font-weight:semibold}.prose h6{font-weight:semibold}.static{position:static}.relative{position:relative}.flex{display:flex}.table{display:table}.transform{-webkit-transform:var(--tw-transform);transform:var(--tw-transform)}.resize{resize:both}.flex-col{flex-direction:column}.opacity-50{opacity:0.5}.filter{-webkit-filter:var(--tw-filter);filter:var(--tw-filter)}.gradio_wrapper .login{width:100%}@media (min-width: 640px){.gradio_wrapper .login{max-width:640px}}@media (min-width: 768px){.gradio_wrapper .login{max-width:768px}}@media (min-width: 1024px){.gradio_wrapper .login{max-width:1024px}}@media (min-width: 1280px){.gradio_wrapper .login{max-width:1280px}}@media (min-width: 1536px){.gradio_wrapper .login{max-width:1536px}}.gradio_wrapper .login{margin-top:2rem}.gradio_wrapper .login form{margin-left:auto;margin-right:auto;width:50%;--tw-bg-opacity:1;background-color:rgba(249, 250, 251, var(--tw-bg-opacity));padding:1rem;--tw-shadow:0 4px 6px -1px rgba(0, 0, 0, 0.1), 0 2px 4px -1px rgba(0, 0, 0, 0.06);box-shadow:var(--tw-ring-offset-shadow, 0 0 #0000), var(--tw-ring-shadow, 0 0 #0000), var(--tw-shadow)}.gradio_wrapper .login h2{margin-top:0.5rem;margin-bottom:0.5rem;font-size:1.5rem;line-height:2rem;font-weight:600}.gradio_wrapper .login label{margin-top:1rem;display:block;text-transform:uppercase}.gradio_wrapper .login input{display:block;padding:0.5rem}.gradio_wrapper .login .submit{margin-top:1rem;cursor:pointer;border-radius:0.25rem;--tw-bg-opacity:1;background-color:rgba(245, 158, 11, var(--tw-bg-opacity));padding-left:1rem;padding-right:1rem;padding-top:0.5rem;padding-bottom:0.5rem;font-weight:600;--tw-text-opacity:1;color:rgba(255, 255, 255, var(--tw-text-opacity));transition-property:background-color, border-color, color, fill, stroke, opacity, box-shadow, -webkit-transform, -webkit-filter, -webkit-backdrop-filter;transition-property:background-color, border-color, color, fill, stroke, opacity, box-shadow, transform, filter, backdrop-filter;transition-property:background-color, border-color, color, fill, stroke, opacity, box-shadow, transform, filter, backdrop-filter, -webkit-transform, -webkit-filter, -webkit-backdrop-filter;transition-timing-function:cubic-bezier(0.4, 0, 0.2, 1);transition-duration:150ms}.gradio_wrapper .login .submit:hover{--tw-bg-opacity:1;background-color:rgba(251, 191, 36, var(--tw-bg-opacity))}.dark .gradio_wrapper .login .submit:hover{--tw-bg-opacity:1;background-color:rgba(217, 119, 6, var(--tw-bg-opacity))}
.gradio_wrapper .gradio_bg[theme=seafoam] {--tw-bg-opacity: 1;background-color: rgba(254, 243, 199, var(--tw-bg-opacity))
}.dark .gradio_wrapper .gradio_bg[theme=seafoam] {--tw-bg-opacity: 1;background-color: rgba(55, 65, 81, var(--tw-bg-opacity))
}.gradio_wrapper .gradio_bg[theme=seafoam] .gradio_interface .component_set {padding: 0px
}.gradio_wrapper .gradio_bg[theme=seafoam] .gradio_interface .component {--tw-bg-opacity: 1;background-color: rgba(255, 255, 255, var(--tw-bg-opacity));padding: 0.5rem;--tw-shadow: 0 1px 2px 0 rgba(0, 0, 0, 0.05);box-shadow: var(--tw-ring-offset-shadow, 0 0 #0000), var(--tw-ring-shadow, 0 0 #0000), var(--tw-shadow);transition-property: background-color, border-color, color, fill, stroke, opacity, box-shadow, -webkit-transform, -webkit-filter, -webkit-backdrop-filter;transition-property: background-color, border-color, color, fill, stroke, opacity, box-shadow, transform, filter, backdrop-filter;transition-property: background-color, border-color, color, fill, stroke, opacity, box-shadow, transform, filter, backdrop-filter, -webkit-transform, -webkit-filter, -webkit-backdrop-filter;transition-timing-function: cubic-bezier(0.4, 0, 0.2, 1);transition-duration: 150ms
}.dark .gradio_wrapper .gradio_bg[theme=seafoam] .gradio_interface .component {--tw-bg-opacity: 1;background-color: rgba(31, 41, 55, var(--tw-bg-opacity))
}.gradio_wrapper .gradio_bg[theme=seafoam] .gradio_interface .component:hover .panel_header {font-size: 1rem;line-height: 1.5rem;--tw-text-opacity: 1;color: rgba(52, 211, 153, var(--tw-text-opacity))
}.gradio_wrapper .gradio_bg[theme=seafoam] .gradio_interface .panel_header {height: 1.5rem;font-size: 0.875rem;line-height: 1.25rem;font-weight: 600;--tw-text-opacity: 1;color: rgba(156, 163, 175, var(--tw-text-opacity));transition-property: all;transition-timing-function: cubic-bezier(0.4, 0, 0.2, 1);transition-duration: 150ms
}.dark .gradio_wrapper .gradio_bg[theme=seafoam] .gradio_interface .panel_header {--tw-text-opacity: 1;color: rgba(229, 231, 235, var(--tw-text-opacity))
}.gradio_wrapper .gradio_bg[theme=seafoam] .gradio_interface .panel_button {background-image: linear-gradient(to top, var(--tw-gradient-stops));--tw-gradient-from: #60a5fa;--tw-gradient-stops: var(--tw-gradient-from), var(--tw-gradient-to, rgba(96, 165, 250, 0));--tw-gradient-to: #6ee7b7;--tw-text-opacity: 1;color: rgba(255, 255, 255, var(--tw-text-opacity));--tw-shadow: 0 1px 3px 0 rgba(0, 0, 0, 0.1), 0 1px 2px 0 rgba(0, 0, 0, 0.06);box-shadow: var(--tw-ring-offset-shadow, 0 0 #0000), var(--tw-ring-shadow, 0 0 #0000), var(--tw-shadow)
}.gradio_wrapper .gradio_bg[theme=seafoam] .gradio_interface .panel_button:hover {--tw-gradient-to: #34d399
}.dark .gradio_wrapper .gradio_bg[theme=seafoam] .gradio_interface .panel_button {--tw-gradient-from: #3b82f6;--tw-gradient-stops: var(--tw-gradient-from), var(--tw-gradient-to, rgba(59, 130, 246, 0))
}.dark .gradio_wrapper .gradio_bg[theme=seafoam] .gradio_interface .examples .examples_table_holder:not(.gallery) .examples_table {--tw-bg-opacity: 1;background-color: rgba(31, 41, 55, var(--tw-bg-opacity))
}.gradio_wrapper .gradio_bg[theme=seafoam] .gradio_interface .examples .examples_table_holder:not(.gallery) .examples_table tbody tr:hover {--tw-bg-opacity: 1;background-color: rgba(96, 165, 250, var(--tw-bg-opacity))
}.dark .gradio_wrapper .gradio_bg[theme=seafoam] .gradio_interface .examples .examples_table_holder:not(.gallery) .examples_table tbody tr:hover {--tw-bg-opacity: 1;background-color: rgba(59, 130, 246, var(--tw-bg-opacity))
}.dark .gradio_wrapper .gradio_bg[theme=seafoam] .gradio_interface .examples .examples_table_holder.gallery .examples_table tbody td {--tw-bg-opacity: 1;background-color: rgba(31, 41, 55, var(--tw-bg-opacity))
}.gradio_wrapper .gradio_bg[theme=seafoam] .gradio_interface .examples .examples_table_holder.gallery .examples_table tbody td:hover {--tw-bg-opacity: 1;background-color: rgba(96, 165, 250, var(--tw-bg-opacity))
}.dark .gradio_wrapper .gradio_bg[theme=seafoam] .gradio_interface .examples .examples_table_holder.gallery .examples_table tbody td:hover {--tw-bg-opacity: 1;background-color: rgba(59, 130, 246, var(--tw-bg-opacity))
}.gradio_wrapper .gradio_bg[theme=seafoam] .gradio_interface .edit_button, .gradio_wrapper .gradio_bg[theme=seafoam] .gradio_interface .clear_button {background-image: linear-gradient(to top, var(--tw-gradient-stops));--tw-gradient-from: #60a5fa;--tw-gradient-stops: var(--tw-gradient-from), var(--tw-gradient-to, rgba(96, 165, 250, 0));--tw-gradient-to: #6ee7b7;--tw-text-opacity: 1;color: rgba(255, 255, 255, var(--tw-text-opacity))
}.gradio_wrapper .gradio_bg[theme=seafoam] .gradio_interface .edit_button:hover, .gradio_wrapper .gradio_bg[theme=seafoam] .gradio_interface .clear_button:hover {--tw-gradient-to: #34d399
}.dark .gradio_wrapper .gradio_bg[theme=seafoam] .gradio_interface .edit_button, .dark .gradio_wrapper .gradio_bg[theme=seafoam] .gradio_interface .clear_button {--tw-gradient-from: #3b82f6;--tw-gradient-stops: var(--tw-gradient-from), var(--tw-gradient-to, rgba(59, 130, 246, 0))
}.gradio_wrapper .gradio_bg[theme=seafoam] .gradio_interface .input_text textarea, .gradio_wrapper .gradio_bg[theme=seafoam] .gradio_interface .input_text input {border-radius: 0px;--tw-bg-opacity: 1;background-color: rgba(249, 250, 251, var(--tw-bg-opacity));--tw-text-opacity: 1;color: rgba(96, 165, 250, var(--tw-text-opacity))
}.dark .gradio_wrapper .gradio_bg[theme=seafoam] .gradio_interface .input_text textarea, .dark .gradio_wrapper .gradio_bg[theme=seafoam] .gradio_interface .input_text input {--tw-bg-opacity: 1;background-color: rgba(55, 65, 81, var(--tw-bg-opacity));--tw-text-opacity: 1;color: rgba(249, 250, 251, var(--tw-text-opacity))
}.gradio_wrapper .gradio_bg[theme=seafoam] .gradio_interface .input_number input {border-radius: 0px;--tw-bg-opacity: 1;background-color: rgba(249, 250, 251, var(--tw-bg-opacity));--tw-text-opacity: 1;color: rgba(96, 165, 250, var(--tw-text-opacity))
}.dark .gradio_wrapper .gradio_bg[theme=seafoam] .gradio_interface .input_number input {--tw-bg-opacity: 1;background-color: rgba(55, 65, 81, var(--tw-bg-opacity));--tw-text-opacity: 1;color: rgba(249, 250, 251, var(--tw-text-opacity))
}.gradio_wrapper .gradio_bg[theme=seafoam] .gradio_interface .input_slider .range {border-radius: 0px;--tw-bg-opacity: 1;background-color: rgba(249, 250, 251, var(--tw-bg-opacity))
}.dark .gradio_wrapper .gradio_bg[theme=seafoam] .gradio_interface .input_slider .range {--tw-bg-opacity: 1;background-color: rgba(55, 65, 81, var(--tw-bg-opacity))
}.gradio_wrapper .gradio_bg[theme=seafoam] .gradio_interface .input_slider .range::-webkit-slider-thumb {background-image: linear-gradient(to top, var(--tw-gradient-stops));--tw-gradient-from: #60a5fa;--tw-gradient-stops: var(--tw-gradient-from), var(--tw-gradient-to, rgba(96, 165, 250, 0));--tw-gradient-to: #6ee7b7;--tw-shadow: 0 1px 2px 0 rgba(0, 0, 0, 0.05);box-shadow: var(--tw-ring-offset-shadow, 0 0 #0000), var(--tw-ring-shadow, 0 0 #0000), var(--tw-shadow)
}.dark .gradio_wrapper .gradio_bg[theme=seafoam] .gradio_interface .input_slider .range::-webkit-slider-thumb {--tw-gradient-from: #3b82f6;--tw-gradient-stops: var(--tw-gradient-from), var(--tw-gradient-to, rgba(59, 130, 246, 0))
}.gradio_wrapper .gradio_bg[theme=seafoam] .gradio_interface .input_slider .range::-moz-range-thumb {background-image: linear-gradient(to top, var(--tw-gradient-stops));--tw-gradient-from: #60a5fa;--tw-gradient-stops: var(--tw-gradient-from), var(--tw-gradient-to, rgba(96, 165, 250, 0));--tw-gradient-to: #6ee7b7;--tw-shadow: 0 1px 2px 0 rgba(0, 0, 0, 0.05);box-shadow: var(--tw-ring-offset-shadow, 0 0 #0000), var(--tw-ring-shadow, 0 0 #0000), var(--tw-shadow)
}.dark .gradio_wrapper .gradio_bg[theme=seafoam] .gradio_interface .input_slider .range::-moz-range-thumb {--tw-gradient-from: #3b82f6;--tw-gradient-stops: var(--tw-gradient-from), var(--tw-gradient-to, rgba(59, 130, 246, 0))
}.gradio_wrapper .gradio_bg[theme=seafoam] .gradio_interface .input_slider .value {--tw-bg-opacity: 1;background-color: rgba(249, 250, 251, var(--tw-bg-opacity));font-weight: 600;--tw-text-opacity: 1;color: rgba(96, 165, 250, var(--tw-text-opacity))
}.dark .gradio_wrapper .gradio_bg[theme=seafoam] .gradio_interface .input_slider .value {--tw-bg-opacity: 1;background-color: rgba(55, 65, 81, var(--tw-bg-opacity));--tw-text-opacity: 1;color: rgba(249, 250, 251, var(--tw-text-opacity))
}.gradio_wrapper .gradio_bg[theme=seafoam] .gradio_interface .input_radio .radio_item {--tw-bg-opacity: 1;background-color: rgba(249, 250, 251, var(--tw-bg-opacity));--tw-text-opacity: 1;color: rgba(96, 165, 250, var(--tw-text-opacity))
}.dark .gradio_wrapper .gradio_bg[theme=seafoam] .gradio_interface .input_radio .radio_item {--tw-bg-opacity: 1;background-color: rgba(55, 65, 81, var(--tw-bg-opacity));--tw-text-opacity: 1;color: rgba(249, 250, 251, var(--tw-text-opacity))
}.gradio_wrapper .gradio_bg[theme=seafoam] .gradio_interface .input_radio .radio_circle {border-width: 4px;--tw-border-opacity: 1;border-color: rgba(229, 231, 235, var(--tw-border-opacity));--tw-bg-opacity: 1;background-color: rgba(249, 250, 251, var(--tw-bg-opacity))
}.dark .gradio_wrapper .gradio_bg[theme=seafoam] .gradio_interface .input_radio .radio_circle {--tw-border-opacity: 1;border-color: rgba(75, 85, 99, var(--tw-border-opacity));--tw-bg-opacity: 1;background-color: rgba(156, 163, 175, var(--tw-bg-opacity))
}.gradio_wrapper .gradio_bg[theme=seafoam] .gradio_interface .input_radio .radio_item.selected {background-image: linear-gradient(to top, var(--tw-gradient-stops));--tw-gradient-from: #60a5fa;--tw-gradient-stops: var(--tw-gradient-from), var(--tw-gradient-to, rgba(96, 165, 250, 0));--tw-gradient-to: #6ee7b7;--tw-text-opacity: 1;color: rgba(255, 255, 255, var(--tw-text-opacity));--tw-shadow: 0 1px 3px 0 rgba(0, 0, 0, 0.1), 0 1px 2px 0 rgba(0, 0, 0, 0.06);box-shadow: var(--tw-ring-offset-shadow, 0 0 #0000), var(--tw-ring-shadow, 0 0 #0000), var(--tw-shadow)
}.dark .gradio_wrapper .gradio_bg[theme=seafoam] .gradio_interface .input_radio .radio_item.selected {--tw-gradient-from: #3b82f6;--tw-gradient-stops: var(--tw-gradient-from), var(--tw-gradient-to, rgba(59, 130, 246, 0))
}.gradio_wrapper .gradio_bg[theme=seafoam] .gradio_interface .input_radio .radio_circle {box-sizing: border-box;height: 1rem;width: 1rem;border-radius: 9999px;--tw-bg-opacity: 1;background-color: rgba(255, 255, 255, var(--tw-bg-opacity));transition-property: background-color, border-color, color, fill, stroke, opacity, box-shadow, -webkit-transform, -webkit-filter, -webkit-backdrop-filter;transition-property: background-color, border-color, color, fill, stroke, opacity, box-shadow, transform, filter, backdrop-filter;transition-property: background-color, border-color, color, fill, stroke, opacity, box-shadow, transform, filter, backdrop-filter, -webkit-transform, -webkit-filter, -webkit-backdrop-filter;transition-timing-function: cubic-bezier(0.4, 0, 0.2, 1);transition-duration: 150ms
}.gradio_wrapper .gradio_bg[theme=seafoam] .gradio_interface .input_radio .selected .radio_circle {--tw-border-opacity: 1;border-color: rgba(156, 163, 175, var(--tw-border-opacity));opacity: 0.4
}.gradio_wrapper .gradio_bg[theme=seafoam] .gradio_interface .input_checkbox_group .checkbox_item, .gradio_wrapper .gradio_bg[theme=seafoam] .gradio_interface .input_checkbox .checkbox_item {--tw-bg-opacity: 1;background-color: rgba(249, 250, 251, var(--tw-bg-opacity));--tw-text-opacity: 1;color: rgba(96, 165, 250, var(--tw-text-opacity))
}.dark .gradio_wrapper .gradio_bg[theme=seafoam] .gradio_interface .input_checkbox_group .checkbox_item, .dark .gradio_wrapper .gradio_bg[theme=seafoam] .gradio_interface .input_checkbox .checkbox_item {--tw-bg-opacity: 1;background-color: rgba(55, 65, 81, var(--tw-bg-opacity));--tw-text-opacity: 1;color: rgba(249, 250, 251, var(--tw-text-opacity))
}.gradio_wrapper .gradio_bg[theme=seafoam] .gradio_interface .input_checkbox_group .checkbox_item.selected, .gradio_wrapper .gradio_bg[theme=seafoam] .gradio_interface .input_checkbox .checkbox_item.selected {background-image: linear-gradient(to top, var(--tw-gradient-stops));--tw-gradient-from: #60a5fa;--tw-gradient-stops: var(--tw-gradient-from), var(--tw-gradient-to, rgba(96, 165, 250, 0));--tw-gradient-to: #6ee7b7;--tw-text-opacity: 1;color: rgba(255, 255, 255, var(--tw-text-opacity));--tw-shadow: 0 1px 3px 0 rgba(0, 0, 0, 0.1), 0 1px 2px 0 rgba(0, 0, 0, 0.06);box-shadow: var(--tw-ring-offset-shadow, 0 0 #0000), var(--tw-ring-shadow, 0 0 #0000), var(--tw-shadow)
}.dark .gradio_wrapper .gradio_bg[theme=seafoam] .gradio_interface .input_checkbox_group .checkbox_item.selected, .dark .gradio_wrapper .gradio_bg[theme=seafoam] .gradio_interface .input_checkbox .checkbox_item.selected {--tw-gradient-from: #3b82f6;--tw-gradient-stops: var(--tw-gradient-from), var(--tw-gradient-to, rgba(59, 130, 246, 0))
}.gradio_wrapper .gradio_bg[theme=seafoam] .gradio_interface .input_checkbox_group .selected .checkbox, .gradio_wrapper .gradio_bg[theme=seafoam] .gradio_interface .input_checkbox .selected .checkbox {--tw-bg-opacity: 1;background-color: rgba(156, 163, 175, var(--tw-bg-opacity));--tw-bg-opacity: 0.4
}.gradio_wrapper .gradio_bg[theme=seafoam] .gradio_interface .input_dropdown .selector {--tw-bg-opacity: 1;background-color: rgba(249, 250, 251, var(--tw-bg-opacity));--tw-text-opacity: 1;color: rgba(96, 165, 250, var(--tw-text-opacity))
}.dark .gradio_wrapper .gradio_bg[theme=seafoam] .gradio_interface .input_dropdown .selector {--tw-bg-opacity: 1;background-color: rgba(55, 65, 81, var(--tw-bg-opacity));--tw-text-opacity: 1;color: rgba(249, 250, 251, var(--tw-text-opacity))
}.gradio_wrapper .gradio_bg[theme=seafoam] .gradio_interface .input_dropdown .dropdown_menu {--tw-shadow: 0 1px 3px 0 rgba(0, 0, 0, 0.1), 0 1px 2px 0 rgba(0, 0, 0, 0.06);box-shadow: var(--tw-ring-offset-shadow, 0 0 #0000), var(--tw-ring-shadow, 0 0 #0000), var(--tw-shadow)
}.gradio_wrapper .gradio_bg[theme=seafoam] .gradio_interface .input_dropdown .dropdown_item {--tw-bg-opacity: 1;background-color: rgba(255, 255, 255, var(--tw-bg-opacity))
}.gradio_wrapper .gradio_bg[theme=seafoam] .gradio_interface .input_dropdown .dropdown_item:hover {--tw-bg-opacity: 1;background-color: rgba(96, 165, 250, var(--tw-bg-opacity));font-weight: 600;--tw-text-opacity: 1;color: rgba(249, 250, 251, var(--tw-text-opacity))
}.dark .gradio_wrapper .gradio_bg[theme=seafoam] .gradio_interface .input_dropdown .dropdown_item {--tw-bg-opacity: 1;background-color: rgba(31, 41, 55, var(--tw-bg-opacity))
}.gradio_wrapper .gradio_bg[theme=seafoam] .gradio_interface .output_label .confidence {border-radius: 0.25rem;background-image: linear-gradient(to top, var(--tw-gradient-stops));--tw-gradient-from: #9ca3af;--tw-gradient-stops: var(--tw-gradient-from), var(--tw-gradient-to, rgba(156, 163, 175, 0));--tw-gradient-to: #d1d5db;font-weight: 600;--tw-text-opacity: 1;color: rgba(255, 255, 255, var(--tw-text-opacity))
}.dark .gradio_wrapper .gradio_bg[theme=seafoam] .gradio_interface .output_label .confidence {--tw-gradient-from: #6b7280;--tw-gradient-stops: var(--tw-gradient-from), var(--tw-gradient-to, rgba(107, 114, 128, 0));--tw-gradient-to: #9ca3af
}.gradio_wrapper .gradio_bg[theme=seafoam] .gradio_interface .output_label .confidence:first-child {background-image: linear-gradient(to top, var(--tw-gradient-stops));--tw-gradient-from: #60a5fa;--tw-gradient-stops: var(--tw-gradient-from), var(--tw-gradient-to, rgba(96, 165, 250, 0));--tw-gradient-to: #6ee7b7
}.dark .gradio_wrapper .gradio_bg[theme=seafoam] .gradio_interface .output_label .confidence:first-child {--tw-gradient-from: #3b82f6;--tw-gradient-stops: var(--tw-gradient-from), var(--tw-gradient-to, rgba(59, 130, 246, 0))
}
